@@ -2,7 +2,7 @@
 /*
  * aliasbr.h -- definitions for the aliasing system
  *
- * $Id$
+ * $Id: aliasbr.h,v 1.3 2006/01/16 10:00:46 opk Exp $
  */
 
 extern char *AliasFile;		/* mh-alias(5)             */
@@ -23,21 +23,20 @@ struct adr {
     char ad_local;		/* text is local (check for expansion) */
 };
 
-struct home {			/* incore version of /etc/passwd         */
+/*
+ * incore version of /etc/passwd
+ */
+struct home {
     char *h_name;		/* user name                             */
     uid_t h_uid;		/* user id                               */
     gid_t h_gid;		/* user's group                          */
     char *h_home;		/* user's home directory                 */
     char *h_shell;		/* user's shell                          */
-#ifdef BSD42
     int	h_ngrps;		/* number of groups this user belongs to */
-#endif /* BSD42 */
     struct home *h_next;	/* next home in list                     */
 };
 
-#ifndef	MMDFMTS
-struct home *seek_home ();
-#endif /* MMDFMTS */
+struct home *seek_home (char *);
 
 /*
  * prototypes
