@@ -2,7 +2,7 @@
 /*
  * mh.h -- main header file for all of nmh
  *
- * $Id: mh.h,v 1.5 2005/10/05 10:05:24 opk Exp $
+ * $Id: mh.h,v 1.8 2007/11/04 11:54:32 jjr Exp $
  */
 
 #include <h/nmh.h>
@@ -58,6 +58,8 @@ struct swit {
 
 extern struct swit anoyes[];	/* standard yes/no switches */
 
+#define ATTACHFORMATS 3		/* Number of send attach formats. */
+
 /*
  * general folder attributes
  */
@@ -334,5 +336,7 @@ extern char *vmhproc;
 extern char *whatnowproc;
 extern char *whomproc;
 
+extern void (*done) (int);
+
 #include <h/prototypes.h>
 
