@@ -2,7 +2,7 @@
 /*
  * nmh.h -- system configuration header file
  *
- * $Id$
+ * $Id: nmh.h,v 1.1.1.1 1999/04/30 18:08:34 doug Exp $
  */
 
 #include <config.h>
@@ -77,7 +77,6 @@
 
 /*
  * we should be getting this value from pathconf(_PC_PATH_MAX)
- * but this is too much trouble
  */
 #ifndef PATH_MAX
 # ifdef MAXPATHLEN
@@ -88,9 +87,19 @@
 # endif
 #endif
 
+/*
+ * we should get this value from sysconf(_SC_NGROUPS_MAX)
+ */
+#ifndef NGROUPS_MAX
+# ifdef NGROUPS
+#  define NGROUPS_MAX NGROUPS
+# else
+#  define NGROUPS_MAX 16
+# endif
+#endif
+
 /*
  * we should be getting this value from sysconf(_SC_OPEN_MAX)
- * but this is too much trouble
  */
 #ifndef OPEN_MAX
 # ifdef NOFILE
