@@ -2,7 +2,7 @@
 /*
  * popsbr.h -- header for POP client subroutines
  *
- * $Id: popsbr.h,v 1.4 2005/01/27 16:34:20 opk Exp $
+ * $Id: popsbr.h,v 1.5 2007/11/08 02:28:38 jjr Exp $
  */
 
 #if 0
@@ -25,11 +25,11 @@ int pop_exists (int (*)());
 int pop_init (char *, char *, char *, char *, int, int, int, int, char *);
 int pop_fd (char *, int, char *, int);
 int pop_stat (int *, int *);
-int pop_retr (int, int (*)());
+int pop_retr (int, int (*)(char *));
 int pop_dele (int);
 int pop_noop (void);
 int pop_rset (void);
-int pop_top (int, int, int (*)());
+int pop_top (int, int, int (*)(char *));
 int pop_quit (void);
 int pop_done (void);
 
