@@ -2,16 +2,20 @@
 /*
  * addrsbr.c -- parse addresses 822-style
  *
- * $Id: addrsbr.c,v 1.3 2000/03/14 05:05:49 danh Exp $
+ * $Id: addrsbr.c,v 1.7 2006/03/08 12:14:16 bress Exp $
+ *
+ * This code is Copyright (c) 2002, by the authors of nmh.  See the
+ * COPYRIGHT file in the root directory of the nmh distribution for
+ * complete copyright information.
  */
 
 #include <h/mh.h>
 #include <h/addrsbr.h>
-#include <zotnet/mf/mf.h>
+#include <h/mf.h>
 
 /* High level parsing of addresses:
 
-   The routines in zotnet/mf/mf.c parse the syntactic representations of
+   The routines in sbr/mf.c parse the syntactic representations of
    addresses.  The routines in sbr/addrsbr.c associate semantics with those
    addresses.  
 
@@ -202,18 +206,18 @@ getm (char *str, char *dfhost, int dftype, int wanthost, char *eresult)
     }
 
     if (wanthost == AD_NHST)
-	mp->m_type = !strcasecmp (LocalName (), mp->m_host)
+	mp->m_type = !mh_strcasecmp (LocalName (), mp->m_host)
 	    ? LOCALHOST : NETHOST;
 #ifdef DUMB
     else
-	mp->m_type = strcasecmp (LocalName(), mp->m_host) ?  NETHOST : LOCALHOST;
+	mp->m_type = mh_strcasecmp (LocalName(), mp->m_host) ?  NETHOST : LOCALHOST;
 #else /* not DUMB */
     else
 	if (pp = OfficialName (mp->m_host)) {
     got_real_host: ;
 	    free (mp->m_host);
 	    mp->m_host = getcpy (pp);
-	    mp->m_type = strcasecmp (LocalName(), mp->m_host) ? NETHOST : LOCALHOST;
+	    mp->m_type = mh_strcasecmp (LocalName(), mp->m_host) ? NETHOST : LOCALHOST;
 	}
 	else {
 	    if (dp = strchr(mp->m_host, '.')) {
@@ -452,11 +456,11 @@ ismymbox (struct mailname *np)
 	    goto local_test;
 
 	case UUCPHOST:
-	    if (strcasecmp (np->m_host, SystemName()))
+	    if (mh_strcasecmp (np->m_host, SystemName()))
 		break;		/* fall */
 	case LOCALHOST:
 local_test: ;
-	    if (!strcasecmp (np->m_mbox, mq.m_mbox))
+	    if (!mh_strcasecmp (np->m_mbox, mq.m_mbox))
 		return 1;
 	    break;
 
@@ -477,11 +481,11 @@ local_test: ;
 	    continue;
 	switch (mp->m_type & W_MBOX) {
 	    case W_NIL: 
-		if (strcasecmp (cp, pp))
+		if (mh_strcasecmp (cp, pp))
 		    continue;
 		break;
 	    case W_MBEG: 
-		if (strcasecmp (cp + len - i, pp))
+		if (mh_strcasecmp (cp + len - i, pp))
 		    continue;
 		break;
 	    case W_MEND: 
@@ -503,11 +507,11 @@ local_test: ;
 	    continue;
 	switch (mp->m_type & W_HOST) {
 	    case W_NIL: 
-		if (strcasecmp (cp, pp))
+		if (mh_strcasecmp (cp, pp))
 		    continue;
 		break;
 	    case W_HBEG: 
-		if (strcasecmp (cp + len - i, pp))
+		if (mh_strcasecmp (cp + len - i, pp))
 		    continue;
 		break;
 	    case W_HEND: 
