@@ -2,7 +2,7 @@
 /*
  * check_charset.c -- routines for character sets
  *
- * $Id: check_charset.c,v 1.4 2005/01/27 16:26:24 opk Exp $
+ * $Id: check_charset.c,v 1.5 2006/03/08 12:14:16 bress Exp $
  *
  * This code is Copyright (c) 2002, by the authors of nmh.  See the
  * COPYRIGHT file in the root directory of the nmh distribution for
@@ -53,7 +53,7 @@ check_charset (char *str, int len)
 
 	/* US-ASCII is a subset of the ISO-8859-X and UTF-8 character sets */
 	if (!strncasecmp("ISO-8859-", mm_charset, 9) ||
-		!strcasecmp("UTF-8", mm_charset)) {
+		!mh_strcasecmp("UTF-8", mm_charset)) {
 	    alt_charset = "US-ASCII";
 	    alt_len = strlen (alt_charset);
 	}
