@@ -3,10 +3,15 @@
  * concat.c -- concatenate a variable number (minimum of 1)
  *             of strings in managed memory
  *
- * $Id: concat.c,v 1.1.1.1 1999/04/30 18:08:34 doug Exp $
+ * $Id: concat.c,v 1.3 2006/01/02 03:17:42 bress Exp $
+ *
+ * This code is Copyright (c) 2002, by the authors of nmh.  See the
+ * COPYRIGHT file in the root directory of the nmh distribution for
+ * complete copyright information.
  */
 
 #include <h/mh.h>
+#include <h/utils.h>
 
 
 char *
@@ -22,8 +27,7 @@ concat (char *s1, ...)
 	len += strlen (cp);
     va_end(list);
 
-    if (!(dp = sp = malloc(len)))
-	adios (NULL, "unable to allocate string storage");
+    dp = sp = mh_xmalloc(len);
 
     sp = copy(s1, sp);
 
