@@ -2,7 +2,7 @@
 /*
  * context_del.c -- delete an entry from the context/profile list
  *
- * $Id: context_del.c,v 1.3 2002/11/18 18:25:02 jon Exp $
+ * $Id: context_del.c,v 1.4 2006/03/08 12:14:16 bress Exp $
  *
  * This code is Copyright (c) 2002, by the authors of nmh.  See the
  * COPYRIGHT file in the root directory of the nmh distribution for
@@ -22,7 +22,7 @@ context_del (char *key)
     register struct node *np, *pp;
 
     for (np = m_defs, pp = NULL; np; pp = np, np = np->n_next) {
-	if (!strcasecmp (np->n_name, key)) {
+	if (!mh_strcasecmp (np->n_name, key)) {
 	    if (!np->n_context)
 		admonish (NULL, "bug: context_del(key=\"%s\")", np->n_name);
 	    if (pp)
