@@ -2,7 +2,7 @@
 /*
  * context_find.c -- find an entry in the context/profile list
  *
- * $Id: context_find.c,v 1.3 2002/11/18 18:25:02 jon Exp $
+ * $Id: context_find.c,v 1.4 2006/03/08 12:14:16 bress Exp $
  *
  * This code is Copyright (c) 2002, by the authors of nmh.  See the
  * COPYRIGHT file in the root directory of the nmh distribution for
@@ -18,7 +18,7 @@ context_find (char *str)
     struct node *np;
 
     for (np = m_defs; np; np = np->n_next)
-	if (!strcasecmp (np->n_name, str))
+	if (!mh_strcasecmp (np->n_name, str))
 	    return (np->n_field);
 
     return NULL;
