@@ -1,7 +1,7 @@
 /*
  * context_read.c -- find and read profile and context files
  *
- * $Id: context_read.c,v 1.9 2005/12/14 01:48:24 bress Exp $
+ * $Id: context_read.c,v 1.10 2007/03/21 00:21:10 pm215 Exp $
  *
  * This code is Copyright (c) 2002, by the authors of nmh.  See the
  * COPYRIGHT file in the root directory of the nmh distribution for
@@ -113,7 +113,7 @@ context_read (void)
 	free (cp);
 
 	if (!makedir (nd))
-	    adios (NULL, "unable to create", nd);
+	    adios (NULL, "unable to create %s", nd);
     }
 
     else if ((st.st_mode & S_IFDIR) == 0)
