@@ -2,7 +2,11 @@
 /*
  * context_save.c -- write out the updated context file
  *
- * $Id: context_save.c,v 1.1.1.1 1999/04/30 18:08:34 doug Exp $
+ * $Id: context_save.c,v 1.4 2005/11/13 23:51:18 pm215 Exp $
+ *
+ * This code is Copyright (c) 2002, by the authors of nmh.  See the
+ * COPYRIGHT file in the root directory of the nmh distribution for
+ * complete copyright information.
  */
 
 #include <h/mh.h>
@@ -21,6 +25,10 @@ context_save (void)
     register struct node *np;
     FILE *out;
     sigset_t set, oset;
+    
+    /* No context in use -- silently ignore any changes! */
+    if (!ctxpath)
+       return;
 
     if (!(ctxflags & CTXMOD))
 	return;
@@ -37,12 +45,12 @@ context_save (void)
     sigaddset (&set, SIGTERM);
     SIGPROCMASK (SIG_BLOCK, &set, &oset);
 
-    if (!(out = fopen (ctxpath, "w")))
+    if (!(out = lkfopen (ctxpath, "w")))
 	adios (ctxpath, "unable to write");
     for (np = m_defs; np; np = np->n_next)
 	if (np->n_context)
 	    fprintf (out, "%s: %s\n", np->n_name, np->n_field);
-    fclose (out);
+    lkfclose (out, ctxpath);
 
     SIGPROCMASK (SIG_SETMASK, &oset, &set); /* reset the signal mask */
 
