@@ -2,7 +2,7 @@
 /*
  * done.c -- terminate the program
  *
- * $Id: done.c,v 1.3 2002/07/02 22:09:14 kenh Exp $
+ * $Id: done.c,v 1.5 2007/11/04 11:54:33 jjr Exp $
  *
  * This code is Copyright (c) 2002, by the authors of nmh.  See the
  * COPYRIGHT file in the root directory of the nmh distribution for
@@ -11,9 +11,4 @@
 
 #include <h/mh.h>
 
-int
-done (int status)
-{
-    exit (status);
-    return 1;  /* dead code to satisfy the compiler */
-}
+void (*done) (int) = exit;
