@@ -2,7 +2,11 @@
 /*
  * fdcompare.c -- are two files identical?
  *
- * $Id$
+ * $Id: fdcompare.c,v 1.2 2002/07/02 22:09:14 kenh Exp $
+ *
+ * This code is Copyright (c) 2002, by the authors of nmh.  See the
+ * COPYRIGHT file in the root directory of the nmh distribution for
+ * complete copyright information.
  */
 
 #include <h/mh.h>
@@ -32,7 +36,7 @@ fdcompare (int fd1, int fd2)
     resp = 0;
 
 leave: ;
-    lseek (fd1, (off_t) 0, 0);
-    lseek (fd2, (off_t) 0, 0);
+    lseek (fd1, (off_t) 0, SEEK_SET);
+    lseek (fd2, (off_t) 0, SEEK_SET);
     return resp;
 }
