@@ -2,7 +2,7 @@
 /*
  * fmt_compile.c -- "compile" format strings for fmt_scan
  *
- * $Id: fmt_compile.c,v 1.7 2005/05/18 12:50:45 opk Exp $
+ * $Id: fmt_compile.c,v 1.8 2007/04/13 11:53:08 jjr Exp $
  *
  * This code is Copyright (c) 2002, by the authors of nmh.  See the
  * COPYRIGHT file in the root directory of the nmh distribution for
@@ -183,7 +183,7 @@ static struct ftable functable[] = {
 #define PUTC(c)			NEW(FT_CHAR,0,0); fp->f_char = (c);
 
 static char *format_string;
-static char *usr_fstring;	/* for CERROR */
+static unsigned char *usr_fstring;	/* for CERROR */
 
 #define CERROR(str) compile_error (str, cp)
 
