@@ -2,10 +2,15 @@
 /*
  * fmt_new.c -- read format file/string and normalize
  *
- * $Id$
+ * $Id: fmt_new.c,v 1.3 2006/01/02 03:17:42 bress Exp $
+ *
+ * This code is Copyright (c) 2002, by the authors of nmh.  See the
+ * COPYRIGHT file in the root directory of the nmh distribution for
+ * complete copyright information.
  */
 
 #include <h/mh.h>
+#include <h/utils.h>
 
 #define QUOTE '\\'
 
@@ -37,8 +42,7 @@ new_fs (char *form, char *format, char *default_fs)
 	if (fstat (fileno (fp), &st) == -1)
 	    adios (form, "unable to stat format file");
 
-	if (!(formats = malloc ((size_t) st.st_size + 1)))
-	    adios (form, "unable to allocate space for format");
+	formats = mh_xmalloc ((size_t) st.st_size + 1);
 
 	if (read (fileno(fp), formats, (int) st.st_size) != st.st_size)
 	    adios (form, "error reading format file");
@@ -50,7 +54,7 @@ new_fs (char *form, char *format, char *default_fs)
 	formats = getcpy (format ? format : default_fs);
     }
 
-    normalize (formats);
+    normalize (formats);	/* expand escapes */
 
     return formats;
 }
