@@ -2,7 +2,7 @@
 /*
  * fmt_scan.c -- format string interpretation
  *
- * $Id: fmt_scan.c,v 1.16 2005/11/06 21:54:40 pm215 Exp $
+ * $Id: fmt_scan.c,v 1.25 2008/04/05 18:41:37 pm215 Exp $
  *
  * This code is Copyright (c) 2002, by the authors of nmh.  See the
  * COPYRIGHT file in the root directory of the nmh distribution for
@@ -25,6 +25,10 @@
 #  include <time.h>
 # endif
 #endif
+#ifdef MULTIBYTE_SUPPORT
+#  include <wctype.h>
+#  include <wchar.h>
+#endif
 
 #define	NFMTS MAXARGS
 
@@ -86,130 +90,159 @@ match (char *str, char *sub)
 }
 
 /*
- * macros to format data
+ * copy a number to the destination subject to a maximum width
  */
-#define PUTDF(cp, num, wid, fill)\
-	if (cp + wid < ep) {\
-	    if ((i = (num)) < 0)\
-		i = -(num);\
-	    if ((c = (wid)) < 0)\
-		c = -c;\
-	    sp = cp + c;\
-	    do {\
-		*--sp = (i % 10) + '0';\
-		i /= 10;\
-	    } while (i > 0 && sp > cp);\
-	    if (i > 0)\
-		*sp = '?';\
-	    else if ((num) < 0 && sp > cp)\
-		*--sp = '-';\
-	    while (sp > cp)\
-		*--sp = fill;\
-	    cp += c;\
+static void
+cpnumber(char **dest, int num, unsigned int wid, char fill, size_t n) {
+    int i, c;
+    char *sp;
+    char *cp = *dest;
+    char *ep = cp + n;
+
+    if (cp + wid < ep) {
+	if ((i = (num)) < 0)
+	    i = -(num);
+	if ((c = (wid)) < 0)
+	    c = -c;
+	sp = cp + c;
+	do {
+	    *--sp = (i % 10) + '0';
+	    i /= 10;
+	} while (i > 0 && sp > cp);
+	if (i > 0)
+	    *sp = '?';
+	else if ((num) < 0 && sp > cp)
+	    *--sp = '-';
+	while (sp > cp)
+	    *--sp = fill;
+	cp += c;
+    }
+    *dest = cp;
+}
+
+/*
+ * copy string from str to dest padding with the fill character to a size
+ * of wid characters. if wid is negative, the string is right aligned
+ * no more than n bytes are copied
+ */
+static void
+cptrimmed(char **dest, char *str, unsigned int wid, char fill, size_t n) {
+    int remaining;     /* remaining output width available */
+    int c, ljust, w;
+    int end;           /* number of input bytes remaining in str */
+#ifdef MULTIBYTE_SUPPORT
+    int char_len;      /* bytes in current character */
+    wchar_t wide_char;
+#endif
+    char *sp;          /* current position in source string */
+    char *cp = *dest;  /* current position in destination string */
+    char *ep = cp + n; /* end of destination buffer */
+    int prevCtrl = 1;
+
+    /* get alignment */
+    ljust = 0;
+    if ((remaining = (wid)) < 0) {
+	remaining = -remaining;
+	ljust++;
+    }
+    if ((sp = (str))) {
+	mbtowc(NULL, NULL, 0); /* reset shift state */
+	end = strlen(str);
+	while (*sp && remaining > 0 && end > 0) {
+#ifdef MULTIBYTE_SUPPORT
+	    char_len = mbtowc(&wide_char, sp, end);
+	    if (char_len <= 0 || (cp + char_len > ep))
+		break;
+
+	    end -= char_len;
+
+	    if (iswcntrl(wide_char) || iswspace(wide_char)) {
+		sp += char_len;
+#else
+	    end--;
+	    if (iscntrl(*sp) || isspace(*sp)) {
+		sp++;
+#endif
+		if (!prevCtrl) {
+		    *cp++ = ' ';
+		    remaining--;
+		}
+
+		prevCtrl = 1;
+		continue;
 	    }
+	    prevCtrl = 0;
 
+#ifdef MULTIBYTE_SUPPORT
+	    w = wcwidth(wide_char);
+	    if (w >= 0 && remaining >= w) {
+		strncpy(cp, sp, char_len);
+		cp += char_len;
+		remaining -= w;
+	    }
+	    sp += char_len;
+#else
+	    *cp++ = *sp++;
+	    remaining--;
+#endif
+	}
+    }
+
+    if (ljust) {
+	if (cp + remaining > ep)
+	    remaining = ep - cp;
+	ep = cp + remaining;
+	if (remaining > 0) {
+	    /* copy string to the right */
+	    while (--cp >= *dest)
+		*(cp + remaining) = *cp;
+	    /* add padding at the beginning */
+	    cp += remaining;
+	    for (c=remaining; c>0; c--)
+		*cp-- = fill;
+	}
+	*dest = ep;
+    } else {
+	/* pad remaining space */
+	while (remaining-- > 0 && cp < ep)
+		*cp++ = fill;
+	*dest = cp;
+    }
+}
+
+static void
+cpstripped (char **start, char *end, char *str)
+{
+    int c;
+    char *s = str;
+
+    if (!s)
+	return;
+
+    /* skip any initial control characters or spaces */
+    while ((c = (unsigned char) *s) &&
 #ifdef LOCALE
-#define PUTSF(cp, str, wid, fill) {\
-		ljust = 0;\
-		if ((i = (wid)) < 0) {\
-			i = -i;\
-			ljust++;\
-		}\
-		if ((sp = (str))) {\
-			if (ljust) {\
-				c = strlen(sp);\
-				if (c > i)\
-					sp += c - i;\
-				else {\
-					while( --i >= c && cp < ep)\
-						*cp++ = fill;\
-					i++;\
-				}\
-			} else {\
-			    while ((c = (unsigned char) *sp) && (iscntrl(c) || isspace(c)))\
-				sp++;\
-			}\
-			while ((c = (unsigned char) *sp++) && --i >= 0 && cp < ep)\
-				if (!iscntrl(c) && !isspace(c)) \
-				    *cp++ = c;\
-				else {\
-					while ((c = (unsigned char) *sp) && (iscntrl(c) || isspace(c)))\
-						sp++;\
-					    *cp++ = ' ';\
-				}\
-		}\
-		if (!ljust)\
-		while( --i >= 0 && cp < ep)\
-		    *cp++ = fill;\
+	    (iscntrl(c) || isspace(c)))
+#else
+	    (c <= 32))
+#endif
+	s++;
+
+    /* compact repeated control characters and spaces into a single space */
+    while((c = (unsigned char) *s++) && *start < end)
+	if (!iscntrl(c) && !isspace(c))
+	    *(*start)++ = c;
+	else {
+	    while ((c = (unsigned char) *s) &&
+#ifdef LOCALE
+		    (iscntrl(c) || isspace(c)))
+#else
+		    (c <= 32))
+#endif
+		s++;
+	    *(*start)++ = ' ';
 	}
-
-#define PUTS(cp, str) {\
-		if ((sp = (str))) {\
-		    while ((c = (unsigned char) *sp) && (iscntrl(c) || isspace(c)))\
-			sp++;\
-		    while((c = (unsigned char) *sp++) && cp < ep)\
-		        if (!iscntrl(c) && !isspace(c)) \
-			    *cp++ = c;\
-			else {\
-			    while ((c = (unsigned char) *sp) && (iscntrl(c) || isspace(c)))\
-				sp++;\
-			    *cp++ = ' ';\
-			}\
-		}\
-	}
-
-#else /* LOCALE */
-#define PUTSF(cp, str, wid, fill) {\
-		ljust = 0;\
-		if ((i = (wid)) < 0) {\
-			i = -i;\
-			ljust++;\
-		}\
-		if (sp = (str)) {\
-			if (ljust) {\
-				c = strlen(sp);\
-				if (c > i)\
-					sp += c - i;\
-				else {\
-					while( --i >= c && cp < ep)\
-						*cp++ = fill;\
-					i++;\
-				}\
-			} else {\
-		    while ((c = *sp) && c <= 32)\
-			sp++;\
-			}\
-			while ((c = *sp++) && --i >= 0 && cp < ep)\
-				if (c > 32) \
-			    *cp++ = c;\
-			else {\
-					while ((c = *sp) && c <= 32)\
-				sp++;\
-			    *cp++ = ' ';\
-			}\
-		}\
-		if (!ljust)\
-		while( --i >= 0 && cp < ep)\
-		    *cp++ = fill;\
-		}
-
-#define PUTS(cp, str) {\
-		if (sp = (str)) {\
-		    while ((c = *sp) && c <= 32)\
-			sp++;\
-		    while( (c = *sp++) && cp < ep)\
-			if ( c > 32 ) \
-			    *cp++ = c;\
-			else {\
-			    while ( (c = *sp) && c <= 32 )\
-				sp++;\
-			    *cp++ = ' ';\
-			}\
-		}\
-		}
-
-#endif /* LOCALE */
-
+}
 
 static char *lmonth[] = { "January",  "February","March",   "April",
 			  "May",      "June",    "July",    "August",
@@ -255,15 +288,17 @@ get_x400_comp (char *mbox, char *key, char *buffer, int buffer_len)
 	    || !(cp = strchr(mbox += idx + strlen (key), '/')))
 	return 0;
 
-    snprintf (buffer, buffer_len, "%*.*s", cp - mbox, cp - mbox, mbox);
+    snprintf (buffer, buffer_len, "%*.*s", (int)(cp - mbox), (int)(cp - mbox), mbox);
     return 1;
 }
 
 struct format *
 fmt_scan (struct format *format, char *scanl, int width, int *dat)
 {
-    char *cp, *ep, *sp;
-    char *savestr, *str = NULL;
+    char *cp, *ep;
+    unsigned char *sp;
+    char *savestr;
+    unsigned char *str = NULL;
     char buffer[BUFSIZ], buffer2[BUFSIZ];
     int i, c, ljust, n;
     int value = 0;
@@ -290,10 +325,10 @@ fmt_scan (struct format *format, char *scanl, int width, int *dat)
 	switch (fmt->f_type) {
 
 	case FT_COMP:
-	    PUTS (cp, fmt->f_comp->c_text);
+	    cpstripped (&cp, ep, fmt->f_comp->c_text);
 	    break;
 	case FT_COMPF:
-	    PUTSF (cp, fmt->f_comp->c_text, fmt->f_width, fmt->f_fill);
+	    cptrimmed (&cp, fmt->f_comp->c_text, fmt->f_width, fmt->f_fill, ep - cp);
 	    break;
 
 	case FT_LIT:
@@ -316,20 +351,25 @@ fmt_scan (struct format *format, char *scanl, int width, int *dat)
 	    break;
 
 	case FT_STR:
-	    PUTS (cp, str);
+	    cpstripped (&cp, ep, str);
 	    break;
 	case FT_STRF:
-	    PUTSF (cp, str, fmt->f_width, fmt->f_fill);
+	    cptrimmed (&cp, str, fmt->f_width, fmt->f_fill, ep - cp);
 	    break;
 	case FT_STRFW:
 	    adios (NULL, "internal error (FT_STRFW)");
 
 	case FT_NUM:
-	    n = snprintf(cp, ep - cp, "%d", value);
-	    if (n >= 0) cp += n;
+	    n = snprintf(cp, ep - cp + 1, "%d", value);
+	    if (n >= 0) {
+		if (n >= ep - cp) {
+		    cp = ep;
+		} else
+		    cp += n;
+	    }
 	    break;
 	case FT_NUMF:
-	    PUTDF (cp, value, fmt->f_width, fmt->f_fill);
+	    cpnumber (&cp, value, fmt->f_width, fmt->f_fill, ep - cp);
 	    break;
 
 	case FT_CHAR:
@@ -455,7 +495,7 @@ fmt_scan (struct format *format, char *scanl, int width, int *dat)
 
 	case FT_LS_TRIM:
 	    if (str) {
-		    char *xp;
+		    unsigned char *xp;
 
 		    strncpy(buffer, str, sizeof(buffer));
 		    buffer[sizeof(buffer)-1] = '\0';
@@ -684,7 +724,7 @@ fmt_scan (struct format *format, char *scanl, int width, int *dat)
 		  }
 		}
 	    }
-	    break;  
+	    break;
 
 
 		/* UNQUOTEs RFC-2822 quoted-string and quoted-pair */
@@ -704,7 +744,7 @@ fmt_scan (struct format *format, char *scanl, int width, int *dat)
 		    switch ( str[n] ) {
 			case '\\':
 			    n++;
-			    if ( str[n] != '\0') 
+			    if ( str[n] != '\0')
 				buffer2[m++] = str[n++];
 			    break;
 			case '"':
@@ -713,7 +753,7 @@ fmt_scan (struct format *format, char *scanl, int width, int *dat)
 			default:
 			    buffer2[m++] = str[n++];
 			    break;
-			}		 
+			}
 		}
 		buffer2[m] = '\0';
 		str = buffer2;
@@ -763,7 +803,8 @@ fmt_scan (struct format *format, char *scanl, int width, int *dat)
 	     * (e.g., "To: ")
 	     */
 	    {
-	    char *lp, *lastb;
+	    unsigned char *lp;
+	    char *lastb;
 	    int indent, wid, len;
 
 	    lp = str;
@@ -804,7 +845,7 @@ fmt_scan (struct format *format, char *scanl, int width, int *dat)
 			*cp++ = ' ';
 		}
 	    }
-	    PUTS (cp, lp);
+	    cpstripped (&cp, ep, lp);
 	    }
 	    break;
 
@@ -826,7 +867,7 @@ fmt_scan (struct format *format, char *scanl, int width, int *dat)
 		comp->c_mn = &fmt_mnull;
 	    }
 	    break;
-	    
+
 	case FT_MYMBOX:
 	    /*
 	     * if there's no component, we say true.  Otherwise we
@@ -884,7 +925,7 @@ fmt_scan (struct format *format, char *scanl, int width, int *dat)
     while (fmt->f_type != FT_DONE)
 	fmt++;
 
-    finished:;    
+    finished:;
     *cp = '\0';
     return (fmt->f_value ? ++fmt : (struct format *) 0);
 
