@@ -2,7 +2,7 @@
 /*
  * folder_addmsg.c -- Link message into folder
  *
- * $Id: folder_addmsg.c,v 1.7 2004/11/19 05:06:16 jon Exp $
+ * $Id: folder_addmsg.c,v 1.8 2007/03/21 00:21:10 pm215 Exp $
  *
  * This code is Copyright (c) 2002, by the authors of nmh.  See the
  * COPYRIGHT file in the root directory of the nmh distribution for
@@ -180,11 +180,11 @@ folder_addmsg (struct msgs **mpp, char *msgfile, int selected,
 	     */
 	    if (linkerr == EXDEV) {
 		if (stat (newmsg, &st1) == 0) {
-		    advise (NULL, "message %s:%s already exists", newmsg);
+		    advise (NULL, "message %s:%s already exists", mp->foldpath, newmsg);
 		    return -1;
 		} else {
 		    if ((infd = open (msgfile, O_RDONLY)) == -1) {
-			advise (msgfile, "unable to open message %s");
+			advise (msgfile, "unable to open message %s", msgfile);
 			return -1;
 		    }
 		    fstat (infd, &st1);
