@@ -2,7 +2,7 @@
 /*
  * folder_read.c -- initialize folder structure and read folder
  *
- * $Id: folder_read.c,v 1.4 2005/05/18 12:57:40 opk Exp $
+ * $Id: folder_read.c,v 1.6 2006/01/02 03:25:18 bress Exp $
  *
  * This code is Copyright (c) 2002, by the authors of nmh.  See the
  * COPYRIGHT file in the root directory of the nmh distribution for
@@ -10,6 +10,7 @@
  */
 
 #include <h/mh.h>
+#include <h/utils.h>
 
 /* We allocate the `mi' array 1024 elements at a time */
 #define	NUMMSGS  1024
@@ -44,8 +45,7 @@ folder_read (char *name)
     }
 
     /* Allocate the main structure for folder information */
-    if (!(mp = (struct msgs *) malloc ((size_t) sizeof(*mp))))
-	adios (NULL, "unable to allocate folder storage");
+    mp = (struct msgs *) mh_xmalloc ((size_t) sizeof(*mp));
 
     clear_folder_flags (mp);
     mp->foldpath = name;
@@ -66,8 +66,7 @@ folder_read (char *name)
      * name of the messages in this folder.
      */
     len = NUMMSGS;
-    if (!(mi = (int *) malloc ((size_t) (len * sizeof(*mi)))))
-	adios (NULL, "unable to allocate storage");
+    mi = (int *) mh_xmalloc ((size_t) (len * sizeof(*mi)));
 
     while ((dp = readdir (dd))) {
 	if ((msgnum = m_atoi (dp->d_name)) && msgnum > 0) {
@@ -77,10 +76,7 @@ folder_read (char *name)
 	     */
 	    if (mp->nummsg >= len) {
 		len += NUMMSGS;
-		if (!(mi = (int *) realloc (mi,
-			(size_t) (len * sizeof(*mi))))) {
-		    adios (NULL, "unable to allocate storage");
-		}
+		mi = (int *) mh_xrealloc (mi, (size_t) (len * sizeof(*mi)));
 	    }
 
 	    /* Check if this is the first message we've seen */
@@ -138,8 +134,7 @@ folder_read (char *name)
     /*
      * Allocate space for status of each message.
      */
-    if (!(mp->msgstats = malloc (MSGSTATSIZE(mp, mp->lowoff, mp->hghoff))))
-	adios (NULL, "unable to allocate storage for msgstats");
+    mp->msgstats = mh_xmalloc (MSGSTATSIZE(mp, mp->lowoff, mp->hghoff));
 
     /*
      * Clear all the flag bits for all the message
