@@ -2,10 +2,15 @@
 /*
  * folder_realloc.c -- realloc a folder/msgs structure
  *
- * $Id$
+ * $Id: folder_realloc.c,v 1.4 2006/01/02 03:25:18 bress Exp $
+ *
+ * This code is Copyright (c) 2002, by the authors of nmh.  See the
+ * COPYRIGHT file in the root directory of the nmh distribution for
+ * complete copyright information.
  */
 
 #include <h/mh.h>
+#include <h/utils.h>
 
 /*
  * Reallocate some of the space in the folder
@@ -25,16 +30,25 @@ folder_realloc (struct msgs *mp, int lo, int hi)
 	adios (NULL, "BUG: called folder_realloc with lo (%d) < 1", lo);
     if (hi < 1)
 	adios (NULL, "BUG: called folder_realloc with hi (%d) < 1", hi);
-    if (mp->lowmsg > 0 && lo > mp->lowmsg)
-	adios (NULL, "BUG: called folder_realloc with lo (%d) > mp->lowmsg (%d)", lo, mp->lowmsg);
-    if (mp->hghmsg > 0 && hi < mp->hghmsg)
-	adios (NULL, "BUG: called folder_realloc with hi (%d) < mp->hghmsg (%d)", hi, mp->hghmsg);
+    if (mp->nummsg > 0 && lo > mp->lowmsg)
+	adios (NULL, "BUG: called folder_realloc with lo (%d) > mp->lowmsg (%d)",
+	       lo, mp->lowmsg);
+    if (mp->nummsg > 0 && hi < mp->hghmsg)
+	adios (NULL, "BUG: called folder_realloc with hi (%d) < mp->hghmsg (%d)",
+	       hi, mp->hghmsg);
 
     /* Check if we really need to reallocate anything */
     if (lo == mp->lowoff && hi == mp->hghoff)
 	return mp;
 
-    if (lo != mp->lowoff) {
+    if (lo == mp->lowoff) {
+	/*
+	 * We are just extending (or shrinking) the end of message
+	 * status array.  So we don't have to move anything and can
+	 * just realloc the message status array.
+	 */
+	mp->msgstats = mh_xrealloc (mp->msgstats, MSGSTATSIZE(mp, lo, hi));
+    } else {
 	/*
 	 * We are changing the offset of the message status
 	 * array.  So we will need to shift everything.
@@ -42,26 +56,15 @@ folder_realloc (struct msgs *mp, int lo, int hi)
 	seqset_t *tmpstats;
 
 	/* first allocate the new message status space */
-	if (!(tmpstats = malloc MSGSTATSIZE(mp, lo, hi))) {
-	    advise (NULL, "unable to reallocate message storage");
-	    return NULL;
-	}
+	tmpstats = mh_xmalloc (MSGSTATSIZE(mp, lo, hi));
 
 	/* then copy messages status array with shift */
-	for (msgnum = mp->lowmsg; msgnum <= mp->hghmsg; msgnum++)
-	    tmpstats[msgnum - lo] = mp->msgstats[msgnum - mp->lowoff];
+	if (mp->nummsg > 0) {
+	    for (msgnum = mp->lowmsg; msgnum <= mp->hghmsg; msgnum++)
+		tmpstats[msgnum - lo] = mp->msgstats[msgnum - mp->lowoff];
+	}
 	free(mp->msgstats);
 	mp->msgstats = tmpstats;
-    } else {
-	/*
-	 * We are just extending (or shrinking) the end of message
-	 * status array.  So we don't have to move anything and can
-	 * just realloc the message status array.
-	 */
-	if (!(mp->msgstats = realloc(mp->msgstats, MSGSTATSIZE(mp, lo, hi)))) {
-	    advise (NULL, "unable to reallocate message storage");
-	    return NULL;
-	}
     }
 
     mp->lowoff = lo;
@@ -71,10 +74,16 @@ folder_realloc (struct msgs *mp, int lo, int hi)
      * Clear all the flags for entries outside
      * the current message range for this folder.
      */
-    for (msgnum = mp->lowoff; msgnum < mp->lowmsg; msgnum++)
-	clear_msg_flags (mp, msgnum);
-    for (msgnum = mp->hghmsg + 1; msgnum <= mp->hghoff; msgnum++)
-	clear_msg_flags (mp, msgnum);
+    if (mp->nummsg > 0) {
+	for (msgnum = mp->lowoff; msgnum < mp->lowmsg; msgnum++)
+	    clear_msg_flags (mp, msgnum);
+	for (msgnum = mp->hghmsg + 1; msgnum <= mp->hghoff; msgnum++)
+	    clear_msg_flags (mp, msgnum);
+    } else {
+	/* no messages, so clear entire range */
+	for (msgnum = mp->lowoff; msgnum <= mp->hghoff; msgnum++)
+	    clear_msg_flags (mp, msgnum);
+    }
 
     return mp;
 }
