@@ -2,7 +2,7 @@
 /*
  * getans.c -- get an answer from the user and return a string array
  *
- * $Id: getans.c,v 1.2 2002/07/02 22:09:14 kenh Exp $
+ * $Id: getans.c,v 1.3 2007/04/29 22:34:04 pm215 Exp $
  *
  * This code is Copyright (c) 2002, by the authors of nmh.  See the
  * COPYRIGHT file in the root directory of the nmh distribution for
@@ -27,7 +27,7 @@ char **
 getans (char *prompt, struct swit *ansp)
 {
     int i;
-    SIGNAL_HANDLER istat;
+    SIGNAL_HANDLER istat = NULL;
     char *cp, **cpp;
 
     if (!(setjmp (sigenv))) {
