@@ -2,7 +2,7 @@
 /*
  * getarguments.c -- Get the argument vector ready to go.
  *
- * $Id: getarguments.c,v 1.2 2002/07/02 22:09:14 kenh Exp $
+ * $Id: getarguments.c,v 1.3 2006/01/02 03:17:42 bress Exp $
  *
  * This code is Copyright (c) 2002, by the authors of nmh.  See the
  * COPYRIGHT file in the root directory of the nmh distribution for
@@ -10,6 +10,7 @@
  */
 
 #include <h/mh.h>
+#include <h/utils.h>
 
 char **
 getarguments (char *invo_name, int argc, char **argv, int check_context)
@@ -30,8 +31,7 @@ getarguments (char *invo_name, int argc, char **argv, int check_context)
 	    n++;
     }
 
-    if (!(arguments = (char **) malloc ((argc + n) * sizeof(*arguments))))
-	adios (NULL, "unable to malloc argument storage");
+    arguments = (char **) mh_xmalloc ((argc + n) * sizeof(*arguments));
     bp = arguments;
 
     /* Copy any arguments from profile/context */
