@@ -6,10 +6,15 @@
  * OF GETCPY WITH STRDUP.  BUT THIS WILL REQUIRE
  * CHANGING PARTS OF THE CODE TO DEAL WITH NULL VALUES.
  *
- * $Id$
+ * $Id: getcpy.c,v 1.3 2006/01/02 03:17:42 bress Exp $
+ *
+ * This code is Copyright (c) 2002, by the authors of nmh.  See the
+ * COPYRIGHT file in the root directory of the nmh distribution for
+ * complete copyright information.
  */
 
 #include <h/mh.h>
+#include <h/utils.h>
 
 
 char *
@@ -20,12 +25,10 @@ getcpy (char *str)
 
     if (str) {
 	len = strlen(str) + 1;
-	if (!(cp = malloc (len)))
-	    adios (NULL, "unable to allocate string storage");
+	cp = mh_xmalloc (len);
 	memcpy (cp, str, len);
     } else {
-	if (!(cp = malloc ((size_t) 1)))
-	    adios (NULL, "unable to allocate string storage");
+	cp = mh_xmalloc ((size_t) 1);
 	*cp = '\0';
     }
     return cp;
