@@ -2,7 +2,7 @@
 /*
  * lock.c -- routines to lock/unlock files
  *
- * $Id: lock_file.c,v 1.11 2004/10/12 20:40:25 jon Exp $
+ * $Id: lock_file.c,v 1.15 2008/04/05 18:41:37 pm215 Exp $
  *
  * This code is Copyright (c) 2002, by the authors of nmh.  See the
  * COPYRIGHT file in the root directory of the nmh distribution for
@@ -19,6 +19,7 @@
  
 #include <h/mh.h>
 #include <h/signals.h>
+#include <h/utils.h>
 
 #ifdef TIME_WITH_SYS_TIME
 # include <sys/time.h>
@@ -35,11 +36,6 @@
 # include <errno.h>
 #endif
 
-#ifdef MMDFONLY
-# include <mmdfonly.h>
-# include <lockonly.h>
-#endif /* MMDFONLY */
-
 #ifdef HAVE_FCNTL_H
 # include <fcntl.h>
 #else
@@ -109,13 +105,15 @@ static int lkopen_kernel (char *, int, mode_t);
 
 #ifdef DOT_LOCKING
 static int lkopen_dot (char *, int, mode_t);
-static int lockit (struct lockinfo *);
 static void lockname (char *, struct lockinfo *, int);
 static void timerON (char *, int);
 static void timerOFF (int);
 static RETSIGTYPE alrmser (int);
 #endif
 
+#if !defined(HAVE_LIBLOCKFILE)
+static int lockit (struct lockinfo *);
+#endif
 
 /*
  * Base routine to open and lock a file,
@@ -360,10 +358,8 @@ lkopen_kernel (char *file, int access, mode_t mode)
 static int
 lkopen_dot (char *file, int access, mode_t mode)
 {
-    int i, fd;
-    time_t curtime;
+    int fd;
     struct lockinfo lkinfo;
-    struct stat st;
 
     /* open the file */
     if ((fd = open (file, access, mode)) == -1)
@@ -376,32 +372,37 @@ lkopen_dot (char *file, int access, mode_t mode)
     lockname (file, &lkinfo, 1);
 
 #if !defined(HAVE_LIBLOCKFILE)
-    for (i = 0;;) {
-	/* attempt to create lock file */
-	if (lockit (&lkinfo) == 0) {
-	    /* if successful, turn on timer and return */
-	    timerON (lkinfo.curlock, fd);
-	    return fd;
-	} else {
-	    /*
-	     * Abort locking, if we fail to lock after 5 attempts
-	     * and are never able to stat the lock file.
-	     */
-	    if (stat (lkinfo.curlock, &st) == -1) {
-		if (i++ > 5)
-		    return -1;
-		sleep (5);
+    {
+	int i;
+	for (i = 0;;) {
+	    /* attempt to create lock file */
+	    if (lockit (&lkinfo) == 0) {
+		/* if successful, turn on timer and return */
+		timerON (lkinfo.curlock, fd);
+		return fd;
 	    } else {
-		i = 0;
-		time (&curtime);
-
-		/* check for stale lockfile, else sleep */
-		if (curtime > st.st_ctime + RSECS)
-		    unlink (lkinfo.curlock);
-		else
+		/*
+		 * Abort locking, if we fail to lock after 5 attempts
+		 * and are never able to stat the lock file.
+		 */
+		struct stat st;
+		if (stat (lkinfo.curlock, &st) == -1) {
+		    if (i++ > 5)
+			return -1;
 		    sleep (5);
+		} else {
+		    time_t curtime;
+		    i = 0;
+		    time (&curtime);
+		    
+		    /* check for stale lockfile, else sleep */
+		    if (curtime > st.st_ctime + RSECS)
+			unlink (lkinfo.curlock);
+		    else
+			sleep (5);
+		}
+		lockname (file, &lkinfo, 1);
 	    }
-	    lockname (file, &lkinfo, 1);
 	}
     }
 #else
@@ -493,7 +494,7 @@ lockname (char *file, struct lockinfo *li, int isnewlock)
     bplen += tmplen;
 #else
     if (cp != file) {
-	snprintf (bp, sizeof(li->curlock), "%.*s", cp - file, file);
+	snprintf (bp, sizeof(li->curlock), "%.*s", (int)(cp - file), file);
 	tmplen = strlen (bp);
 	bp    += tmplen;
 	bplen += tmplen;
@@ -525,7 +526,7 @@ lockname (char *file, struct lockinfo *li, int isnewlock)
 	    strncpy (li->tmplock, ",LCK.XXXXXX", sizeof(li->tmplock));
 	else
 	    snprintf (li->tmplock, sizeof(li->tmplock), "%.*s,LCK.XXXXXX",
-		     cp - li->curlock, li->curlock);
+		     (int)(cp - li->curlock), li->curlock);
     }
 #endif
 }
@@ -542,15 +543,11 @@ timerON (char *curlock, int fd)
     struct lock *lp;
     size_t len;
 
-    if (!(lp = (struct lock *) malloc (sizeof(*lp))))
-	return;
+    lp = (struct lock *) mh_xmalloc (sizeof(*lp));
 
     len = strlen(curlock) + 1;
     lp->l_fd = fd;
-    if (!(lp->l_lock = malloc (len))) {
-	free ((char *) lp);
-	return;
-    }
+    lp->l_lock = mh_xmalloc (len);
     memcpy (lp->l_lock, curlock, len);
     lp->l_next = l_top;
 
@@ -606,7 +603,6 @@ timerOFF (int fd)
 static RETSIGTYPE
 alrmser (int sig)
 {
-    int j;
     char *lockfile;
     struct lock *lp;
 
@@ -618,8 +614,11 @@ alrmser (int sig)
     for (lp = l_top; lp; lp = lp->l_next) {
 	lockfile = lp->l_lock;
 #if !defined(HAVE_LIBLOCKFILE)
-	if (*lockfile && (j = creat (lockfile, 0600)) != -1)
-	    close (j);
+	{
+	    int j;
+	    if (*lockfile && (j = creat (lockfile, 0600)) != -1)
+		close (j);
+	}
 #else
     lockfile_touch(lockfile);
 #endif
