@@ -4,7 +4,11 @@
  *          -- return the numeric value of the message.  If the string
  *          -- contains any non-digit characters, then return 0.
  *
- * $Id: m_atoi.c,v 1.1.1.1 1999/04/30 18:08:34 doug Exp $
+ * $Id: m_atoi.c,v 1.3 2007/04/13 11:53:08 jjr Exp $
+ *
+ * This code is Copyright (c) 2002, by the authors of nmh.  See the
+ * COPYRIGHT file in the root directory of the nmh distribution for
+ * complete copyright information.
  */
 
 #include <h/mh.h>
@@ -14,7 +18,7 @@ int
 m_atoi (char *str)
 {
     int i;
-    char *cp;
+    unsigned char *cp;
 
     for (i = 0, cp = str; *cp; cp++) {
 #ifdef LOCALE
