@@ -2,7 +2,11 @@
 /*
  * m_backup.c -- construct a backup file
  *
- * $Id: m_backup.c,v 1.1.1.1 1999/04/30 18:08:34 doug Exp $
+ * $Id: m_backup.c,v 1.3 2008/04/05 18:41:37 pm215 Exp $
+ *
+ * This code is Copyright (c) 2002, by the authors of nmh.  See the
+ * COPYRIGHT file in the root directory of the nmh distribution for
+ * complete copyright information.
  */
 
 #include <h/mh.h>
@@ -18,7 +22,7 @@ m_backup (char *file)
 	snprintf(buffer, sizeof(buffer), "%s%s",
 		BACKUP_PREFIX, cp);
     else
-	snprintf(buffer, sizeof(buffer), "%.*s%s%s", cp - file, file,
+	snprintf(buffer, sizeof(buffer), "%.*s%s%s", (int)(cp - file), file,
 		BACKUP_PREFIX, cp);
 
     unlink(buffer);
