@@ -2,7 +2,7 @@
 /*
  * m_scratch.c -- construct a scratch file
  *
- * $Id: m_scratch.c,v 1.5 2002/07/02 22:09:14 kenh Exp $
+ * $Id: m_scratch.c,v 1.6 2008/04/05 18:41:37 pm215 Exp $
  *
  * This code is Copyright (c) 2002, by the authors of nmh.  See the
  * COPYRIGHT file in the root directory of the nmh distribution for
@@ -33,7 +33,7 @@ m_scratch (char *file, char *template)
     if ((cp = r1bindex (file, '/')) == file)
 	strncpy (buffer, tmpfil, sizeof(buffer));
     else
-	snprintf (buffer, sizeof(buffer), "%.*s%s", cp - file, file, tmpfil);
+	snprintf (buffer, sizeof(buffer), "%.*s%s", (int)(cp - file), file, tmpfil);
     unlink (buffer);
 
     return buffer;
