@@ -2,7 +2,7 @@
 /*
  * mts.c -- definitions for the mail transport system
  *
- * $Id: mts.c,v 1.3 2003/09/30 16:58:43 gbburkhardt Exp $
+ * $Id: mts.c,v 1.5 2007/04/13 11:53:08 jjr Exp $
  *
  * This code is Copyright (c) 2002, by the authors of nmh.  See the
  * COPYRIGHT file in the root directory of the nmh distribution for
@@ -11,6 +11,7 @@
 
 #include <h/mh.h>   /* for snprintf() */
 #include <h/nmh.h>
+#include <h/utils.h>
 
 #define nmhetcdir(file) NMHETCDIR#file
 
@@ -30,7 +31,7 @@
 /*
  * static prototypes
  */
-static char *tailor_value (char *);
+static char *tailor_value (unsigned char *);
 static void getuserinfo (void);
 
 /*
@@ -171,7 +172,8 @@ static struct bind binds[] = {
 void
 mts_init (char *name)
 {
-    char *bp, *cp, buffer[BUFSIZ];
+    unsigned char *bp;
+    char *cp, buffer[BUFSIZ];
     struct bind *b;
     FILE *fp;
     static int inited = 0;
@@ -232,7 +234,7 @@ mts_init (char *name)
  */
 
 static char *
-tailor_value (char *s)
+tailor_value (unsigned char *s)
 {
     int i, r;
     char *bp;
@@ -271,8 +273,8 @@ tailor_value (char *s)
     *bp = 0;
 
     len = strlen (buffer) + 1;
-    if ((bp = malloc (len)))
-	memcpy (bp, buffer, len);
+    bp = mh_xmalloc (len);
+    memcpy (bp, buffer, len);
 
     return bp;
 }
@@ -405,7 +407,8 @@ getfullname (void)
 static void
 getuserinfo (void)
 {
-    register char *cp, *np;
+    register unsigned char *cp;
+    register char *np;
     register struct passwd *pw;
 
 #ifdef KPOP
