@@ -2,7 +2,7 @@
 /*
  * pidwait.c -- wait for child to exit
  *
- * $Id: pidwait.c,v 1.5 2002/11/20 19:57:19 jon Exp $
+ * $Id: pidwait.c,v 1.6 2008/04/11 14:12:55 opk Exp $
  *
  * This code is Copyright (c) 2002, by the authors of nmh.  See the
  * COPYRIGHT file in the root directory of the nmh distribution for
@@ -24,10 +24,10 @@ pidwait (pid_t id, int sigsok)
     pid_t pid;
     SIGNAL_HANDLER istat, qstat;
 
-#ifdef WAITINT
-    int status;
-#else
+#ifdef HAVE_UNION_WAIT
     union wait status;
+#else
+    int status;
 #endif
 
     if (sigsok == -1) {
@@ -50,9 +50,9 @@ pidwait (pid_t id, int sigsok)
 	SIGNAL (SIGQUIT, qstat);
     }
 
-#ifdef WAITINT
-    return (pid == -1 ? -1 : status);
-#else
+#ifdef HAVE_UNION_WAIT
     return (pid == -1 ? -1 : status.w_status);
+#else
+    return (pid == -1 ? -1 : status);
 #endif
 }
