@@ -3,7 +3,7 @@
  * readconfig.c -- base routine to read nmh configuration files
  *              -- such as nmh profile, context file, or mhn.defaults.
  *
- * $Id: readconfig.c,v 1.2 2002/07/02 22:09:14 kenh Exp $
+ * $Id: readconfig.c,v 1.3 2006/01/02 03:17:42 bress Exp $
  *
  * This code is Copyright (c) 2002, by the authors of nmh.  See the
  * COPYRIGHT file in the root directory of the nmh distribution for
@@ -11,6 +11,7 @@
  */
 
 #include <h/mh.h>
+#include <h/utils.h>
 
 struct procstr {
     char *procname;
@@ -65,8 +66,7 @@ readconfig (struct node **npp, FILE *ib, char *file, int ctx)
 	    case FLD:
 	    case FLDPLUS:
 	    case FLDEOF:
-		if (!(np = (struct node *) malloc (sizeof(*np))))
-		    adios (NULL, "unable to allocate profile storage");
+		np = (struct node *) mh_xmalloc (sizeof(*np));
 		*npp = np;
 		*(npp = &np->n_next) = NULL;
 		np->n_name = getcpy (name);
