@@ -3,10 +3,15 @@
  * seq_list.c -- Get all messages in a sequence and return them
  *            -- as a space separated list of message ranges.
  *
- * $Id: seq_list.c,v 1.1.1.1 1999/04/30 18:08:34 doug Exp $
+ * $Id: seq_list.c,v 1.4 2006/01/02 03:25:18 bress Exp $
+ *
+ * This code is Copyright (c) 2002, by the authors of nmh.  See the
+ * COPYRIGHT file in the root directory of the nmh distribution for
+ * complete copyright information.
  */
 
 #include <h/mh.h>
+#include <h/utils.h>
 
 /* allocate this much buffer space at a time */
 #define MAXBUFFER 1024
@@ -25,8 +30,7 @@ seq_list(struct msgs *mp, char *seqname)
     /* On first invocation, allocate initial buffer space */
     if (!buffer) {
 	len = MAXBUFFER;
-	if (!(buffer = malloc ((size_t) len)))
-	    adios (NULL, "unable to malloc storage in seq_list");
+	buffer = mh_xmalloc ((size_t) len);
     }
 
     /*
@@ -71,8 +75,7 @@ seq_list(struct msgs *mp, char *seqname)
 	    char *newbuf;
 
 	    len += MAXBUFFER;
-	    if (!(newbuf = realloc (buffer, (size_t) len)))
-		adios (NULL, "unable to realloc storage in seq_list");
+	    newbuf = mh_xrealloc (buffer, (size_t) len);
 	    bp = newbuf + (bp - buffer);
 	    buffer = newbuf;
 	}
