@@ -2,7 +2,7 @@
 /*
  * seq_nameok.c -- check if a sequence name is ok
  *
- * $Id: seq_nameok.c,v 1.2 2002/07/02 22:09:14 kenh Exp $
+ * $Id: seq_nameok.c,v 1.3 2007/04/13 11:53:08 jjr Exp $
  *
  * This code is Copyright (c) 2002, by the authors of nmh.  See the
  * COPYRIGHT file in the root directory of the nmh distribution for
@@ -13,9 +13,9 @@
 
 
 int
-seq_nameok (char *s)
+seq_nameok (unsigned char *s)
 {
-    char *pp;
+    unsigned char *pp;
 
     if (s == NULL || *s == '\0') {
 	advise (NULL, "empty sequence name");
