@@ -2,7 +2,7 @@
 /*
  * strcasecmp.c -- compare strings, ignoring case
  *
- * $Id: strcasecmp.c,v 1.2 2002/07/02 22:09:14 kenh Exp $
+ * $Id: strcasecmp.c,v 1.3 2006/03/08 12:14:16 bress Exp $
  *
  * This code is Copyright (c) 2002, by the authors of nmh.  See the
  * COPYRIGHT file in the root directory of the nmh distribution for
@@ -18,7 +18,7 @@
  */
 
 int
-strcasecmp (const char *s1, const char *s2) 
+mh_strcasecmp (const char *s1, const char *s2) 
 {
     const unsigned char *us1, *us2;
 
@@ -38,7 +38,7 @@ strcasecmp (const char *s1, const char *s2)
  
 
 int
-strncasecmp (const char *s1, const char *s2, size_t n)
+mh_strncasecmp (const char *s1, const char *s2, size_t n)
 {
     const unsigned char *us1, *us2;
 
