@@ -4,7 +4,7 @@
  *           -- replace internal whitespace with spaces,
  *           -- then return a copy.
  *
- * $Id: trimcpy.c,v 1.2 2002/07/02 22:09:14 kenh Exp $
+ * $Id: trimcpy.c,v 1.3 2007/04/13 11:53:08 jjr Exp $
  *
  * This code is Copyright (c) 2002, by the authors of nmh.  See the
  * COPYRIGHT file in the root directory of the nmh distribution for
@@ -15,9 +15,9 @@
 
 
 char *
-trimcpy (char *cp)
+trimcpy (unsigned char *cp)
 {
-    char *sp;
+    unsigned char *sp;
 
     /* skip over leading whitespace */
     while (isspace(*cp))
