@@ -2,7 +2,7 @@
 /*
  * ali.c -- list nmh mail aliases
  *
- * $Id: ali.c,v 1.7 2002/07/02 22:09:14 kenh Exp $
+ * $Id: ali.c,v 1.11 2007/11/04 11:54:33 jjr Exp $
  *
  * This code is Copyright (c) 2002, by the authors of nmh.  See the
  * COPYRIGHT file in the root directory of the nmh distribution for
@@ -13,6 +13,7 @@
 #include <h/addrsbr.h>
 #include <h/aliasbr.h>
 #include <h/mts.h>
+#include <h/utils.h>
 
 /*
  * maximum number of names
@@ -50,8 +51,8 @@ extern struct aka *akahead;
 /*
  * prototypes
  */
-void print_aka (char *, int, int);
-void print_usr (char *, int, int);
+static void print_aka (char *, int, int);
+static void print_usr (char *, int, int);
 
 
 int
@@ -169,10 +170,11 @@ main (int argc, char **argv)
 	}
     }
 
-    return done (0);
+    done (0);
+    return 1;
 }
 
-void
+static void
 print_aka (char *p, int list, int margin)
 {
     char c;
@@ -212,7 +214,7 @@ print_aka (char *p, int list, int margin)
     pos = 1;
 }
 
-void
+static void
 print_usr (char *s, int list, int norm)
 {
     register char *cp, *pp, *vp;
@@ -232,8 +234,8 @@ print_usr (char *s, int list, int norm)
 	while ((cp = getname (pp))) {
 	    if ((np = getm (cp, NULL, 0, norm, NULL)) == NULL)
 		continue;
-	    if (!strcasecmp (mp->m_host, np->m_host)
-		    && !strcasecmp (mp->m_mbox, np->m_mbox)) {
+	    if (!mh_strcasecmp (mp->m_host, np->m_host)
+		    && !mh_strcasecmp (mp->m_mbox, np->m_mbox)) {
 		vp = vp ? add (ak->ak_name, add (",", vp))
 		    : getcpy (ak->ak_name);
 		mnfree (np);
