@@ -2,11 +2,16 @@
 /*
  * aliasbr.c -- new aliasing mechanism
  *
- * $Id: aliasbr.c,v 1.3 2000/01/26 09:27:59 danh Exp $
+ * $Id: aliasbr.c,v 1.8 2007/04/13 11:53:08 jjr Exp $
+ *
+ * This code is Copyright (c) 2002, by the authors of nmh.  See the
+ * COPYRIGHT file in the root directory of the nmh distribution for
+ * complete copyright information.
  */
 
 #include <h/mh.h>
 #include <h/aliasbr.h>
+#include <h/utils.h>
 #include <grp.h>
 #include <pwd.h>
 
@@ -31,7 +36,7 @@ char *akerror (int);
 
 static  char *akval (struct aka *, char *);
 static int aleq (char *, char *);
-static char *scanp (char *);
+static char *scanp (unsigned char *);
 static char *getp (char *);
 static char *seekp (char *, char *, char **);
 static int addfile (struct aka *, char *);
@@ -42,9 +47,7 @@ static char *getalias (char *);
 static void add_aka (struct aka *, char *);
 static struct aka *akalloc (char *);
 static struct home *hmalloc (struct passwd *);
-#ifndef MMDFMTS
 struct home *seek_home (char *);
-#endif
 
 
 /* Do mh alias substitution on 's' and return the results. */
@@ -276,7 +279,7 @@ akerror (int i)
 
 
 static char *
-scanp (char *p)
+scanp (unsigned char *p)
 {
     while (isspace (*p))
 	p++;
@@ -287,7 +290,7 @@ scanp (char *p)
 static char *
 getp (char *p)
 {
-    register char  *cp = scanp (p);
+    register unsigned char  *cp = scanp (p);
 
     p = cp;
     while (!isspace (*cp) && *cp)
@@ -301,7 +304,7 @@ getp (char *p)
 static char *
 seekp (char *p, char *c, char **a)
 {
-    register char *cp;
+    register unsigned char *cp;
 
     p = cp = scanp (p);
     while (!isspace (*cp) && *cp && *cp != ':' && *cp != ';')
@@ -433,7 +436,7 @@ addall (struct aka *ak)
 static char *
 getalias (char *addrs)
 {
-    register char *pp, *qp;
+    register unsigned char *pp, *qp;
     static char *cp = NULL;
 
     if (cp == NULL)
@@ -471,9 +474,7 @@ add_aka (struct aka *ak, char *pp)
 	if (!strcmp (pp, ad->ad_text))
 	    return;
 
-    ad = (struct adr *) malloc (sizeof(*ad));
-    if (ad == NULL)
-	return;
+    ad = (struct adr *) mh_xmalloc (sizeof(*ad));
     ad->ad_text = getcpy (pp);
     ad->ad_local = strchr(pp, '@') == NULL && strchr(pp, '!') == NULL;
     ad->ad_next = NULL;
@@ -518,8 +519,7 @@ akalloc (char *id)
 {
     register struct aka *p;
 
-    if (!(p = (struct aka *) malloc (sizeof(*p))))
-	return NULL;
+    p = (struct aka *) mh_xmalloc (sizeof(*p));
 
     p->ak_name = getcpy (id);
     p->ak_visible = 0;
@@ -540,8 +540,7 @@ hmalloc (struct passwd *pw)
 {
     register struct home *p;
 
-    if (!(p = (struct home *) malloc (sizeof(*p))))
-	return NULL;
+    p = (struct home *) mh_xmalloc (sizeof(*p));
 
     p->h_name = getcpy (pw->pw_name);
     p->h_uid = pw->pw_uid;
@@ -560,7 +559,6 @@ hmalloc (struct passwd *pw)
 }
 
 
-#ifndef	MMDFMTS
 struct home *
 seek_home (char *name)
 {
@@ -568,7 +566,8 @@ seek_home (char *name)
 #ifdef DBMPWD
     struct passwd *pw;
     char lname[32];
-    char *c,*c1;
+    unsigned char *c;
+    char *c1;
 #else  /* DBMPWD */
 
     if (homehead == NULL)
@@ -576,7 +575,7 @@ seek_home (char *name)
 #endif /* DBMPWD */
 
     for (hp = homehead; hp; hp = hp->h_next)
-	if (!strcasecmp (name, hp->h_name))
+	if (!mh_strcasecmp (name, hp->h_name))
 	    return hp;
 
 #ifdef DBMPWD
@@ -597,4 +596,3 @@ seek_home (char *name)
 	
     return NULL;
 }
-#endif	/* MMDFMTS */
