@@ -2,7 +2,7 @@
 /*
  * anno.c -- annotate messages
  *
- * $Id: anno.c,v 1.6 2005/12/07 21:25:47 jon Exp $
+ * $Id: anno.c,v 1.12 2007/11/04 11:54:33 jjr Exp $
  *
  * This code is Copyright (c) 2002, by the authors of nmh.  See the
  * COPYRIGHT file in the root directory of the nmh distribution for
@@ -46,13 +46,7 @@
  */
 
 #include <h/mh.h>
-
-/*
- * We allocate space for messages (msgs array)
- * this number of elements at a time.
- */
-#define MAXMSGS  256
-
+#include <h/utils.h>
 
 static struct swit switches[] = {
 #define	COMPSW	0
@@ -91,17 +85,19 @@ static struct swit switches[] = {
 /*
  * static prototypes
  */
-static void make_comp (char **);
+static void make_comp (unsigned char **);
 
 
 int
 main (int argc, char **argv)
 {
     int inplace = 1, datesw = 1;
-    int nummsgs, maxmsgs, msgnum;
-    char *cp, *maildir, *comp = NULL;
+    int msgnum;
+    char *cp, *maildir;
+    unsigned char *comp = NULL;
     char *text = NULL, *folder = NULL, buf[BUFSIZ];
-    char **argp, **arguments, **msgs;
+    char **argp, **arguments;
+    struct msgs_array msgs = { 0, 0, NULL };
     struct msgs *mp;
     int		append = 0;		/* append annotations instead of default prepend */
     int		delete = -2;		/* delete header element if set */
@@ -121,15 +117,6 @@ main (int argc, char **argv)
     arguments = getarguments (invo_name, argc, argv, 1);
     argp = arguments;
 
-    /*
-     * Allocate the initial space to record message
-     * names and ranges.
-     */
-    nummsgs = 0;
-    maxmsgs = MAXMSGS;
-    if (!(msgs = (char **) malloc ((size_t) (maxmsgs * sizeof(*msgs)))))
-	adios (NULL, "unable to allocate storage");
-
     while ((cp = *argp++)) {
 	if (*cp == '-') {
 	    switch (smatch (++cp, switches)) {
@@ -225,20 +212,9 @@ main (int argc, char **argv)
 	    if (folder)
 		adios (NULL, "only one folder at a time!");
 	    else
-		folder = path (cp + 1, *cp == '+' ? TFOLDER : TSUBCWF);
-	} else {
-	    /*
-	     * Check if we need to allocate more space
-	     * for message name/ranges.
-	     */
-	    if (nummsgs >= maxmsgs) {
-		maxmsgs += MAXMSGS;
-		if (!(msgs = (char **) realloc (msgs,
-			(size_t) (maxmsgs * sizeof(*msgs)))))
-		    adios (NULL, "unable to reallocate msgs storage");
-	    }
-	    msgs[nummsgs++] = cp;
-	}
+		folder = pluspath (cp);
+	} else
+		app_msgarg(&msgs, cp);
     }
 
     /*
@@ -248,7 +224,7 @@ main (int argc, char **argv)
      */
 
     if (draft != (char *)0) {
-	if (nummsgs != 0)
+	if (msgs.size != 0)
 	    adios(NULL, "can only have message numbers or -draft.");
 
 	draft = getcpy(m_draft(folder, (char *)0, 1, &isdf));
@@ -260,7 +236,8 @@ main (int argc, char **argv)
 	else
 	    annotate (draft, comp, text, inplace, datesw, delete, append);
 
-	return (done(0));
+	done(0);
+	return 1;
     }
 
 #ifdef UCI
@@ -270,8 +247,8 @@ main (int argc, char **argv)
 
     if (!context_find ("path"))
 	free (path ("./", TFOLDER));
-    if (!nummsgs)
-	msgs[nummsgs++] = "cur";
+    if (!msgs.size)
+	app_msgarg(&msgs, "cur");
     if (!folder)
 	folder = getfolder (1);
     maildir = m_maildir (folder);
@@ -288,8 +265,8 @@ main (int argc, char **argv)
 	adios (NULL, "no messages in %s", folder);
 
     /* parse all the message ranges/sequences and set SELECTED */
-    for (msgnum = 0; msgnum < nummsgs; msgnum++)
-	if (!m_convert (mp, msgs[msgnum]))
+    for (msgnum = 0; msgnum < msgs.size; msgnum++)
+	if (!m_convert (mp, msgs.msgs[msgnum]))
 	    done (1);
 
     make_comp (&comp);
@@ -309,13 +286,14 @@ main (int argc, char **argv)
     seq_save (mp);	/* synchronize message sequences */
     folder_free (mp);	/* free folder/message structure */
     context_save ();	/* save the context file         */
-    return done (0);
+    done (0);
+    return 1;
 }
 
 static void
-make_comp (char **ap)
+make_comp (unsigned char **ap)
 {
-    register char *cp;
+    register unsigned char *cp;
     char buffer[BUFSIZ];
 
     if (*ap == NULL) {
