@@ -2,7 +2,7 @@
 /*
  * annosbr.c -- prepend annotation to messages
  *
- * $Id: annosbr.c,v 1.6 2005/12/07 21:25:47 jon Exp $
+ * $Id: annosbr.c,v 1.9 2008/04/05 18:41:38 pm215 Exp $
  *
  * This code is Copyright (c) 2002, by the authors of nmh.  See the
  * COPYRIGHT file in the root directory of the nmh distribution for
@@ -11,6 +11,7 @@
 
 #include <h/mh.h>
 #include <h/tws.h>
+#include <h/utils.h>
 #include <fcntl.h>
 #include <errno.h>
 #include <utime.h>
@@ -93,8 +94,7 @@ annolist(char *file, char *comp, char *text, int number)
      *  This buffer might need to be quite large, so we grow it as needed.
      */
 
-    if ((field = (char *)malloc(field_size = 256)) == (char *)0)
-	adios(NULL, "can't allocate field buffer.");
+    field = (char *)mh_xmalloc(field_size = 256);
 
     /*
      *  Get the length of the field name since we use it often.
@@ -120,8 +120,7 @@ annolist(char *file, char *comp, char *text, int number)
 	    }
 
 	    if (++n >= field_size - 1) {
-		if ((field = (char *)realloc((void *)field, field_size += 256)) == (char *)0)
-		    adios(NULL, "can't grow field buffer.");
+		field = (char *) mh_xrealloc((void *)field, field_size += 256);
 		
 		cp = field + n - 1;
 	    }
@@ -208,8 +207,7 @@ annosbr (int fd, char *file, char *comp, char *text, int inplace, int datesw, in
 	if ((fp = fdopen(fd, "r")) == (FILE *)0)
 	    adios(NULL, "unable to fdopen file.");
 
-	if ((field = (char *)malloc(field_size = 256)) == (char *)0)
-	    adios(NULL, "can't allocate field buffer.");
+	field = (char *)mh_xmalloc(field_size = 256);
     }
 
     /*
@@ -263,8 +261,7 @@ annosbr (int fd, char *file, char *comp, char *text, int inplace, int datesw, in
 		}
 
 		if (++n >= field_size - 1) {
-		    if ((field = (char *)realloc((void *)field, field_size *= 2)) == (char *)0)
-			adios(NULL, "can't grow field buffer.");
+		    field = (char *) mh_xrealloc((void *)field, field_size *= 2);
 		
 		    cp = field + n - 1;
 		}
@@ -384,7 +381,7 @@ annosbr (int fd, char *file, char *comp, char *text, int inplace, int datesw, in
 		while (*cp && *cp++ != '\n')
 		    continue;
 		if (cp - sp)
-		    fprintf (tmp, "%s: %*.*s", comp, cp - sp, cp - sp, sp);
+		    fprintf (tmp, "%s: %*.*s", comp, (int)(cp - sp), (int)(cp - sp), sp);
 	    } while (*cp);
 	    if (cp[-1] != '\n' && cp != text)
 		putc ('\n', tmp);
