@@ -2,7 +2,7 @@
 /*
  * burst.c -- explode digests into individual messages
  *
- * $Id: burst.c,v 1.5 2002/08/23 20:37:01 jon Exp $
+ * $Id: burst.c,v 1.7 2007/11/04 11:54:33 jjr Exp $
  *
  * This code is Copyright (c) 2002, by the authors of nmh.  See the
  * COPYRIGHT file in the root directory of the nmh distribution for
@@ -111,7 +111,7 @@ main (int argc, char **argv)
 	    if (folder)
 		adios (NULL, "only one folder at a time!");
 	    else
-		folder = path (cp + 1, *cp == '+' ? TFOLDER : TSUBCWF);
+		folder = pluspath (cp);
 	} else {
 	    msgs[msgp++] = cp;
 	}
@@ -189,7 +189,8 @@ main (int argc, char **argv)
     seq_save (mp);	/* synchronize message sequences */
     context_save ();	/* save the context file         */
     folder_free (mp);	/* free folder/message structure */
-    return done (0);
+    done (0);
+    return 1;
 }
 
 
