@@ -2,10 +2,15 @@
 /*
  * comp.c -- compose a message
  *
- * $Id: comp.c,v 1.2 1999/07/16 01:33:58 danh Exp $
+ * $Id: comp.c,v 1.7 2007/11/04 11:54:33 jjr Exp $
+ *
+ * This code is Copyright (c) 2002, by the authors of nmh.  See the
+ * COPYRIGHT file in the root directory of the nmh distribution for
+ * complete copyright information.
  */
 
 #include <h/mh.h>
+#include <h/utils.h>
 #include <fcntl.h>
 
 static struct swit switches[] = {
@@ -34,7 +39,7 @@ static struct swit switches[] = {
 #define VERSIONSW             11
     { "version", 0 },
 #define	HELPSW                12
-    { "help", 4 },
+    { "help", 0 },
     { NULL, 0 }
 };
 
@@ -167,7 +172,7 @@ main (int argc, char **argv)
 	    if (folder)
 		adios (NULL, "only one folder at a time!");
 	    else
-		folder = path (cp + 1, *cp == '+' ? TFOLDER : TSUBCWF);
+		folder = pluspath (cp);
 	} else {
 	    if (msg)
 		adios (NULL, "only one message at a time!");
@@ -223,19 +228,8 @@ main (int argc, char **argv)
 
 	if ((in = open (form = getcpy (m_name (mp->lowsel)), O_RDONLY)) == NOTOK)
 	    adios (form, "unable to open message");
-    } else {
-	/*
-	 * Open a component or forms file
-	 */
-	if (form) {
-	    if ((in = open (etcpath (form), O_RDONLY)) == NOTOK)
-		adios (form, "unable to open form file");
-	} else {
-	    if ((in = open (etcpath (components), O_RDONLY)) == NOTOK)
-		adios (components, "unable to open default components file");
-	    form = components;
-	}
-    }
+    } else
+	in = open_form(&form, components);
 
 try_it_again:
     strncpy (drft, m_draft (dfolder, file, use, &isdf), sizeof(drft));
@@ -302,5 +296,6 @@ edit_it:
     if (nwhat)
 	done (0);
     what_now (ed, nedit, use, drft, NULL, 0, NULLMP, NULL, 0, cwd);
-    return done (1);
+    done (1);
+    return 1;
 }
