@@ -2,13 +2,18 @@
 /*
  * conflict.c -- check for conflicts in mail system
  *
- * $Id: conflict.c,v 1.3 2000/02/04 20:28:23 danh Exp $
+ * $Id: conflict.c,v 1.9 2007/11/04 11:54:33 jjr Exp $
+ *
+ * This code is Copyright (c) 2002, by the authors of nmh.  See the
+ * COPYRIGHT file in the root directory of the nmh distribution for
+ * complete copyright information.
  */
 
 #include <h/mh.h>
 #include <fcntl.h>
 #include <h/aliasbr.h>
-#include <zotnet/mts/mts.h>
+#include <h/mts.h>
+#include <h/utils.h>
 #include <grp.h>
 #include <pwd.h>
 
@@ -134,7 +139,8 @@ main (int argc, char **argv)
 #endif	/* UCI */
     maildrops ();
 
-    return done (0);
+    done (0);
+    return 1;
 }
 
 
@@ -185,8 +191,7 @@ grp_names (void)
     /* allocate space NGRPS at a time */
     numgroups = 0;
     maxgroups = NGRPS;
-    if (!(grps = (char **) malloc((size_t) (maxgroups * sizeof(*grps)))))
-	adios (NULL, "unable to allocate group name storage");
+    grps = (char **) mh_xmalloc((size_t) (maxgroups * sizeof(*grps)));
 
     setgrent ();
     while ((gr = getgrent ())) {
@@ -201,9 +206,8 @@ grp_names (void)
 	if (i >= numgroups) {
 	    if (numgroups >= maxgroups) {
 		maxgroups += NGRPS;
-		if (!(grps = (char **) realloc(grps,
-			(size_t) (maxgroups * sizeof(*grps)))))
-		    adios (NULL, "unable to reallocate group name storage");
+		grps = (char **) mh_xrealloc(grps,
+		    (size_t) (maxgroups * sizeof(*grps)));
 	    }
 	    grps[numgroups++] = getcpy (gr->gr_name);
 	}
