@@ -2,10 +2,15 @@
 /*
  * dist.c -- re-distribute a message
  *
- * $Id: dist.c,v 1.2 1999/07/16 01:33:15 danh Exp $
+ * $Id: dist.c,v 1.7 2007/11/04 11:54:33 jjr Exp $
+ *
+ * This code is Copyright (c) 2002, by the authors of nmh.  See the
+ * COPYRIGHT file in the root directory of the nmh distribution for
+ * complete copyright information.
  */
 
 #include <h/mh.h>
+#include <h/utils.h>
 #include <fcntl.h>
 
 static struct swit switches[] = {
@@ -36,7 +41,7 @@ static struct swit switches[] = {
 #define VERSIONSW 12
     { "version", 0 },
 #define	HELPSW	13
-    { "help", 4 },
+    { "help", 0 },
 #define	FILESW	14
     { "file file", -4 },	/* interface from msh */
     { NULL, 0 }
@@ -175,7 +180,7 @@ main (int argc, char **argv)
 	    if (folder)
 		adios (NULL, "only one folder at a time!");
 	    else
-		folder = path (cp + 1, *cp == '+' ? TFOLDER : TSUBCWF);
+		folder = pluspath (cp);
 	} else {
 	    if (msg)
 		adios (NULL, "only one message at a time!");
@@ -191,14 +196,7 @@ main (int argc, char **argv)
     if (file && (msg || folder))
 	adios (NULL, "can't mix files and folders/msgs");
 
-    if (form) {
-	if ((in = open (etcpath (form), O_RDONLY)) == NOTOK)
-	    adios (form, "unable to open form file");
-    } else {
-	if ((in = open (etcpath (distcomps), O_RDONLY)) == NOTOK)
-	    adios (distcomps, "unable to open default components file");
-	form = distcomps;
-    }
+    in = open_form(&form, distcomps);
 
 try_it_again:
     strncpy (drft, m_draft (dfolder, dmsg, NOUSE, &isdf), sizeof(drft));
@@ -287,5 +285,6 @@ try_it_again:
 	done (0);
     what_now (ed, nedit, NOUSE, drft, msgnam, 1, mp,
 	anot ? "Resent" : NULL, inplace, cwd);
-    return done (1);
+    done (1);
+    return 1;
 }
