@@ -2,7 +2,7 @@
 /*
  * distsbr.c -- routines to do additional "dist-style" processing
  *
- * $Id: distsbr.c,v 1.2 2002/07/02 22:09:14 kenh Exp $
+ * $Id: distsbr.c,v 1.4 2007/04/13 11:53:08 jjr Exp $
  *
  * This code is Copyright (c) 2002, by the authors of nmh.  See the
  * COPYRIGHT file in the root directory of the nmh distribution for
@@ -11,6 +11,7 @@
 
 #include <h/mh.h>
 #include <fcntl.h>
+#include <h/utils.h>
 
 static int  hdrfd = NOTOK;
 static int  txtfd = NOTOK;
@@ -29,7 +30,8 @@ int
 distout (char *drft, char *msgnam, char *backup)
 {
     int state;
-    register char *dp, *resent;
+    register unsigned char *dp;
+    register char *resent;
     char name[NAMESZ], buffer[BUFSIZ];
     register FILE *ifp, *ofp;
 
