@@ -2,12 +2,16 @@
 /*
  * dp.c -- parse dates 822-style
  *
- * $Id: dp.c,v 1.3 2000/02/04 20:28:23 danh Exp $
+ * $Id: dp.c,v 1.6 2007/11/04 11:54:33 jjr Exp $
+ *
+ * This code is Copyright (c) 2002, by the authors of nmh.  See the
+ * COPYRIGHT file in the root directory of the nmh distribution for
+ * complete copyright information.
  */
 
 #include <h/mh.h>
 #include <h/fmt_scan.h>
-#include <zotnet/tws/tws.h>
+#include <h/tws.h>
 
 #define	NDATES 100
 
@@ -132,7 +136,8 @@ main (int argc, char **argv)
 	status += process (dates[datep], width);
 
     context_save ();	/* save the context file */
-    return done (status);
+    done (status);
+    return 1;
 }
 
 
