@@ -13,10 +13,11 @@
  * makes no warranty about the software, its performance or its conformity to
  * any specification.
  *
- *  $Id: flist.c,v 1.6 2005/11/02 17:22:27 opk Exp $
+ *  $Id: flist.c,v 1.12 2007/11/04 11:54:33 jjr Exp $
  */
 
 #include <h/mh.h>
+#include <h/utils.h>
 
 #define FALSE   0
 #define TRUE    1
@@ -113,7 +114,6 @@ int AddFolder(char *, int);
 void BuildFolderList(char *, int);
 void BuildFolderListRecurse(char *, struct stat *, int);
 void PrintFolders(void);
-static int num_digits (int);
 void AllocFolders(struct Folder **, int *, int);
 int AssignPriority(char *);
 static void do_readonly_folders(void);
@@ -148,8 +148,7 @@ main(int argc, char **argv)
     /* allocate the initial space to record the folder names */
     numfolders = 0;
     maxfolders = MAXFOLDERS;
-    if (!(foldersToDo = (char **) malloc ((size_t) (maxfolders * sizeof(*foldersToDo)))))
-	adios (NULL, "unable to allocate folder storage");
+    foldersToDo = (char **) mh_xmalloc ((size_t) (maxfolders * sizeof(*foldersToDo)));
 
     /* no sequences yet */
     numsequences = 0;
@@ -228,13 +227,12 @@ main(int argc, char **argv)
 	     */
 	    if (numfolders >= maxfolders) {
 		maxfolders += MAXFOLDERS;
-		if (!(foldersToDo = (char **) realloc (foldersToDo,
-			(size_t) (maxfolders * sizeof(*foldersToDo)))))
-		    adios (NULL, "unable to reallocate folder name storage");
+		foldersToDo = (char **) mh_xrealloc (foldersToDo,
+		    (size_t) (maxfolders * sizeof(*foldersToDo)));
 	    }
 	    if (*cp == '+' || *cp == '@') {
 		foldersToDo[numfolders++] =
-		    path (cp + 1, *cp == '+' ? TFOLDER : TSUBCWF);
+		    pluspath (cp);
 	    } else
 		foldersToDo[numfolders++] = cp;
 	}
@@ -278,7 +276,8 @@ main(int argc, char **argv)
     ScanFolders();
     qsort(folders, nFolders, sizeof(struct Folder), (qsort_comp) CompareFolders);
     PrintFolders();
-    return done (0);
+    done (0);
+    return 1;
 }
 
 /*
@@ -289,7 +288,7 @@ main(int argc, char **argv)
 void
 GetFolderOrder(void)
 {
-    char *p, *s;
+    unsigned char *p, *s;
     int priority = 1;
     struct Folder *o;
 
@@ -306,7 +305,7 @@ GetFolderOrder(void)
 	    AllocFolders(&orders, &nOrdersAlloced, nOrders + 1);
 	    o = &orders[nOrders++];
 	    o->priority = priority++;
-	    o->name = (char *) malloc(p - s + 1);
+	    o->name = (char *) mh_xmalloc(p - s + 1);
 	    strncpy(o->name, s, p - s);
 	    o->name[p - s] = 0;
 	} else
@@ -401,7 +400,8 @@ BuildFolderList(char *dirName, int searchdepth)
 void
 BuildFolderListRecurse(char *dirName, struct stat *s, int searchdepth)
 {
-    char *base, *n, name[PATH_MAX];
+    char *base, name[PATH_MAX];
+    unsigned char *n;
     int nlinks;
     DIR *dir;
     struct dirent *dp;
@@ -605,29 +605,6 @@ PrintFolders(void)
     }
 }
 
-/*
- * Calculate the number of digits in a nonnegative integer
- */
-static int
-num_digits (int n)
-{
-    int ndigits = 0;
-
-    /* Sanity check */
-    if (n < 0)
-	adios (NULL, "oops, num_digits called with negative value");
-
-    if (n == 0)
-	return 1;
-
-    while (n) {
-	n /= 10;
-	ndigits++;
-    }
-
-    return ndigits;
-}
-
 /*
  * Put them in priority order.
  */
@@ -652,10 +629,10 @@ AllocFolders(struct Folder **f, int *nfa, int n)
 	return;
     if (*f == NULL) {
 	*nfa = 10;
-	*f = (struct Folder *) malloc (*nfa * (sizeof(struct Folder)));
+	*f = (struct Folder *) mh_xmalloc (*nfa * (sizeof(struct Folder)));
     } else {
 	*nfa *= 2;
-	*f = (struct Folder *) realloc (*f, *nfa * (sizeof(struct Folder)));
+	*f = (struct Folder *) mh_xrealloc (*f, *nfa * (sizeof(struct Folder)));
     }
 }
 
