@@ -2,7 +2,7 @@
 /*
  * fmtdump.c -- compile format file and dump out instructions
  *
- * $Id: fmtdump.c,v 1.6 2003/08/11 01:20:52 jchonig Exp $
+ * $Id: fmtdump.c,v 1.7 2007/11/04 11:54:33 jjr Exp $
  *
  * This code is Copyright (c) 2002, by the authors of nmh.  See the
  * COPYRIGHT file in the root directory of the nmh distribution for
@@ -106,7 +106,8 @@ main (int argc, char **argv)
     ncomps = fmt_compile(nfs, &fmt);
 
     fmt_dump(fmt);
-    return done(0);
+    done(0);
+    return 1;
 }
 
 static void
