@@ -4,7 +4,7 @@
  *             -- push/pop a folder onto/from the folder stack
  *             -- list the folder stack
  *
- * $Id: folder.c,v 1.6 2003/09/30 16:58:00 gbburkhardt Exp $
+ * $Id: folder.c,v 1.13 2007/11/04 11:54:33 jjr Exp $
  *
  * This code is Copyright (c) 2002, by the authors of nmh.  See the
  * COPYRIGHT file in the root directory of the nmh distribution for
@@ -12,6 +12,7 @@
  */
 
 #include <h/mh.h>
+#include <h/utils.h>
 #include <errno.h>
 
 static struct swit switches[] = {
@@ -120,7 +121,6 @@ static int maxFolderInfo;
 static void dodir (char *);
 static int get_folder_info (char *, char *);
 static void print_folders (void);
-static int num_digits (int);
 static int sfold (struct msgs *, char *);
 static void addir (char *);
 static void addfold (char *);
@@ -135,7 +135,6 @@ main (int argc, char **argv)
     int pushsw = 0, popsw = 0;
     char *cp, *dp, *msg = NULL, *argfolder = NULL;
     char **ap, **argp, buf[BUFSIZ], **arguments;
-    struct stat st;
 
 #ifdef LOCALE
     setlocale(LC_ALL, "");
@@ -260,7 +259,7 @@ main (int argc, char **argv)
 	    if (argfolder)
 		adios (NULL, "only one folder at a time!");
 	    else
-		argfolder = path (cp + 1, *cp == '+' ? TFOLDER : TSUBCWF);
+		argfolder = pluspath (cp);
 	} else {
 	    if (msg)
 		adios (NULL, "only one (current) message at a time!");
@@ -353,13 +352,11 @@ main (int argc, char **argv)
 
     /* Allocate initial space to record folder names */
     maxfolders = NUMFOLDERS;
-    if ((folds = malloc (maxfolders * sizeof(char *))) == NULL)
-	adios (NULL, "unable to allocate storage for folder names");
+    folds = mh_xmalloc (maxfolders * sizeof(char *));
 
     /* Allocate initial space to record folder information */
     maxFolderInfo = NUMFOLDERS;
-    if ((fi = malloc (maxFolderInfo * sizeof(*fi))) == NULL)
-	adios (NULL, "unable to allocate storage for folder info");
+    fi = mh_xmalloc (maxFolderInfo * sizeof(*fi));
 
     /*
      * Scan the folders
@@ -394,22 +391,7 @@ main (int argc, char **argv)
 	 * Check if folder exists.  If not, then see if
 	 * we should create it, or just exit.
 	 */
-	if (stat (strncpy (buf, m_maildir (folder), sizeof(buf)), &st) == -1) {
-	    if (errno != ENOENT)
-		adios (buf, "error on folder");
-	    if (fcreat == 0) {
-		/* ask before creating folder */
-		cp = concat ("Create folder \"", buf, "\"? ", NULL);
-		if (!getanswer (cp))
-		    done (1);
-		free (cp);
-	    } else if (fcreat == -1) {
-		/* do not create, so exit */
-		done (1);
-	    }
-	    if (!makedir (buf))
-		adios (NULL, "unable to create folder %s", buf);
-	}
+        create_folder (m_maildir (folder), fcreat, done);
 
 	if (get_folder_info (folder, msg) && argfolder) {
 	    /* update current folder */
@@ -423,7 +405,8 @@ main (int argc, char **argv)
     print_folders();
 
     context_save ();	/* save the context file */
-    return done (0);
+    done (0);
+    return 1;
 }
 
 /*
@@ -470,8 +453,7 @@ get_folder_info (char *fold, char *msg)
      */
     if (total_folders >= maxFolderInfo) {
 	maxFolderInfo += NUMFOLDERS;
-	if ((fi = realloc (fi, maxFolderInfo * sizeof(*fi))) == NULL)
-	    adios (NULL, "unable to re-allocate storage for folder info");
+	fi = mh_xrealloc (fi, maxFolderInfo * sizeof(*fi));
     }
 
     fi[i].name   = fold;
@@ -657,29 +639,6 @@ print_folders (void)
     fflush (stdout);
 }
 
-/*
- * Calculate the number of digits in a nonnegative integer
- */
-int
-num_digits (int n)
-{
-    int ndigits = 0;
-
-    /* Sanity check */
-    if (n < 0)
-	adios (NULL, "oops, num_digits called with negative value");
-
-    if (n == 0)
-	return 1;
-
-    while (n) {
-	n /= 10;
-	ndigits++;
-    }
-
-    return ndigits;
-}
-
 /*
  * Set the current message and sychronize sequences
  */
@@ -775,8 +734,7 @@ addfold (char *fold)
     /* if necessary, reallocate the space for folder names */
     if (foldp >= maxfolders) {
 	maxfolders += NUMFOLDERS;
-	if ((folds = realloc (folds, maxfolders * sizeof(char *))) == NULL)
-	    adios (NULL, "unable to re-allocate storage for folder names");
+	folds = mh_xrealloc (folds, maxfolders * sizeof(char *));
     }
 
     cp = getcpy (fold);
