@@ -2,11 +2,15 @@
 /*
  * ftpsbr.c -- simple FTP client library
  *
- * $Id$
+ * $Id: ftpsbr.c,v 1.5 2007/04/13 11:53:08 jjr Exp $
+ *
+ * This code is Copyright (c) 2002, by the authors of nmh.  See the
+ * COPYRIGHT file in the root directory of the nmh distribution for
+ * complete copyright information.
  */
 
 #include <h/mh.h>
-#include <h/mhn.h>
+#include <h/mime.h>
 
 #ifdef HAVE_ARPA_FTP_H
 # include <arpa/ftp.h>
@@ -27,16 +31,15 @@ extern int v_verbose;
 #include <sys/socket.h>
 #include <netinet/in.h>
 #include <netdb.h>
+#include <errno.h>
 
-#if defined(BIND) && !defined(h_addr)
+#if !defined(h_addr)
 # define h_addr	h_addr_list[0]
 #endif
 
 #define	inaddr_copy(hp,sin) \
     memcpy((char *) &((sin)->sin_addr), (hp)->h_addr, (hp)->h_length)
 
-extern int errno;
-
 #define	start_tcp_client(sock,priv) \
     	socket (AF_INET, SOCK_STREAM, 0)
 
@@ -54,7 +57,7 @@ int ftp_trans (char *, char *, char *, char *, char *, char *, char *, int, int)
  * static prototypes
  */
 static int start_tcp_server (struct sockaddr_in *, int, int, int);
-static void _asprintf (char *, char *, va_list);
+static void _asnprintf (char *, int, char *, va_list);
 static int ftp_quit (void);
 static int ftp_read (char *, char *, char *, int);
 static int initconn (void);
@@ -95,9 +98,9 @@ static int __len__;
 #define	close_tcp_socket close
 
 static void
-_asprintf (char *bp, char *what, va_list ap)
+_asnprintf (char *bp, int len_bp, char *what, va_list ap)
 {
-    register int eindex;
+    int eindex, len;
     char *fmt;
 
     eindex = errno;
@@ -106,21 +109,25 @@ _asprintf (char *bp, char *what, va_list ap)
     fmt = va_arg (ap, char *);
 
     if (fmt) {
-	vsprintf(bp, fmt, ap);
-	bp += strlen(bp);
+	vsnprintf(bp, len_bp, fmt, ap);
+	len = strlen(bp);
+	bp += len;
+	len_bp -= len;
     }
 
     if (what) {
 	char *s;
 
 	if (*what) {
-	    sprintf (bp, " %s: ", what);
-	    bp += strlen (bp);
+	    snprintf (bp, len_bp, " %s: ", what);
+	    len = strlen (bp);
+	    bp += len;
+	    len_bp -= len;
 	}
 	if ((s = strerror(eindex)))
-	    strcpy (bp, s);
+	    strncpy (bp, s, len_bp);
 	else
-	    sprintf (bp, "Error %d", eindex);
+	    snprintf (bp, len_bp, "Error %d", eindex);
 	bp += strlen (bp);
     }
 
@@ -439,7 +446,7 @@ vcommand (int complete, va_list ap)
     if (ftp_fd == NOTOK)
 	return NOTOK;
 
-    _asprintf (buffer, NULL, ap);
+    _asnprintf (buffer, sizeof(buffer), NULL, ap);
     if (v_debug)
 	fprintf (stderr, "<--- %s\n", buffer);
 
@@ -468,7 +475,7 @@ getreply (int complete, int expecteof)
 	bp = buffer;
 
 	for (;;) {
-	    char c;
+	    unsigned char c;
 
 	    if (read_tcp_socket (ftp_fd, &c, 1) < 1) {
 		if (expecteof)
