@@ -2,7 +2,7 @@
 /*
  * inc.c -- incorporate messages from a maildrop into a folder
  *
- * $Id: inc.c,v 1.20 2005/01/27 16:34:20 opk Exp $
+ * $Id: inc.c,v 1.26 2007/11/04 11:54:34 jjr Exp $
  *
  * This code is Copyright (c) 2002, by the authors of nmh.  See the
  * COPYRIGHT file in the root directory of the nmh distribution for
@@ -29,6 +29,7 @@
 #endif
 
 #include <h/mh.h>
+#include <h/utils.h>
 #include <fcntl.h>
 
 #ifdef POP
@@ -222,8 +223,8 @@ static FILE *in;
  */
 char *map_name(char *);
 
+static void inc_done(int);
 #ifdef POP
-int done(int);
 static int pop_action(char *);
 static int pop_pack(char *);
 static int map_count(void);
@@ -262,6 +263,8 @@ main (int argc, char **argv)
     struct hes_postoffice *po;
 #endif
 
+    done=inc_done;
+
 /* absolutely the first thing we do is save our privileges,
  * and drop them if we can.
  */
@@ -456,7 +459,7 @@ main (int argc, char **argv)
 	    if (folder)
 		adios (NULL, "only one folder at a time!");
 	    else
-		folder = path (cp + 1, *cp == '+' ? TFOLDER : TSUBCWF);
+		folder = pluspath (cp);
 	} else {
 	    adios (NULL, "usage: %s [+folder] [switches]", invo_name);
 	}
@@ -562,15 +565,14 @@ main (int argc, char **argv)
     if ((maildir_copy = strdup(maildir)) == (char *)0)
         adios (maildir, "error allocating memory to copy maildir");
 
-    if (stat (maildir, &st) == NOTOK) {
-	if (errno != ENOENT)
-	    adios (maildir, "error on folder");
-	cp = concat ("Create folder \"", maildir, "\"? ", NULL);
-	if (noisy && !getanswer (cp))
-	    done (1);
-	free (cp);
-	if (!makedir (maildir))
-	    adios (NULL, "unable to create folder %s", maildir);
+    if (!folder_exists(maildir)) {
+        /* If the folder doesn't exist, and we're given the -silent flag,
+         * just fail.
+         */
+        if (noisy)
+            create_folder(maildir, 0, done);
+        else
+            done (1);
     }
 
     if (chdir (maildir) == NOTOK)
@@ -950,7 +952,8 @@ go_to_it:
     seq_setunseen (mp, 0);	/* set the Unseen-Sequence */
     seq_save (mp);		/* synchronize sequences   */
     context_save ();		/* save the context file   */
-    return done (0);
+    done (0);
+    return 1;
 }
 
 
@@ -987,8 +990,8 @@ cpymsg (FILE *in, FILE *out)
 #endif /* if 0 */
 
 
-int
-done (int status)
+static void
+inc_done (int status)
 {
 #ifdef POP
     if (packfile && pd != NOTOK)
@@ -1001,7 +1004,6 @@ done (int status)
         DROPGROUPPRIVS();
     }
     exit (status);
-    return 1;  /* dead code to satisfy the compiler */
 }
 
 #ifdef POP
