@@ -1,7 +1,7 @@
 /*
  * install-mh.c -- initialize the nmh environment of a new user
  *
- * $Id: install-mh.c,v 1.5 2002/11/18 18:25:02 jon Exp $
+ * $Id: install-mh.c,v 1.7 2007/11/04 11:54:34 jjr Exp $
  *
  * This code is Copyright (c) 2002, by the authors of nmh.  See the
  * COPYRIGHT file in the root directory of the nmh distribution for
@@ -9,6 +9,7 @@
  */
 
 #include <h/mh.h>				/* mh internals */
+#include <h/utils.h>
 #include <pwd.h>				/* structure for getpwuid() results */
 
 static struct swit switches[] = {
@@ -180,8 +181,7 @@ query:
     /*
      * Add some initial elements to the profile/context list
      */
-    if (!(m_defs = (struct node *) malloc (sizeof *np)))
-	adios (NULL, "unable to allocate profile storage");
+    m_defs = (struct node *) mh_xmalloc (sizeof *np);
     np = m_defs;
     np->n_name = getcpy ("Path");
     np->n_field = getcpy (pathname);
@@ -213,7 +213,8 @@ query:
 	    fprintf (out, "%s: %s\n", np->n_name, np->n_field);
     }
     fclose (out);
-    return done (0);
+    done (0);
+    return 1;
 }
 
 
