@@ -4,17 +4,15 @@
  *        -- delete messages (s) from sequences in given folder
  *        -- list sequences in given folder
  *
- * $Id: mark.c,v 1.3 2000/02/04 20:28:24 danh Exp $
+ * $Id: mark.c,v 1.9 2007/11/04 11:54:34 jjr Exp $
+ *
+ * This code is Copyright (c) 2002, by the authors of nmh.  See the
+ * COPYRIGHT file in the root directory of the nmh distribution for
+ * complete copyright information.
  */
 
 #include <h/mh.h>
-
-/*
- * We allocate space for messages (msgs array)
- * this number of elements at a time.
- */
-#define MAXMSGS  256
-
+#include <h/utils.h>
 
 static struct swit switches[] = {
 #define	ADDSW               0
@@ -54,10 +52,11 @@ main (int argc, char **argv)
 {
     int addsw = 0, deletesw = 0, debugsw = 0;
     int listsw = 0, publicsw = -1, zerosw = 0;
-    int seqp = 0, msgnum, nummsgs, maxmsgs;
+    int seqp = 0, msgnum;
     char *cp, *maildir, *folder = NULL, buf[BUFSIZ];
     char **argp, **arguments;
-    char *seqs[NUMATTRS + 1], **msgs;
+    char *seqs[NUMATTRS + 1];
+    struct msgs_array msgs = { 0, 0, NULL };
     struct msgs *mp;
 
 #ifdef LOCALE
@@ -71,15 +70,6 @@ main (int argc, char **argv)
     arguments = getarguments (invo_name, argc, argv, 1);
     argp = arguments;
 
-    /*
-     * Allocate the initial space to record message
-     * names, ranges, and sequences.
-     */
-    nummsgs = 0;
-    maxmsgs = MAXMSGS;
-    if (!(msgs = (char **) malloc ((size_t) (maxmsgs * sizeof(*msgs)))))
-	adios (NULL, "unable to allocate storage");
-
     /*
      * Parse arguments
      */
@@ -147,20 +137,9 @@ main (int argc, char **argv)
 	    if (folder)
 		adios (NULL, "only one folder at a time!");
 	    else
-		folder = path (cp + 1, *cp == '+' ? TFOLDER : TSUBCWF);
-	} else {
-	    /*
-	     * Check if we need to allocate more space
-	     * for message names/ranges/sequences.
-	     */
-	    if (nummsgs >= maxmsgs) {
-		maxmsgs += MAXMSGS;
-		if (!(msgs = (char **) realloc (msgs,
-						(size_t) (maxmsgs * sizeof(*msgs)))))
-		    adios (NULL, "unable to reallocate msgs storage");
-	    }
-	    msgs[nummsgs++] = cp;
-	}
+		folder = pluspath (cp);
+	} else
+		app_msgarg(&msgs, cp);
     }
 
     /*
@@ -177,8 +156,8 @@ main (int argc, char **argv)
 
     if (!context_find ("path"))
 	free (path ("./", TFOLDER));
-    if (!nummsgs)
-	msgs[nummsgs++] = listsw ? "all" :"cur";
+    if (!msgs.size)
+	app_msgarg(&msgs, listsw ? "all" :"cur");
     if (!folder)
 	folder = getfolder (1);
     maildir = m_maildir (folder);
@@ -199,8 +178,8 @@ main (int argc, char **argv)
 	adios (NULL, "no messages in %s", folder);
 
     /* parse all the message ranges/sequences and set SELECTED */
-    for (msgnum = 0; msgnum < nummsgs; msgnum++)
-	if (!m_convert (mp, msgs[msgnum]))
+    for (msgnum = 0; msgnum < msgs.size; msgnum++)
+	if (!m_convert (mp, msgs.msgs[msgnum]))
 	    done (1);
 
     if (publicsw == 1 && is_readonly(mp))
@@ -249,7 +228,8 @@ main (int argc, char **argv)
     context_replace (pfolder, folder);	/* update current folder         */
     context_save ();			/* save the context file         */
     folder_free (mp);			/* free folder/message structure */
-    return done (0);
+    done (0);
+    return 1;
 }
 
 
