@@ -2,7 +2,7 @@
 /*
  * mhbuild.c -- expand/translate MIME composition files
  *
- * $Id: mhbuild.c,v 1.8 2003/09/30 16:58:43 gbburkhardt Exp $
+ * $Id: mhbuild.c,v 1.12 2007/11/04 11:54:34 jjr Exp $
  *
  * This code is Copyright (c) 2002, by the authors of nmh.  See the
  * COPYRIGHT file in the root directory of the nmh distribution for
@@ -20,6 +20,7 @@
 #include <h/mime.h>
 #include <h/mhparse.h>
 #include <h/mhcachesbr.h>
+#include <h/utils.h>
 
 #ifdef HAVE_SYS_WAIT_H
 # include <sys/wait.h>
@@ -58,11 +59,15 @@ static struct swit switches[] = {
     { "rcache policy", 0 },
 #define	WCACHESW               15
     { "wcache policy", 0 },
-#define VERSIONSW              16
+#define	CONTENTIDSW            16
+    { "contentid", 0 },
+#define	NCONTENTIDSW           17
+    { "nocontentid", 0 },
+#define VERSIONSW              18
     { "version", 0 },
-#define	HELPSW                 17
+#define	HELPSW                 19
     { "help", 0 },
-#define	DEBUGSW                18
+#define	DEBUGSW                20
     { "debug", -5 },
     { NULL, 0 }
 };
@@ -84,6 +89,7 @@ int verbosw = 0;
 int ebcdicsw = 0;
 int listsw   = 0;
 int rfc934sw = 0;
+int contentidsw = 1;
 
 /*
  * Temporary files
@@ -94,6 +100,7 @@ static int unlink_infile  = 0;
 static char outfile[BUFSIZ];
 static int unlink_outfile = 0;
 
+static void unlink_done (int);
 
 /* mhbuildsbr.c */
 CT build_mime (char *);
@@ -120,6 +127,8 @@ main (int argc, char **argv)
     CT ct, cts[2];
     FILE *fp;
 
+    done=unlink_done;
+
 #ifdef LOCALE
     setlocale(LC_ALL, "");
 #endif
@@ -218,6 +227,13 @@ main (int argc, char **argv)
 		sizesw = 0;
 		continue;
 
+	    case CONTENTIDSW:
+		contentidsw = 1;
+		continue;
+	    case NCONTENTIDSW:
+		contentidsw = 0;
+		continue;
+
 	    case VERBSW: 
 		verbosw++;
 		continue;
@@ -365,12 +381,13 @@ main (int argc, char **argv)
     unlink_outfile = 0;
 
     free_content (ct);
-    return done (0);
+    done (0);
+    return 1;
 }
 
 
-int
-done (int status)
+static void
+unlink_done (int status)
 {
     /*
      * Check if we need to remove stray
@@ -382,5 +399,4 @@ done (int status)
 	unlink (outfile);
 
     exit (status);
-    return 1;  /* dead code to satisfy the compiler */
 }
