@@ -3,7 +3,7 @@
  * mhfree.c -- routines to free the data structures used to
  *          -- represent MIME messages
  *
- * $Id: mhfree.c,v 1.4 2003/09/30 16:58:43 gbburkhardt Exp $
+ * $Id: mhfree.c,v 1.7 2007/11/04 11:54:34 jjr Exp $
  *
  * This code is Copyright (c) 2002, by the authors of nmh.  See the
  * COPYRIGHT file in the root directory of the nmh distribution for
@@ -15,6 +15,9 @@
 #include <h/mime.h>
 #include <h/mhparse.h>
 
+/* The list of top-level contents to display */
+CT *cts = NULL;
+
 /*
  * prototypes
  */
@@ -22,6 +25,7 @@ void free_content (CT);
 void free_header (CT);
 void free_ctinfo (CT);
 void free_encoding (CT, int);
+void freects_done (int);
 
 /*
  * static prototypes
@@ -101,6 +105,8 @@ free_content (CT ct)
 	free (ct->c_id);
     if (ct->c_descr)
 	free (ct->c_descr);
+    if (ct->c_dispo)
+	free (ct->c_dispo);
 
     if (ct->c_file) {
 	if (ct->c_unlink)
@@ -279,3 +285,16 @@ free_encoding (CT ct, int toplevel)
 	ct->c_ceopenfnx = NULL;
     }
 }
+
+
+void
+freects_done (int status)
+{
+    CT *ctp;
+
+    if ((ctp = cts))
+	for (; *ctp; ctp++)
+	    free_content (*ctp);
+
+    exit (status);
+}
