@@ -2,7 +2,7 @@
 /*
  * mhl.c -- the nmh message listing program
  *
- * $Id: mhl.c,v 1.4 2002/07/02 22:09:14 kenh Exp $
+ * $Id: mhl.c,v 1.5 2007/11/04 11:54:34 jjr Exp $
  *
  * This code is Copyright (c) 2002, by the authors of nmh.  See the
  * COPYRIGHT file in the root directory of the nmh distribution for
@@ -21,7 +21,8 @@ main (int argc, char **argv)
 #ifdef LOCALE
     setlocale(LC_ALL, "");
 #endif
-    return done (mhl (argc, argv));
+    done (mhl (argc, argv));
+    return 1;
 }
 
 
