@@ -2,11 +2,16 @@
 /*
  * mhmail.c -- simple mail program
  *
- * $Id: mhmail.c,v 1.2 1999/07/16 01:30:05 danh Exp $
+ * $Id: mhmail.c,v 1.6 2008/04/05 19:04:42 pm215 Exp $
+ *
+ * This code is Copyright (c) 2002, by the authors of nmh.  See the
+ * COPYRIGHT file in the root directory of the nmh distribution for
+ * complete copyright information.
  */
 
 #include <h/mh.h>
 #include <h/signals.h>
+#include <h/utils.h>
 #include <signal.h>
 
 static struct swit switches[] = {
@@ -21,7 +26,7 @@ static struct swit switches[] = {
 #define VERSIONSW          4
     { "version", 0 },
 #define	HELPSW             5
-    { "help", 4 },
+    { "help", 0 },
 #define	RESNDSW            6
     { "resent", -6 },
 #define	QUEUESW            7
@@ -168,7 +173,7 @@ main (int argc, char **argv)
 
     if (child_id == NOTOK) {
 	/* report failure and then send it */
-	admonish (NULL, "unable to fork");
+	adios (NULL, "unable to fork");
     } else if (child_id) {
 	/* parent process */
 	if ((status = pidXwait(child_id, postproc))) {
