@@ -2,7 +2,7 @@
 /*
  * mhparse.c -- misc routines to process MIME messages
  *
- * $Id: mhmisc.c,v 1.5 2004/12/17 15:16:04 opk Exp $
+ * $Id: mhmisc.c,v 1.7 2006/03/08 12:14:16 bress Exp $
  *
  * This code is Copyright (c) 2002, by the authors of nmh.  See the
  * COPYRIGHT file in the root directory of the nmh distribution for
@@ -13,6 +13,7 @@
 #include <errno.h>
 #include <h/mime.h>
 #include <h/mhparse.h>
+#include <h/utils.h>
 
 extern int debugsw;
 
@@ -73,7 +74,7 @@ type_ok (CT ct, int sP)
 
     snprintf (buffer, sizeof(buffer), "%s/%s", ci->ci_type, ci->ci_subtype);
     for (ap = types; *ap; ap++)
-	if (!strcasecmp (*ap, ci->ci_type) || !strcasecmp (*ap, buffer))
+	if (!mh_strcasecmp (*ap, ci->ci_type) || !mh_strcasecmp (*ap, buffer))
 	    return 1;
 
     return 0;
