@@ -2,7 +2,7 @@
 /*
  * mhn.c -- display, list, cache, or store the contents of MIME messages
  *
- * $Id: mhn.c,v 1.8 2003/09/30 16:58:43 gbburkhardt Exp $
+ * $Id: mhn.c,v 1.15 2007/11/04 11:54:34 jjr Exp $
  *
  * This code is Copyright (c) 2002, by the authors of nmh.  See the
  * COPYRIGHT file in the root directory of the nmh distribution for
@@ -20,18 +20,12 @@
 #include <h/mime.h>
 #include <h/mhparse.h>
 #include <h/mhcachesbr.h>
+#include <h/utils.h>
 
 #ifdef HAVE_SYS_WAIT_H
 # include <sys/wait.h>
 #endif
 
-/*
- * We allocate space for message names (msgs array)
- * this number of elements at a time.
- */
-#define MAXMSGS  256
-
-
 static struct swit switches[] = {
 #define	AUTOSW                  0
     { "auto", 0 },
@@ -163,9 +157,6 @@ extern int userrs;
 int debugsw = 0;
 int verbosw = 0;
 
-/* The list of top-level contents to display */
-CT *cts = NULL;
-
 /*
  * variables for mhbuild (mhn -build)
  */
@@ -206,6 +197,8 @@ void cache_all_messages (CT *);
 
 /* mhfree.c */
 void free_content (CT);
+extern CT *cts;
+void freects_done (int);
 
 /*
  * static prototypes
@@ -217,14 +210,17 @@ int
 main (int argc, char **argv)
 {
     int sizesw = 1, headsw = 1;
-    int nummsgs, maxmsgs, msgnum, *icachesw;
+    int msgnum, *icachesw;
     char *cp, *file = NULL, *folder = NULL;
     char *maildir, buf[100], **argp;
-    char **arguments, **msgs;
+    char **arguments;
+    struct msgs_array msgs = { 0, 0, NULL };
     struct msgs *mp = NULL;
     CT ct, *ctp;
     FILE *fp;
 
+    done=freects_done;
+
 #ifdef LOCALE
     setlocale(LC_ALL, "");
 #endif
@@ -236,15 +232,6 @@ main (int argc, char **argv)
     arguments = getarguments (invo_name, argc, argv, 1);
     argp = arguments;
 
-    /*
-     * Allocate the initial space to record message
-     * names, ranges, and sequences.
-     */
-    nummsgs = 0;
-    maxmsgs = MAXMSGS;
-    if (!(msgs = (char **) malloc ((size_t) (maxmsgs * sizeof(*msgs)))))
-	adios (NULL, "unable to allocate storage");
-
     /*
      * Parse arguments
      */
@@ -441,20 +428,9 @@ do_cache:
 	    if (folder)
 		adios (NULL, "only one folder at a time!");
 	    else
-		folder = path (cp + 1, *cp == '+' ? TFOLDER : TSUBCWF);
-	} else {
-	    /*
-	     * Check if we need to allocate more space
-	     * for message names/ranges/sequences.
-	     */
-	    if (nummsgs >= maxmsgs) {
-		maxmsgs += MAXMSGS;
-		if (!(msgs = (char **) realloc (msgs,
-			(size_t) (maxmsgs * sizeof(*msgs)))))
-		    adios (NULL, "unable to reallocate msgs storage");
-	    }
-	    msgs[nummsgs++] = cp;
-	}
+		folder = pluspath (cp);
+	} else
+		app_msgarg(&msgs, cp);
     }
 
     /* null terminate the list of acceptable parts/types */
@@ -525,9 +501,9 @@ do_cache:
 
 	if (showsw || storesw || cachesw)
 	    adios (NULL, "cannot use -build with -show, -store, -cache");
-	if (nummsgs < 1)
+	if (msgs.size < 1)
 	    adios (NULL, "need to specify a %s composition file", invo_name);
-	if (nummsgs > 1)
+	if (msgs.size > 1)
 	    adios (NULL, "only one %s composition file at a time", invo_name);
 
 	vecp = 0;
@@ -543,7 +519,7 @@ do_cache:
 	else if (rfc934sw == -1)
 	    vec[vecp++] = "-norfc934mode";
 
-	vec[vecp++] = msgs[0];
+	vec[vecp++] = msgs.msgs[0];
 	vec[vecp] = NULL;
 
 	execvp ("mhbuild", vec);
@@ -554,10 +530,10 @@ do_cache:
     /*
      * Process a mhn composition file (old MH style)
      */
-    if (nummsgs == 1 && !folder && !npart && !cachesw
+    if (msgs.size == 1 && !folder && !npart && !cachesw
 	&& !showsw && !storesw && !ntype && !file
 	&& (cp = getenv ("mhdraft"))
-	&& strcmp (cp, msgs[0]) == 0) {
+	&& strcmp (cp, msgs.msgs[0]) == 0) {
 
 	char *vec[MAXARGS];
 	int vecp;
@@ -583,7 +559,7 @@ do_cache:
 	_exit (-1);
     }
 
-    if (file && nummsgs)
+    if (file && msgs.size)
 	adios (NULL, "cannot specify msg and file at same time!");
 
     /*
@@ -600,8 +576,8 @@ do_cache:
 	/*
 	 * message(s) are coming from a folder
 	 */
-	if (!nummsgs)
-	    msgs[nummsgs++] = "cur";
+	if (!msgs.size)
+	    app_msgarg(&msgs, "cur");
 	if (!folder)
 	    folder = getfolder (1);
 	maildir = m_maildir (folder);
@@ -618,8 +594,8 @@ do_cache:
 	    adios (NULL, "no messages in %s", folder);
 
 	/* parse all the message ranges/sequences and set SELECTED */
-	for (msgnum = 0; msgnum < nummsgs; msgnum++)
-	    if (!m_convert (mp, msgs[msgnum]))
+	for (msgnum = 0; msgnum < msgs.size; msgnum++)
+	    if (!m_convert (mp, msgs.msgs[msgnum]))
 		done (1);
 	seq_setprev (mp);	/* set the previous-sequence */
 
@@ -710,7 +686,8 @@ do_cache:
 	context_save ();		  /* save the context file  */
     }
 
-    return done (0);
+    done (0);
+    return 1;
 }
 
 
@@ -727,17 +704,3 @@ pipeser (int i)
     done (1);
     /* NOTREACHED */
 }
-
-
-int
-done (int status)
-{
-    CT *ctp;
-
-    if ((ctp = cts))
-	for (; *ctp; ctp++)
-	    free_content (*ctp);
-
-    exit (status);
-    return 1;  /* dead code to satisfy the compiler */
-}
