@@ -3,7 +3,11 @@
  * mhoutsbr.c -- routines to output MIME messages
  *            -- given a Content structure
  *
- * $Id: mhoutsbr.c,v 1.2 1999/07/16 01:10:13 danh Exp $
+ * $Id: mhoutsbr.c,v 1.8 2006/03/08 12:14:16 bress Exp $
+ *
+ * This code is Copyright (c) 2002, by the authors of nmh.  See the
+ * COPYRIGHT file in the root directory of the nmh distribution for
+ * complete copyright information.
  */
 
 #include <h/mh.h>
@@ -12,8 +16,8 @@
 #include <h/md5.h>
 #include <errno.h>
 #include <signal.h>
-#include <zotnet/mts/mts.h>
-#include <zotnet/tws/tws.h>
+#include <h/mts.h>
+#include <h/tws.h>
 #include <h/mime.h>
 #include <h/mhparse.h>
 
@@ -22,7 +26,6 @@
 #endif
 
 
-extern int errno;
 extern int ebcdicsw;
 
 static char ebcdicsafe[0x100] = {
@@ -260,7 +263,7 @@ writeExternalBody (CT ct, FILE *out)
 
 	    case 'N':
 		for (ap = ci2->ci_attrs, ep = ci2->ci_values; *ap; ap++, ep++)
-		    if (!strcasecmp (*ap, "name")) {
+		    if (!mh_strcasecmp (*ap, "name")) {
 			fprintf (out, "%s", *ep);
 			break;
 		    }
