@@ -5,7 +5,11 @@
  * Originally contributed by
  * Jeffrey C Honig <Jeffrey_C_Honig@cornell.edu>
  *
- * $Id: mhparam.c,v 1.2 1999/07/16 01:29:28 danh Exp $
+ * $Id: mhparam.c,v 1.6 2007/11/04 11:54:34 jjr Exp $
+ *
+ * This code is Copyright (c) 2002, by the authors of nmh.  See the
+ * COPYRIGHT file in the root directory of the nmh distribution for
+ * complete copyright information.
  */
 
 #include <h/mh.h>
@@ -26,7 +30,7 @@ static struct swit switches[] = {
 #define VERSIONSW 3
     { "version", 0 },
 #define	HELPSW	  4
-    { "help", 4 },
+    { "help", 0 },
 #define DEBUGSW   5
     { "debug", -5 },
     { NULL, 0 }
@@ -177,7 +181,8 @@ main(int argc, char **argv)
 	}
     }
     
-    return done (missed);
+    done (missed);
+    return 1;
 }
 
 
@@ -187,7 +192,7 @@ p_find(char *str)
     struct proc *ps;
 
     for (ps = procs; ps->p_name; ps++)
-	if (!strcasecmp (ps->p_name, str))
+	if (!mh_strcasecmp (ps->p_name, str))
 	    return (*ps->p_field);
 
     return NULL;
