@@ -2,7 +2,7 @@
 /*
  * mhparse.c -- routines to parse the contents of MIME messages
  *
- * $Id: mhparse.c,v 1.12 2005/11/06 00:32:20 pm215 Exp $
+ * $Id: mhparse.c,v 1.18 2008/04/05 18:41:38 pm215 Exp $
  *
  * This code is Copyright (c) 2002, by the authors of nmh.  See the
  * COPYRIGHT file in the root directory of the nmh distribution for
@@ -20,6 +20,7 @@
 #include <h/tws.h>
 #include <h/mime.h>
 #include <h/mhparse.h>
+#include <h/utils.h>
 
 #ifdef HAVE_SYS_WAIT_H
 # include <sys/wait.h>
@@ -126,8 +127,8 @@ CT parse_mime (char *);
  */
 static CT get_content (FILE *, char *, int);
 static int add_header (CT, char *, char *);
-static int get_ctinfo (char *, CT);
-static int get_comment (CT, char **, int);
+static int get_ctinfo (unsigned char *, CT);
+static int get_comment (CT, unsigned char **, int);
 static int InitGeneric (CT);
 static int InitText (CT);
 static int InitMultiPart (CT);
@@ -208,7 +209,8 @@ pidcheck (int status)
 
     fflush (stdout);
     fflush (stderr);
-    return done (1);
+    done (1);
+    return 1;
 }
 
 
@@ -374,9 +376,10 @@ get_content (FILE *in, char *file, int toplevel)
     hp = ct->c_first_hf;	/* start at first header field */
     while (hp) {
 	/* Get MIME-Version field */
-	if (!strcasecmp (hp->name, VRSN_FIELD)) {
+	if (!mh_strcasecmp (hp->name, VRSN_FIELD)) {
 	    int ucmp;
-	    char c, *cp, *dp;
+	    char c;
+	    unsigned char *cp, *dp;
 
 	    if (ct->c_vrsn) {
 		advise (NULL, "message %s has multiple %s: fields",
@@ -406,14 +409,14 @@ get_content (FILE *in, char *file, int toplevel)
 		continue;
 	    c = *dp;
 	    *dp = '\0';
-	    ucmp = !strcasecmp (cp, VRSN_VALUE);
+	    ucmp = !mh_strcasecmp (cp, VRSN_VALUE);
 	    *dp = c;
 	    if (!ucmp) {
 		admonish (NULL, "message %s has unknown value for %s: field (%s)",
 		ct->c_file, VRSN_FIELD, cp);
 	    }
 	}
-	else if (!strcasecmp (hp->name, TYPE_FIELD)) {
+	else if (!mh_strcasecmp (hp->name, TYPE_FIELD)) {
 	/* Get Content-Type field */
 	    struct str2init *s2i;
 	    CI ci = &ct->c_ctinfo;
@@ -434,16 +437,17 @@ get_content (FILE *in, char *file, int toplevel)
 	     * flag for this content type.
 	     */
 	    for (s2i = str2cts; s2i->si_key; s2i++)
-		if (!strcasecmp (ci->ci_type, s2i->si_key))
+		if (!mh_strcasecmp (ci->ci_type, s2i->si_key))
 		    break;
 	    if (!s2i->si_key && !uprf (ci->ci_type, "X-"))
 		s2i++;
 	    ct->c_type = s2i->si_val;
 	    ct->c_ctinitfnx = s2i->si_init;
 	}
-	else if (!strcasecmp (hp->name, ENCODING_FIELD)) {
+	else if (!mh_strcasecmp (hp->name, ENCODING_FIELD)) {
 	/* Get Content-Transfer-Encoding field */
-	    char c, *cp, *dp;
+	    char c;
+	    unsigned char *cp, *dp;
 	    struct str2init *s2i;
 
 	    /*
@@ -471,7 +475,7 @@ get_content (FILE *in, char *file, int toplevel)
 	     * for this transfer encoding.
 	     */
 	    for (s2i = str2ces; s2i->si_key; s2i++)
-		if (!strcasecmp (cp, s2i->si_key))
+		if (!mh_strcasecmp (cp, s2i->si_key))
 		    break;
 	    if (!s2i->si_key && !uprf (cp, "X-"))
 		s2i++;
@@ -482,9 +486,10 @@ get_content (FILE *in, char *file, int toplevel)
 	    if (s2i->si_init && (*s2i->si_init) (ct) == NOTOK)
 		goto out;
 	}
-	else if (!strcasecmp (hp->name, MD5_FIELD)) {
+	else if (!mh_strcasecmp (hp->name, MD5_FIELD)) {
 	/* Get Content-MD5 field */
-	    char *cp, *dp, *ep;
+	    unsigned char *cp, *dp;
+	    char *ep;
 
 	    if (!checksw)
 		goto next_header;
@@ -521,11 +526,11 @@ get_content (FILE *in, char *file, int toplevel)
 	    free (ep);
 	    ct->c_digested++;
 	}
-	else if (!strcasecmp (hp->name, ID_FIELD)) {
+	else if (!mh_strcasecmp (hp->name, ID_FIELD)) {
 	/* Get Content-ID field */
 	    ct->c_id = add (hp->value, ct->c_id);
 	}
-	else if (!strcasecmp (hp->name, DESCR_FIELD)) {
+	else if (!mh_strcasecmp (hp->name, DESCR_FIELD)) {
 	/* Get Content-Description field */
 	    ct->c_descr = add (hp->value, ct->c_descr);
 	}
@@ -584,8 +589,7 @@ add_header (CT ct, char *name, char *value)
     HF hp;
 
     /* allocate header field structure */
-    if (!(hp = malloc (sizeof(*hp))))
-	adios (NULL, "out of memory");
+    hp = mh_xmalloc (sizeof(*hp));
 
     /* link data into header structure */
     hp->name = name;
@@ -611,10 +615,11 @@ add_header (CT ct, char *name, char *value)
  */
 
 static int
-get_ctinfo (char *cp, CT ct)
+get_ctinfo (unsigned char *cp, CT ct)
 {
     int	i;
-    char *dp, **ap, **ep;
+    unsigned char *dp;
+    char **ap, **ep;
     char c;
     CI ci;
 
@@ -708,7 +713,8 @@ magic_skip:
      */
     ep = (ap = ci->ci_attrs) + NPARMS;
     while (*cp == ';') {
-	char *vp, *up;
+	char *vp;
+	unsigned char *up;
 
 	if (ap >= ep) {
 	    advise (NULL,
@@ -812,10 +818,11 @@ bad_quote:
 
 
 static int
-get_comment (CT ct, char **ap, int istype)
+get_comment (CT ct, unsigned char **ap, int istype)
 {
     int i;
-    char *bp, *cp;
+    char *bp;
+    unsigned char *cp;
     char c, buffer[BUFSIZ], *dp;
     CI ci;
 
@@ -907,7 +914,7 @@ InitText (CT ct)
 
     /* match subtype */
     for (kv = SubText; kv->kv_key; kv++)
-	if (!strcasecmp (ci->ci_subtype, kv->kv_key))
+	if (!mh_strcasecmp (ci->ci_subtype, kv->kv_key))
 	    break;
     ct->c_subtype = kv->kv_value;
 
@@ -918,7 +925,7 @@ InitText (CT ct)
 
     /* scan for charset parameter */
     for (ap = ci->ci_attrs, ep = ci->ci_values; *ap; ap++, ep++)
-	if (!strcasecmp (*ap, "charset"))
+	if (!mh_strcasecmp (*ap, "charset"))
 	    break;
 
     if (*ap)
@@ -928,7 +935,7 @@ InitText (CT ct)
 
     /* match character set, or set to unknown */
     for (kv = Charset; kv->kv_key; kv++)
-	if (!strcasecmp (chset, kv->kv_key))
+	if (!mh_strcasecmp (chset, kv->kv_key))
 	    break;
     t->tx_charset = kv->kv_value;
 
@@ -956,7 +963,8 @@ InitMultiPart (CT ct)
 {
     int	inout;
     long last, pos;
-    char *cp, *dp, **ap, **ep;
+    unsigned char *cp, *dp;
+    char **ap, **ep;
     char *bp, buffer[BUFSIZ];
     struct multipart *m;
     struct k2v *kv;
@@ -979,7 +987,7 @@ InitMultiPart (CT ct)
 
     /* match subtype */
     for (kv = SubMultiPart; kv->kv_key; kv++)
-	if (!strcasecmp (ci->ci_subtype, kv->kv_key))
+	if (!mh_strcasecmp (ci->ci_subtype, kv->kv_key))
 	    break;
     ct->c_subtype = kv->kv_value;
 
@@ -989,7 +997,7 @@ InitMultiPart (CT ct)
      */
     bp = 0;
     for (ap = ci->ci_attrs, ep = ci->ci_values; *ap; ap++, ep++) {
-	if (!strcasecmp (*ap, "boundary")) {
+	if (!mh_strcasecmp (*ap, "boundary")) {
 	    bp = *ep;
 	    break;
 	}
@@ -1112,7 +1120,7 @@ last_part:
 	char partnam[BUFSIZ];
 
 	if (ct->c_partno) {
-	    snprintf (partnam, sizeof(partnum), "%s.", ct->c_partno);
+	    snprintf (partnam, sizeof(partnam), "%s.", ct->c_partno);
 	    pp = partnam + strlen (partnam);
 	} else {
 	    pp = partnam;
@@ -1209,7 +1217,7 @@ InitMessage (CT ct)
 
     /* match subtype */
     for (kv = SubMessage; kv->kv_key; kv++)
-	if (!strcasecmp (ci->ci_subtype, kv->kv_key))
+	if (!mh_strcasecmp (ci->ci_subtype, kv->kv_key))
 	    break;
     ct->c_subtype = kv->kv_value;
 
@@ -1228,11 +1236,11 @@ InitMessage (CT ct)
 
 		/* scan for parameters "id", "number", and "total" */
 		for (ap = ci->ci_attrs, ep = ci->ci_values; *ap; ap++, ep++) {
-		    if (!strcasecmp (*ap, "id")) {
+		    if (!mh_strcasecmp (*ap, "id")) {
 			p->pm_partid = add (*ep, NULL);
 			continue;
 		    }
-		    if (!strcasecmp (*ap, "number")) {
+		    if (!mh_strcasecmp (*ap, "number")) {
 			if (sscanf (*ep, "%d", &p->pm_partno) != 1
 			        || p->pm_partno < 1) {
 invalid_param:
@@ -1244,7 +1252,7 @@ invalid_param:
 			}
 			continue;
 		    }
-		    if (!strcasecmp (*ap, "total")) {
+		    if (!mh_strcasecmp (*ap, "total")) {
 			if (sscanf (*ep, "%d", &p->pm_maxno) != 1
 			        || p->pm_maxno < 1)
 			    goto invalid_param;
@@ -1303,8 +1311,7 @@ invalid_param:
 			goto no_body;
 		    }
 		    
-		    if ((e->eb_body = bp = malloc ((unsigned) size)) == NULL)
-			adios (NULL, "out of memory");
+		    e->eb_body = bp = mh_xmalloc ((unsigned) size);
 		    fseek (p->c_fp, p->c_begin, SEEK_SET);
 		    while (size > 0)
 			switch (cc = fread (bp, sizeof(*bp), size, p->c_fp)) {
@@ -1365,12 +1372,12 @@ params_external (CT ct, int composing)
     CI ci = &ct->c_ctinfo;
 
     for (ap = ci->ci_attrs, ep = ci->ci_values; *ap; ap++, ep++) {
-	if (!strcasecmp (*ap, "access-type")) {
+	if (!mh_strcasecmp (*ap, "access-type")) {
 	    struct str2init *s2i;
 	    CT p = e->eb_content;
 
 	    for (s2i = str2methods; s2i->si_key; s2i++)
-		if (!strcasecmp (*ep, s2i->si_key))
+		if (!mh_strcasecmp (*ep, s2i->si_key))
 		    break;
 	    if (!s2i->si_key) {
 		e->eb_access = *ep;
@@ -1387,39 +1394,39 @@ params_external (CT ct, int composing)
 		return NOTOK;
 	    continue;
 	}
-	if (!strcasecmp (*ap, "name")) {
+	if (!mh_strcasecmp (*ap, "name")) {
 	    e->eb_name = *ep;
 	    continue;
 	}
-	if (!strcasecmp (*ap, "permission")) {
+	if (!mh_strcasecmp (*ap, "permission")) {
 	    e->eb_permission = *ep;
 	    continue;
 	}
-	if (!strcasecmp (*ap, "site")) {
+	if (!mh_strcasecmp (*ap, "site")) {
 	    e->eb_site = *ep;
 	    continue;
 	}
-	if (!strcasecmp (*ap, "directory")) {
+	if (!mh_strcasecmp (*ap, "directory")) {
 	    e->eb_dir = *ep;
 	    continue;
 	}
-	if (!strcasecmp (*ap, "mode")) {
+	if (!mh_strcasecmp (*ap, "mode")) {
 	    e->eb_mode = *ep;
 	    continue;
 	}
-	if (!strcasecmp (*ap, "size")) {
+	if (!mh_strcasecmp (*ap, "size")) {
 	    sscanf (*ep, "%lu", &e->eb_size);
 	    continue;
 	}
-	if (!strcasecmp (*ap, "server")) {
+	if (!mh_strcasecmp (*ap, "server")) {
 	    e->eb_server = *ep;
 	    continue;
 	}
-	if (!strcasecmp (*ap, "subject")) {
+	if (!mh_strcasecmp (*ap, "subject")) {
 	    e->eb_subject = *ep;
 	    continue;
 	}
-	if (composing && !strcasecmp (*ap, "body")) {
+	if (composing && !mh_strcasecmp (*ap, "body")) {
 	    e->eb_body = getcpy (*ep);
 	    continue;
 	}
@@ -1448,7 +1455,7 @@ InitApplication (CT ct)
 
     /* match subtype */
     for (kv = SubApplication; kv->kv_key; kv++)
-	if (!strcasecmp (ci->ci_subtype, kv->kv_key))
+	if (!mh_strcasecmp (ci->ci_subtype, kv->kv_key))
 	    break;
     ct->c_subtype = kv->kv_value;
 
@@ -1569,7 +1576,8 @@ openBase64 (CT ct, char **file)
     int fd, len, skip;
     unsigned long bits;
     unsigned char value, *b, *b1, *b2, *b3;
-    char *cp, *ep, buffer[BUFSIZ];
+    unsigned char *cp, *ep;
+    char buffer[BUFSIZ];
     /* sbeck -- handle prefixes */
     CI ci;
     CE ce;
@@ -1780,7 +1788,7 @@ static int
 openQuoted (CT ct, char **file)
 {
     int	cc, digested, len, quoted;
-    char *cp, *ep;
+    unsigned char *cp, *ep;
     char buffer[BUFSIZ];
     unsigned char mask;
     CE ce;
@@ -2226,7 +2234,7 @@ openFile (CT ct, char **file)
 	return NOTOK;
     }
 
-    if ((!e->eb_permission || strcasecmp (e->eb_permission, "read-write"))
+    if ((!e->eb_permission || mh_strcasecmp (e->eb_permission, "read-write"))
 	    && find_cache (NULL, wcachesw, &cachetype, e->eb_content->c_id,
 		cachefile, sizeof(cachefile)) != NOTOK) {
 	int mask;
@@ -2374,7 +2382,7 @@ openFTP (CT ct, char **file)
     ce->ce_unlink = (*file == NULL);
     caching = 0;
     cachefile[0] = '\0';
-    if ((!e->eb_permission || strcasecmp (e->eb_permission, "read-write"))
+    if ((!e->eb_permission || mh_strcasecmp (e->eb_permission, "read-write"))
 	    && find_cache (NULL, wcachesw, &cachetype, e->eb_content->c_id,
 		cachefile, sizeof(cachefile)) != NOTOK) {
 	if (*file == NULL) {
@@ -2410,7 +2418,7 @@ openFTP (CT ct, char **file)
 	vec[vecp++] = e->eb_dir;
 	vec[vecp++] = e->eb_name;
 	vec[vecp++] = ce->ce_file,
-	vec[vecp++] = e->eb_mode && !strcasecmp (e->eb_mode, "ascii")
+	vec[vecp++] = e->eb_mode && !mh_strcasecmp (e->eb_mode, "ascii")
 	    		? "ascii" : "binary";
 	vec[vecp] = NULL;
 
@@ -2447,7 +2455,7 @@ losing_ftp:
     else
 	if (ftp_get (e->eb_site, user, pass, e->eb_dir, e->eb_name,
 		     ce->ce_file,
-		     e->eb_mode && !strcasecmp (e->eb_mode, "ascii"), 0)
+		     e->eb_mode && !mh_strcasecmp (e->eb_mode, "ascii"), 0)
 	        == NOTOK)
 	    goto losing_ftp;
 #endif
@@ -2676,7 +2684,7 @@ invalid_digest:
 	    while (*cp)
 		cp++;
 	    fprintf (stderr, "invalid MD5 digest (got %d octets)\n",
-		     cp - bp);
+		     (int)(cp - bp));
 	}
 
 	return NOTOK;
