@@ -2,33 +2,32 @@
 /*
  * mhpath.c -- print full pathnames of nmh messages and folders
  *
- * $Id: mhpath.c,v 1.2 1999/07/16 01:29:46 danh Exp $
+ * $Id: mhpath.c,v 1.9 2007/11/04 11:54:35 jjr Exp $
+ *
+ * This code is Copyright (c) 2002, by the authors of nmh.  See the
+ * COPYRIGHT file in the root directory of the nmh distribution for
+ * complete copyright information.
  */
 
 #include <h/mh.h>
+#include <h/utils.h>
 
 static struct swit switches[] = {
 #define VERSIONSW 0
     { "version", 0 },
 #define	HELPSW	1
-    { "help", 4 },
+    { "help", 0 },
     { NULL, 0 }
 };
 
-/*
- * Add space for message/sequence names
- * by MAXMSGS at a time.
- */
-#define MAXMSGS 256
-
-
 int
 main(int argc, char **argv)
 {
-    int i, maxmsgs, nummsgs;
+    int i;
     char *cp, *maildir, *folder = NULL;
-    char **argp, **msgs;
+    char **argp;
     char **arguments, buf[BUFSIZ];
+    struct msgs_array msgs = { 0, 0, NULL };
     struct msgs *mp;
 
 #ifdef LOCALE
@@ -42,15 +41,6 @@ main(int argc, char **argv)
     arguments = getarguments (invo_name, argc, argv, 1);
     argp = arguments;
 
-    /*
-     * Allocate initial space to record message
-     * and sequence names
-     */
-    nummsgs = 0;
-    maxmsgs = MAXMSGS;
-    if (!(msgs = (char **) malloc ((size_t) (maxmsgs * sizeof(*msgs)))))
-	adios (NULL, "unable to allocate storage");
-
     /*
      * Parse arguments
      */
@@ -77,20 +67,9 @@ main(int argc, char **argv)
 	    if (folder)
 		adios (NULL, "only one folder at a time!");
 	    else
-		folder = path (cp + 1, *cp == '+' ? TFOLDER : TSUBCWF);
-	} else {
-	    /*
-	     * if necessary, reallocate space for
-	     * message/sequence names
-	     */
-	    if (nummsgs >= maxmsgs) {
-		maxmsgs += MAXMSGS;
-		if (!(msgs = (char **) realloc (msgs,
-			(size_t) (maxmsgs * sizeof(*msgs)))))
-		    adios (NULL, "unable to reallocate msgs storage ");
-	    }
-	    msgs[nummsgs++] = cp;
-	}
+		folder = pluspath (cp);
+	} else
+		app_msgarg(&msgs, cp);
     }
 
     if (!context_find ("path"))
@@ -101,7 +80,7 @@ main(int argc, char **argv)
     maildir = m_maildir (folder);
 
     /* If no messages are given, print folder pathname */
-    if (!nummsgs) {
+    if (!msgs.size) {
 	printf ("%s\n", maildir);
 	done (0);
     }
@@ -130,8 +109,8 @@ main(int argc, char **argv)
     mp->msgflags |= ALLOW_NEW;	/* allow the "new" sequence */
 
     /* parse all the message ranges/sequences and set SELECTED */
-    for (i = 0; i < nummsgs; i++)
-	if (!m_convert (mp, msgs[i]))
+    for (i = 0; i < msgs.size; i++)
+	if (!m_convert (mp, msgs.msgs[i]))
 	    done (1);
 
     seq_setprev (mp);	/* set the previous-sequence */
@@ -144,5 +123,6 @@ main(int argc, char **argv)
     seq_save (mp);	/* synchronize message sequences */
     context_save ();	/* save the context file         */
     folder_free (mp);	/* free folder/message structure */
-    return done (0);
+    done (0);
+    return 1;
 }
