@@ -2,7 +2,7 @@
 /*
  * mhshow.c -- display the contents of MIME messages
  *
- * $Id: mhshow.c,v 1.8 2003/09/30 16:58:43 gbburkhardt Exp $
+ * $Id: mhshow.c,v 1.15 2007/11/04 11:54:35 jjr Exp $
  *
  * This code is Copyright (c) 2002, by the authors of nmh.  See the
  * COPYRIGHT file in the root directory of the nmh distribution for
@@ -20,18 +20,12 @@
 #include <h/mime.h>
 #include <h/mhparse.h>
 #include <h/mhcachesbr.h>
+#include <h/utils.h>
 
 #ifdef HAVE_SYS_WAIT_H
 # include <sys/wait.h>
 #endif
 
-/*
- * We allocate space for message names (msgs array)
- * this number of elements at a time.
- */
-#define MAXMSGS  256
-
-
 static struct swit switches[] = {
 #define	CHECKSW                 0
     { "check", 0 },
@@ -115,9 +109,6 @@ extern int userrs;
 int debugsw = 0;
 int verbosw = 0;
 
-/* The list of top-level contents to display */
-CT *cts = NULL;
-
 #define	quitser	pipeser
 
 /* mhparse.c */
@@ -134,6 +125,8 @@ void show_all_messages (CT *);
 
 /* mhfree.c */
 void free_content (CT);
+extern CT *cts;
+void freects_done (int);
 
 /*
  * static prototypes
@@ -144,14 +137,17 @@ static RETSIGTYPE pipeser (int);
 int
 main (int argc, char **argv)
 {
-    int nummsgs, maxmsgs, msgnum, *icachesw;
+    int msgnum, *icachesw;
     char *cp, *file = NULL, *folder = NULL;
     char *maildir, buf[100], **argp;
-    char **arguments, **msgs;
+    char **arguments;
+    struct msgs_array msgs = { 0, 0, NULL };
     struct msgs *mp = NULL;
     CT ct, *ctp;
     FILE *fp;
 
+    done=freects_done;
+
 #ifdef LOCALE
     setlocale(LC_ALL, "");
 #endif
@@ -163,15 +159,6 @@ main (int argc, char **argv)
     arguments = getarguments (invo_name, argc, argv, 1);
     argp = arguments;
 
-    /*
-     * Allocate the initial space to record message
-     * names, ranges, and sequences.
-     */
-    nummsgs = 0;
-    maxmsgs = MAXMSGS;
-    if (!(msgs = (char **) malloc ((size_t) (maxmsgs * sizeof(*msgs)))))
-	adios (NULL, "unable to allocate storage");
-
     /*
      * Parse arguments
      */
@@ -297,20 +284,9 @@ do_cache:
 	    if (folder)
 		adios (NULL, "only one folder at a time!");
 	    else
-		folder = path (cp + 1, *cp == '+' ? TFOLDER : TSUBCWF);
-	} else {
-	    /*
-	     * Check if we need to allocate more space
-	     * for message names/ranges/sequences.
-	     */
-	    if (nummsgs >= maxmsgs) {
-		maxmsgs += MAXMSGS;
-		if (!(msgs = (char **) realloc (msgs,
-			(size_t) (maxmsgs * sizeof(*msgs)))))
-		    adios (NULL, "unable to reallocate msgs storage");
-	    }
-	    msgs[nummsgs++] = cp;
-	}
+		folder = pluspath (cp);
+	} else
+		app_msgarg(&msgs, cp);
     }
 
     /* null terminate the list of acceptable parts/types */
@@ -366,7 +342,7 @@ do_cache:
     if (!context_find ("path"))
 	free (path ("./", TFOLDER));
 
-    if (file && nummsgs)
+    if (file && msgs.size)
 	adios (NULL, "cannot specify msg and file at same time!");
 
     /*
@@ -383,8 +359,8 @@ do_cache:
 	/*
 	 * message(s) are coming from a folder
 	 */
-	if (!nummsgs)
-	    msgs[nummsgs++] = "cur";
+	if (!msgs.size)
+	    app_msgarg(&msgs, "cur");
 	if (!folder)
 	    folder = getfolder (1);
 	maildir = m_maildir (folder);
@@ -401,8 +377,8 @@ do_cache:
 	    adios (NULL, "no messages in %s", folder);
 
 	/* parse all the message ranges/sequences and set SELECTED */
-	for (msgnum = 0; msgnum < nummsgs; msgnum++)
-	    if (!m_convert (mp, msgs[msgnum]))
+	for (msgnum = 0; msgnum < msgs.size; msgnum++)
+	    if (!m_convert (mp, msgs.msgs[msgnum]))
 		done (1);
 
 	/*
@@ -477,7 +453,8 @@ do_cache:
 	context_save ();		  /* save the context file  */
     }
 
-    return done (0);
+    done (0);
+    return 1;
 }
 
 
@@ -494,17 +471,3 @@ pipeser (int i)
     done (1);
     /* NOTREACHED */
 }
-
-
-int
-done (int status)
-{
-    CT *ctp;
-
-    if ((ctp = cts))
-	for (; *ctp; ctp++)
-	    free_content (*ctp);
-
-    exit (status);
-    return 1;  /* dead code to satisfy the compiler */
-}
