@@ -2,7 +2,7 @@
 /*
  * mhshowsbr.c -- routines to display the contents of MIME messages
  *
- * $Id: mhshowsbr.c,v 1.11 2003/09/30 16:58:43 gbburkhardt Exp $
+ * $Id: mhshowsbr.c,v 1.14 2008/04/11 14:12:55 opk Exp $
  *
  * This code is Copyright (c) 2002, by the authors of nmh.  See the
  * COPYRIGHT file in the root directory of the nmh distribution for
@@ -20,6 +20,7 @@
 #include <h/tws.h>
 #include <h/mime.h>
 #include <h/mhparse.h>
+#include <h/utils.h>
 
 #ifdef HAVE_SYS_WAIT_H
 # include <sys/wait.h>
@@ -118,7 +119,7 @@ show_all_messages (CT *cts)
 	ct = *ctp;
 
 	/* if top-level type is ok, then display message */
-	if (type_ok (ct, 0))
+	if (type_ok (ct, 1))
 	    show_single_message (ct, formsw);
     }
 }
@@ -133,10 +134,10 @@ show_single_message (CT ct, char *form)
 {
     sigset_t set, oset;
 
-#ifdef WAITINT
-    int status;
-#else
+#ifdef HAVE_UNION_WAIT
     union wait status;
+#else
+    int status;
 #endif
 
     /* Allow user executable bit so that temporary directories created by
@@ -171,10 +172,10 @@ show_single_message (CT ct, char *form)
     SIGPROCMASK (SIG_BLOCK, &set, &oset);
 
     while (wait (&status) != NOTOK) {
-#ifdef WAITINT
-	pidcheck (status);
-#else
+#ifdef HAVE_UNION_WAIT
 	pidcheck (status.w_status);
+#else
+	pidcheck (status);
 #endif
 	continue;
     }
@@ -784,10 +785,10 @@ show_multi_internal (CT ct, int serial, int alternate)
     if (serial && !nowserial) {
 	pid_t pid;
 	int kids;
-#ifdef WAITINT
-	int status;
-#else
+#ifdef HAVE_UNION_WAIT
 	union wait status;
+#else
+	int status;
 #endif
 
 	kids = 0;
@@ -803,10 +804,10 @@ show_multi_internal (CT ct, int serial, int alternate)
 	}
 
 	while (kids > 0 && (pid = wait (&status)) != NOTOK) {
-#ifdef WAITINT
-	    pidcheck (status);
-#else
+#ifdef HAVE_UNION_WAIT
 	    pidcheck (status.w_status);
+#else
+	    pidcheck (status);
 #endif
 
 	    for (part = m->mp_parts; part; part = part->mp_next) {
