@@ -2,7 +2,7 @@
 /*
  * msgchk.c -- check for mail
  *
- * $Id: msgchk.c,v 1.11 2005/01/27 16:34:21 opk Exp $
+ * $Id: msgchk.c,v 1.13 2007/11/04 11:54:35 jjr Exp $
  *
  * This code is Copyright (c) 2002, by the authors of nmh.  See the
  * COPYRIGHT file in the root directory of the nmh distribution for
@@ -307,13 +307,12 @@ main (int argc, char **argv)
     if (vecp == 0) {
 	char *home;
 
-	home = (uid = geteuid()) ? home = getenv ("HOME") : NULL;
-	if (home == NULL) {
+        /* Not sure this check makes sense... */
+	if (!geteuid() || NULL == (home = getenv("HOME"))) {
 	    pw = getpwnam (user);
 	    if (pw == NULL)
 		adios (NULL, "unable to get information about user");
-	    if (home == NULL)
-		home = pw->pw_dir;
+	    home = pw->pw_dir;
 	}
 	status = checkmail (user, home, datesw, notifysw, 1);
     } else {
@@ -328,7 +327,8 @@ main (int argc, char **argv)
     }		/* host == NULL */
 #endif
 
-    return done (status);
+    done (status);
+    return 1;
 }
 
 
