@@ -2,7 +2,11 @@
 /*
  * msh.c -- The nmh shell
  *
- * $Id: msh.c,v 1.4 2000/03/06 20:19:04 danh Exp $
+ * $Id: msh.c,v 1.13 2007/11/04 11:54:35 jjr Exp $
+ *
+ * This code is Copyright (c) 2002, by the authors of nmh.  See the
+ * COPYRIGHT file in the root directory of the nmh distribution for
+ * complete copyright information.
  */
 
 /*
@@ -16,8 +20,9 @@
 #include <h/dropsbr.h>
 #include <h/fmt_scan.h>
 #include <h/scansbr.h>
-#include <zotnet/tws/tws.h>
-#include <zotnet/mts/mts.h>
+#include <h/tws.h>
+#include <h/mts.h>
+#include <h/utils.h>
 
 #ifdef HAVE_TERMIOS_H
 # include <termios.h>
@@ -346,7 +351,7 @@ main (int argc, char **argv)
 	    if (folder)
 		adios (NULL, "only one folder at a time!");
 	    else
-		folder = path (cp + 1, *cp == '+' ? TFOLDER : TSUBCWF);
+		folder = pluspath (cp);
 	}
 	else
 	    if (file)
@@ -408,7 +413,8 @@ main (int argc, char **argv)
 
     m_reset ();
     
-    return done (0);
+    done (0);
+    return 1;
 }
 
 
@@ -937,9 +943,7 @@ m_gMsgs (int n)
 	return;
 
     nmsgs = nMsgs + n + MAXFOLDER / 2;
-    Msgs = (struct Msg *) realloc ((char *) Msgs, (size_t) (nmsgs + 2) * sizeof *Msgs);
-    if (Msgs == NULL)
-	padios (NULL, "unable to reallocate Msgs structure");
+    Msgs = (struct Msg *) mh_xrealloc ((char *) Msgs, (size_t) (nmsgs + 2) * sizeof *Msgs);
     memset((char *) (Msgs + nMsgs + 2), 0, (size_t) ((nmsgs - nMsgs) * sizeof *Msgs));
 
     nMsgs = nmsgs;
@@ -1222,7 +1226,7 @@ readid (int msgnum)
 	    case FLD: 
 	    case FLDEOF: 
 	    case FLDPLUS: 
-		if (!strcasecmp (name, BBoard_ID)) {
+		if (!mh_strcasecmp (name, BBoard_ID)) {
 		    bp = getcpy (buf);
 		    while (state == FLDPLUS) {
 			state = m_getfld (state, name, buf, sizeof(buf), zp);
@@ -1541,7 +1545,8 @@ static int
 parse (char *buffer, struct Cmd *cmdp)
 {
     int argp = 0;
-    char c, *cp, *pp;
+    unsigned char c, *cp;
+    char *pp;
 
     cmdp->line[0] = 0;
     pp = cmdp->args[argp++] = cmdp->line;
@@ -1888,7 +1893,7 @@ static int
 pINI (void)
 {
     int i, vrsn;
-    char *bp;
+    unsigned char *bp;
     struct record rcs, *rc;
 
     rc = &rcs;
