@@ -2,7 +2,7 @@
 /*
  * mshcmds.c -- command handlers in msh
  *
- * $Id: mshcmds.c,v 1.12 2003/09/30 16:58:43 gbburkhardt Exp $
+ * $Id: mshcmds.c,v 1.16 2007/04/13 11:53:08 jjr Exp $
  *
  * This code is Copyright (c) 2002, by the authors of nmh.  See the
  * COPYRIGHT file in the root directory of the nmh distribution for
@@ -21,6 +21,7 @@
 #include <signal.h>
 #include <h/msh.h>
 #include <h/picksbr.h>
+#include <h/utils.h>
 
 
 static char delim3[] = "-------";	/* from burst.c */
@@ -592,7 +593,7 @@ filehak (char **args)
 	if (cwd == NULL)
 	    cwd = getcpy (pwd ());
 	chdir (m_maildir (""));
-	cp = path (cp + 1, *cp == '+' ? TFOLDER : TSUBCWF);
+	cp = pluspath (cp);
 	if (access (m_maildir (cp), F_OK) == NOTOK)
 	    result = OK;
 	free (cp);
@@ -702,7 +703,7 @@ foldcmd (char **args)
 		return;
 	    }
 	    else
-		folder = fmsh ? path (cp + 1, *cp == '+' ? TFOLDER : TSUBCWF)
+		folder = fmsh ? pluspath (cp)
 			    : cp + 1;
 	}
 	else
@@ -2160,8 +2161,7 @@ scancmd (char **args)
 		if (*dp == '\\' || *dp == '"' || *dp == '\n')
 		    i++;
 	    i++;
-	    if ((ep = malloc ((unsigned) i)) == NULL)
-		adios (NULL, "out of memory");
+	    ep = mh_xmalloc ((unsigned) i);
 	    for (dp = nfs, fp = ep; *dp; dp++) {
 		if (*dp == '\n') {
 		    *fp++ = '\\', *fp++ = 'n';
@@ -2310,10 +2310,10 @@ showcmd (char **args)
     char *cp, *proc = showproc, buf[BUFSIZ];
     char *msgs[MAXARGS], *vec[MAXARGS];
 
-    if (!strcasecmp (cmd_name, "next"))
+    if (!mh_strcasecmp (cmd_name, "next"))
 	mode = 1;
     else
-	if (!strcasecmp (cmd_name, "prev"))
+	if (!mh_strcasecmp (cmd_name, "prev"))
 	    mode = -1;
     while ((cp = *args++)) {
 	if (*cp == '-')
@@ -2547,7 +2547,8 @@ static int
 is_nontext (int msgnum)
 {
     int	result, state;
-    char *bp, *cp, *dp;
+    unsigned char *bp, *dp;
+    char *cp;
     char buf[BUFSIZ], name[NAMESZ];
     FILE *fp;
 
@@ -2565,7 +2566,7 @@ is_nontext (int msgnum)
 	    /*
 	     * Check Content-Type field
 	     */
-	    if (!strcasecmp (name, TYPE_FIELD)) {
+	    if (!mh_strcasecmp (name, TYPE_FIELD)) {
 		int passno;
 		char c;
 
@@ -2620,7 +2621,7 @@ invalid:
 		if (!*bp)
 		    goto invalid;
 		if (passno > 1) {
-		    if ((result = (strcasecmp (bp, "plain") != 0)))
+		    if ((result = (mh_strcasecmp (bp, "plain") != 0)))
 			goto out;
 		    *dp = c;
 		    for (dp++; isspace (*dp); dp++)
@@ -2652,7 +2653,7 @@ invalid:
 		    /* Check the character set */
 		    result = !check_charset (dp, strlen (dp));
 		} else {
-		    if (!(result = (strcasecmp (bp, "text") != 0))) {
+		    if (!(result = (mh_strcasecmp (bp, "text") != 0))) {
 			*dp = c;
 			bp = dp;
 			passno = 2;
@@ -2671,7 +2672,7 @@ out:
 	    /*
 	     * Check Content-Transfer-Encoding field
 	     */
-	    if (!strcasecmp (name, ENCODING_FIELD)) {
+	    if (!mh_strcasecmp (name, ENCODING_FIELD)) {
 		cp = add (buf, NULL);
 		while (state == FLDPLUS) {
 		    state = m_getfld (state, name, buf, sizeof buf, fp);
@@ -2682,9 +2683,9 @@ out:
 		for (dp = bp; istoken (*dp); dp++)
 		    continue;
 		*dp = '\0';
-		result = (strcasecmp (bp, "7bit")
-		       && strcasecmp (bp, "8bit")
-		       && strcasecmp (bp, "binary"));
+		result = (mh_strcasecmp (bp, "7bit")
+		       && mh_strcasecmp (bp, "8bit")
+		       && mh_strcasecmp (bp, "binary"));
 
 		free (cp);
 		if (result) {
@@ -2868,7 +2869,7 @@ get_fields (char *datesw, char *subjsw, int msgnum, struct Msg *msgp)
 	    case FLD: 
 	    case FLDEOF: 
 	    case FLDPLUS: 
-		if (!strcasecmp (name, datesw)) {
+		if (!mh_strcasecmp (name, datesw)) {
 		    bp = getcpy (buf);
 		    while (state == FLDPLUS) {
 			state = m_getfld (state, name, buf, sizeof buf, zp);
@@ -2885,7 +2886,7 @@ get_fields (char *datesw, char *subjsw, int msgnum, struct Msg *msgp)
 			break;		/* all done! */
 		    gotdate++;
 		}
-		else if (subjsw && !strcasecmp(name, subjsw)) {
+		else if (subjsw && !mh_strcasecmp(name, subjsw)) {
 		    bp = getcpy (buf);
 		    while (state == FLDPLUS) {
 			state = m_getfld (state, name, buf, sizeof buf, zp);
@@ -2960,12 +2961,13 @@ subsort (struct Msg *a, struct Msg *b)
 static char *
 sosmash (char *subj, char *s)
 {
-    register char *cp, *dp, c;
+    register char *cp, *dp;
+    register unsigned char c;
 
     if (s) {
 	cp = s;
 	dp = s;	/* dst pointer */
-	if (!strcasecmp (subj, "subject"))
+	if (!mh_strcasecmp (subj, "subject"))
 	    while ((c = *cp)) {
 		if (! isspace(c)) {
 		    if(uprf(cp, "re:"))
