@@ -2,7 +2,7 @@
 /*
  * pick.c -- search for messages by content
  *
- * $Id: pick.c,v 1.6 2003/09/30 14:19:20 gbburkhardt Exp $
+ * $Id: pick.c,v 1.12 2007/11/04 11:54:35 jjr Exp $
  *
  * This code is Copyright (c) 2002, by the authors of nmh.  See the
  * COPYRIGHT file in the root directory of the nmh distribution for
@@ -12,13 +12,7 @@
 #include <h/mh.h>
 #include <h/tws.h>
 #include <h/picksbr.h>
-
-/*
- * We allocate space for messages (msgs array)
- * this number of elements at a time.
- */
-#define MAXMSGS  256
-
+#include <h/utils.h>
 
 static struct swit switches[] = {
 #define	ANDSW                   0
@@ -74,18 +68,22 @@ static struct swit switches[] = {
 
 static int listsw = -1;
 
+static void putzero_done (int);
 
 int
 main (int argc, char **argv)
 {
     int publicsw = -1, zerosw = 1, seqp = 0, vecp = 0;
-    int nummsgs, maxmsgs, lo, hi, msgnum;
+    int lo, hi, msgnum;
     char *maildir, *folder = NULL, buf[100];
     char *cp, **argp, **arguments;
-    char **msgs, *seqs[NUMATTRS + 1], *vec[MAXARGS];
+    char *seqs[NUMATTRS + 1], *vec[MAXARGS];
+    struct msgs_array msgs = { 0, 0, NULL };
     struct msgs *mp;
     register FILE *fp;
 
+    done=putzero_done;
+
 #ifdef LOCALE
     setlocale(LC_ALL, "");
 #endif
@@ -97,15 +95,6 @@ main (int argc, char **argv)
     arguments = getarguments (invo_name, argc, argv, 1);
     argp = arguments;
 
-    /*
-     * Allocate the initial space to record message
-     * names, ranges, and sequences.
-     */
-    nummsgs = 0;
-    maxmsgs = MAXMSGS;
-    if (!(msgs = (char **) malloc ((size_t) (maxmsgs * sizeof(*msgs)))))
-	adios (NULL, "unable to allocate storage");
-
     while ((cp = *argp++)) {
 	if (*cp == '-') {
 	    if (*++cp == '-') {
@@ -191,20 +180,9 @@ main (int argc, char **argv)
 	    if (folder)
 		adios (NULL, "only one folder at a time!");
 	    else
-		folder = path (cp + 1, *cp == '+' ? TFOLDER : TSUBCWF);
-	} else {
-	    /*
-	     * Check if we need to allocate more space
-	     * for message name/ranges/sequences.
-	     */
-	    if (nummsgs >= maxmsgs) {
-		maxmsgs += MAXMSGS;
-		if (!(msgs = (char **) realloc (msgs,
-						(size_t) (maxmsgs * sizeof(*msgs)))))
-		    adios (NULL, "unable to reallocate msgs storage");
-	    }
-	    msgs[nummsgs++] = cp;
-	}
+		folder = pluspath (cp);
+	} else
+		app_msgarg(&msgs, cp);
     }
     vec[vecp] = NULL;
 
@@ -215,8 +193,8 @@ main (int argc, char **argv)
      * If we didn't specify which messages to search,
      * then search the whole folder.
      */
-    if (!nummsgs)
-	msgs[nummsgs++] = "all";
+    if (!msgs.size)
+	app_msgarg(&msgs, "all");
 
     if (!folder)
 	folder = getfolder (1);
@@ -234,8 +212,8 @@ main (int argc, char **argv)
 	adios (NULL, "no messages in %s", folder);
 
     /* parse all the message ranges/sequences and set SELECTED */
-    for (msgnum = 0; msgnum < nummsgs; msgnum++)
-	if (!m_convert (mp, msgs[msgnum]))
+    for (msgnum = 0; msgnum < msgs.size; msgnum++)
+	if (!m_convert (mp, msgs.msgs[msgnum]))
 	    done (1);
     seq_setprev (mp);	/* set the previous-sequence */
 
@@ -308,15 +286,15 @@ main (int argc, char **argv)
     seq_save (mp);			/* synchronize message sequences */
     context_save ();			/* save the context file         */
     folder_free (mp);			/* free folder/message structure */
-    return done (0);
+    done (0);
+    return 1;
 }
 
 
-int
-done (int status)
+static void
+putzero_done (int status)
 {
     if (listsw && status && !isatty (fileno (stdout)))
 	printf ("0\n");
     exit (status);
-    return 1;  /* dead code to satisfy the compiler */
 }
