@@ -2,7 +2,7 @@
 /*
  * popi.c -- POP initiator for MPOP
  *
- * $Id: popi.c,v 1.8 2005/01/27 16:34:21 opk Exp $
+ * $Id: popi.c,v 1.11 2006/04/27 12:00:28 jjr Exp $
  *
  * This code is Copyright (c) 2002, by the authors of nmh.  See the
  * COPYRIGHT file in the root directory of the nmh distribution for
@@ -13,6 +13,7 @@
 #include <h/fmt_scan.h>
 #include <h/scansbr.h>
 #include <h/mts.h>
+#include <h/utils.h>
 #include <errno.h>
 
 #ifndef	RPOP
@@ -190,7 +191,7 @@ main (int argc, char **argv)
 	    if (folder)
 		adios (NULL, "only one folder at a time!");
 	    else
-		folder = path (cp + 1, *cp == '+' ? TFOLDER : TSUBCWF);
+		folder = pluspath (cp);
 	}
 	else
 	    adios (NULL, "usage: %s [+folder] [switches]", invo_name);
@@ -228,16 +229,7 @@ main (int argc, char **argv)
 	folder = getfolder (0);
     maildir = m_maildir (folder);
 
-    if (stat (maildir, &st) == NOTOK) {
-	if (errno != ENOENT)
-	    adios (maildir, "error on folder");
-	cp = concat ("Create folder \"", maildir, "\"? ", NULL);
-	if (noisy && !getanswer (cp))
-	    done (1);
-	free (cp);
-	if (!makedir (maildir))
-	    adios (NULL, "unable to create folder %s", maildir);
-    }
+    create_folder(maildir, 0, done);
 
     if (chdir (maildir) == NOTOK)
 	adios (maildir, "unable to change directory to");
@@ -402,8 +394,7 @@ popi (void)
 			if (*dp == '\\' || *dp == '"' || *dp == '\n')
 			    i++;
 		    i++;
-		    if ((ep = malloc ((unsigned) i)) == NULL)
-			adios (NULL, "out of memory");
+		    ep = mh_xmalloc ((unsigned) i);
 		    for (dp = nfs, fp = ep; *dp; dp++) {
 			if (*dp == '\n') {
 			    *fp++ = '\\', *fp++ = 'n';
