@@ -1,7 +1,7 @@
 /*
  * popsbr.c -- POP client subroutines
  *
- * $Id: popsbr.c,v 1.13 2005/11/06 00:34:56 pm215 Exp $
+ * $Id: popsbr.c,v 1.19 2007/11/08 02:28:39 jjr Exp $
  *
  * This code is Copyright (c) 2002, by the authors of nmh.  See the
  * COPYRIGHT file in the root directory of the nmh distribution for
@@ -9,6 +9,7 @@
  */
 
 #include <h/mh.h>
+#include <h/utils.h>
 
 extern int  client(char *args, char *protocol, char *service, int rproto,
 		   char *response, int len_response);
@@ -103,9 +104,9 @@ static int pop_auth_sasl(char *, char *, char *);
 static int sasl_fgetc(FILE *);
 #endif /* CYRUS_SASL */
 
-static int traverse (int (*)(), const char *, ...);
+static int traverse (int (*)(char *), const char *, ...);
 static int vcommand(const char *, va_list);
-static int getline (char *, int, FILE *);
+static int sasl_getline (char *, int, FILE *);
 static int putline (char *, FILE *);
 
 
@@ -432,10 +433,7 @@ sasl_get_pass(sasl_conn_t *conn, void *context, int id, sasl_secret_t **psecret)
 
     len = strlen(pass);
 
-    *psecret = (sasl_secret_t *) malloc(sizeof(sasl_secret_t) + len);
-
-    if (! *psecret)
-	return SASL_NOMEM;
+    *psecret = (sasl_secret_t *) mh_xmalloc(sizeof(sasl_secret_t) + len);
 
     (*psecret)->len = len;
     strcpy((char *) (*psecret)->data, pass);
@@ -457,7 +455,7 @@ parse_proxy(char *proxy, char *host)
     int pargc = 2;
     int hlen = strlen(host);
     int plen = 1;
-    char *cur, *pro;
+    unsigned char *cur, *pro;
     char *c;
     
     /* skip any initial space */
@@ -476,8 +474,8 @@ parse_proxy(char *proxy, char *host)
     }
 
    /* put together list of arguments */
-    p = pargv = malloc(pargc * sizeof(char *));
-    c = *pargv = malloc(plen * sizeof(char));
+    p = pargv = mh_xmalloc(pargc * sizeof(char *));
+    c = *pargv = mh_xmalloc(plen * sizeof(char));
     for (cur = pro; *cur; cur++) {
         if (isspace(*cur) && cur[1] && !isspace(cur[1])) {
 	    *c++ = '\0';
@@ -599,7 +597,7 @@ pop_init (char *host, char *user, char *pass, char *proxy, int snoop,
 
     SIGNAL (SIGPIPE, SIG_IGN);
 
-    switch (getline (response, sizeof response, input)) {
+    switch (sasl_getline (response, sizeof response, input)) {
 	case OK: 
 	    if (poprint)
 		fprintf (stderr, "<--- %s\n", response);
@@ -825,7 +823,7 @@ pop_list (int msgno, int *nmsgs, int *msgs, int *bytes)
 
 
 int
-pop_retr (int msgno, int (*action)())
+pop_retr (int msgno, int (*action)(char *))
 {
 #ifndef NNTP
     return traverse (action, "RETR %d", (targ_t) msgno);
@@ -836,7 +834,7 @@ pop_retr (int msgno, int (*action)())
 
 
 static int
-traverse (int (*action)(), const char *fmt, ...)
+traverse (int (*action)(char *), const char *fmt, ...)
 {
     int result;
     va_list ap;
@@ -897,7 +895,7 @@ pop_rset (void)
 
 
 int
-pop_top (int msgno, int lines, int (*action)())
+pop_top (int msgno, int lines, int (*action)(char *))
 {
 #ifndef NNTP
     return traverse (action, "TOP %d %d", (targ_t) msgno, (targ_t) lines);
@@ -930,20 +928,20 @@ pop_xtnd (int (*action)(), char *fmt, ...)
     snprintf (buffer, sizeof(buffer), fmt, a, b, c, d);
     ap = brkstring (buffer, " ", "\n");	/* a hack, i know... */
 
-    if (!strcasecmp(ap[0], "x-bboards")) {	/* XTND "X-BBOARDS group */
+    if (!mh_strcasecmp(ap[0], "x-bboards")) {	/* XTND "X-BBOARDS group */
 	/* most of these parameters are meaningless under NNTP. 
 	 * bbc.c was modified to set AKA and LEADERS as appropriate,
 	 * the rest are left blank.
 	 */
 	return OK;
     }
-    if (!strcasecmp (ap[0], "archive") && ap[1]) {
+    if (!mh_strcasecmp (ap[0], "archive") && ap[1]) {
 	snprintf (xtnd_name, sizeof(xtnd_name), "%s", ap[1]);	/* save the name */
 	xtnd_last = 0;
 	xtnd_first = 1;		/* setup to fail in pop_stat */
 	return OK;
     }
-    if (!strcasecmp (ap[0], "bboards")) {
+    if (!mh_strcasecmp (ap[0], "bboards")) {
 
 	if (ap[1]) {			/* XTND "BBOARDS group" */
 	    snprintf (xtnd_name, sizeof(xtnd_name), "%s", ap[1]);	/* save the name */
@@ -1043,7 +1041,7 @@ vcommand (const char *fmt, va_list ap)
 	fprintf(stderr, "(decrypted) ");
 #endif /* CYRUS_SASL */
 
-    switch (getline (response, sizeof response, input)) {
+    switch (sasl_getline (response, sizeof response, input)) {
 	case OK: 
 	    if (poprint)
 		fprintf (stderr, "<--- %s\n", response);
@@ -1074,7 +1072,7 @@ multiline (void)
 {
     char buffer[BUFSIZ + TRMLEN];
 
-    if (getline (buffer, sizeof buffer, input) != OK)
+    if (sasl_getline (buffer, sizeof buffer, input) != OK)
 	return NOTOK;
 #ifdef DEBUG
     if (poprint) {
@@ -1103,7 +1101,7 @@ multiline (void)
  */
 
 static int
-getline (char *s, int n, FILE *iop)
+sasl_getline (char *s, int n, FILE *iop)
 {
     int c;
     char *p;
@@ -1240,12 +1238,7 @@ sasl_fgetc(FILE *f)
     }
 
     if (retbufsize > size) {
-	buffer = realloc(buffer, retbufsize);
-	if (!buffer) {
-	    snprintf(response, sizeof(response), "Error during realloc in "
-		     "read routine: %s", strerror(errno));
-	    return -2;
-	}
+	buffer = mh_xrealloc(buffer, retbufsize);
 	size = retbufsize;
     }
 
