@@ -2,7 +2,7 @@
 /*
  * prompter.c -- simple prompting editor front-end
  *
- * $Id: prompter.c,v 1.5 2003/09/30 16:58:43 gbburkhardt Exp $
+ * $Id: prompter.c,v 1.6 2007/11/04 11:54:35 jjr Exp $
  *
  * This code is Copyright (c) 2002, by the authors of nmh.  See the
  * COPYRIGHT file in the root directory of the nmh distribution for
@@ -400,7 +400,8 @@ no_body:
     unlink (tmpfil);
 
     context_save ();	/* save the context file */
-    return done (0);
+    done (0);
+    return 1;
 }
 
 
