@@ -2,14 +2,19 @@
 /*
  * rcvdist.c -- asynchronously redistribute messages
  *
- * $Id: rcvdist.c,v 1.4 2000/02/04 20:28:24 danh Exp $
+ * $Id: rcvdist.c,v 1.12 2007/11/04 11:54:35 jjr Exp $
+ *
+ * This code is Copyright (c) 2002, by the authors of nmh.  See the
+ * COPYRIGHT file in the root directory of the nmh distribution for
+ * complete copyright information.
  */
 
 #include <h/mh.h>
 #include <h/fmt_scan.h>
 #include <h/rcvmail.h>
-#include <zotnet/tws/tws.h>
-#include <zotnet/mts/mts.h>
+#include <h/tws.h>
+#include <h/mts.h>
+#include <h/utils.h>
 
 static struct swit switches[] = {
 #define	FORMSW       0
@@ -29,7 +34,7 @@ static char tmpfil[BUFSIZ] = "";
  * prototypes
  */
 static void rcvdistout (FILE *, char *, char *);
-int done (int);
+static void unlink_done (int);
 
 
 int
@@ -41,6 +46,8 @@ main (int argc, char **argv)
     char **argp, **arguments, *vec[MAXARGS];
     register FILE *fp;
 
+    done=unlink_done;
+
 #ifdef LOCALE
     setlocale(LC_ALL, "");
 #endif
@@ -177,8 +184,7 @@ rcvdistout (FILE *inb, char *form, char *addrs)
     *--savecomp = 0;
 
     for (i = ncomps; i--;)
-	if (!(*nxtbuf++ = malloc (SBUFSIZ)))
-	    adios (NULL, "unable to allocate component buffer");
+	*nxtbuf++ = mh_xmalloc (SBUFSIZ);
     nxtbuf = compbuffers;
     tmpbuf = *nxtbuf++;
 
@@ -198,7 +204,7 @@ rcvdistout (FILE *inb, char *form, char *addrs)
 	    case FLDPLUS: 
 		if ((cptr = wantcomp[CHASH (name)]))
 		    do {
-			if (!strcasecmp (name, cptr->c_name)) {
+			if (!mh_strcasecmp (name, cptr->c_name)) {
 			    char_read += msg_count;
 			    if (!cptr->c_text) {
 				cptr->c_text = tmpbuf;
@@ -244,7 +250,7 @@ rcvdistout (FILE *inb, char *form, char *addrs)
 finished: ;
 
     i = format_len + char_read + 256;
-    scanl = malloc ((size_t) i + 2);
+    scanl = mh_xmalloc ((size_t) i + 2);
     dat[0] = dat[1] = dat[2] = dat[4] = 0;
     dat[3] = outputlinelen;
     fmt_scan (fmt, scanl, i, dat);
@@ -264,8 +270,8 @@ finished: ;
 }
 
 
-int
-done (int status)
+static void
+unlink_done (int status)
 {
     if (backup[0])
 	unlink (backup);
@@ -275,5 +281,4 @@ done (int status)
 	unlink (tmpfil);
 
     exit (status ? RCV_MBX : RCV_MOK);
-    return 1;  /* dead code to satisfy the compiler */
 }
