@@ -2,14 +2,18 @@
 /*
  * rcvpack.c -- append message to a file
  *
- * $Id: rcvpack.c,v 1.3 2000/02/04 20:28:24 danh Exp $
+ * $Id: rcvpack.c,v 1.8 2007/11/04 11:54:35 jjr Exp $
+ *
+ * This code is Copyright (c) 2002, by the authors of nmh.  See the
+ * COPYRIGHT file in the root directory of the nmh distribution for
+ * complete copyright information.
  */
 
 #include <h/mh.h>
 #include <h/dropsbr.h>
 #include <h/rcvmail.h>
-#include <zotnet/tws/tws.h>
-#include <zotnet/mts/mts.h>
+#include <h/tws.h>
+#include <h/mts.h>
 
 static struct swit switches[] = {
 #define MBOXSW       0
@@ -99,5 +103,6 @@ main (int argc, char **argv)
     if (mbx_close (file, md) == NOTOK)
 	done (RCV_MBX);
 
-    return done (RCV_MOK);
+    done (RCV_MOK);
+    return 1;
 }
