@@ -3,7 +3,7 @@
  * refile.c -- move or link message(s) from a source folder
  *          -- into one or more destination folders
  *
- * $Id: refile.c,v 1.7 2004/11/19 05:06:16 jon Exp $
+ * $Id: refile.c,v 1.14 2007/11/04 11:54:36 jjr Exp $
  *
  * This code is Copyright (c) 2002, by the authors of nmh.  See the
  * COPYRIGHT file in the root directory of the nmh distribution for
@@ -11,16 +11,10 @@
  */
 
 #include <h/mh.h>
+#include <h/utils.h>
 #include <fcntl.h>
 #include <errno.h>
 
-/*
- * We allocate spaces for messages (msgs array)
- * this number of elements at a time.
- */
-#define MAXMSGS  256
-
-
 static struct swit switches[] = {
 #define	DRAFTSW          0
     { "draft", 0 },
@@ -72,12 +66,13 @@ main (int argc, char **argv)
 {
     int	linkf = 0, preserve = 0, filep = 0;
     int foldp = 0, isdf = 0, unlink_msgs = 0;
-    int i, msgnum, nummsgs, maxmsgs;
+    int i, msgnum;
     char *cp, *folder = NULL, buf[BUFSIZ];
-    char **argp, **arguments, **msgs;
+    char **argp, **arguments;
     char *filevec[NFOLDERS + 2];
     char **files = &filevec[1];	   /* leave room for remove_files:vec[0] */
     struct st_fold folders[NFOLDERS + 1];
+    struct msgs_array msgs = { 0, 0, NULL };
     struct msgs *mp;
 
 #ifdef LOCALE
@@ -91,15 +86,6 @@ main (int argc, char **argv)
     arguments = getarguments (invo_name, argc, argv, 1);
     argp = arguments;
 
-    /*
-     * Allocate the initial space to record message
-     * names, ranges, and sequences.
-     */
-    nummsgs = 0;
-    maxmsgs = MAXMSGS;
-    if (!(msgs = (char **) malloc ((size_t) (maxmsgs * sizeof(*msgs)))))
-	adios (NULL, "unable to allocate storage");
-
     /*
      * Parse arguments
      */
@@ -177,20 +163,9 @@ main (int argc, char **argv)
 	    if (foldp > NFOLDERS)
 		adios (NULL, "only %d folders allowed!", NFOLDERS);
 	    folders[foldp++].f_name =
-		path (cp + 1, *cp == '+' ? TFOLDER : TSUBCWF);
-	} else {
-	    /*
-	     * Check if we need to allocate more space
-	     * for message names, ranges, and sequences.
-	     */
-	    if (nummsgs >= maxmsgs) {
-		maxmsgs += MAXMSGS;
-		if (!(msgs = (char **) realloc (msgs,
-						(size_t) (maxmsgs * sizeof(*msgs)))))
-		    adios (NULL, "unable to reallocate msgs storage");
-	    }
-	    msgs[nummsgs++] = cp;
-	}
+		pluspath (cp);
+	} else
+		app_msgarg(&msgs, cp);
     }
 
     if (!context_find ("path"))
@@ -199,7 +174,7 @@ main (int argc, char **argv)
 	adios (NULL, "no folder specified");
 
 #ifdef WHATNOW
-    if (!nummsgs && !foldp && !filep && (cp = getenv ("mhdraft")) && *cp)
+    if (!msgs.size && !foldp && !filep && (cp = getenv ("mhdraft")) && *cp)
 	files[filep++] = cp;
 #endif /* WHATNOW */
 
@@ -207,7 +182,7 @@ main (int argc, char **argv)
      * We are refiling a file to the folders
      */
     if (filep > 0) {
-	if (folder || nummsgs)
+	if (folder || msgs.size)
 	    adios (NULL, "use -file or some messages, not both");
 	opnfolds (folders, foldp);
 	for (i = 0; i < filep; i++)
@@ -219,8 +194,8 @@ main (int argc, char **argv)
 	done (0);
     }
 
-    if (!nummsgs)
-	msgs[nummsgs++] = "cur";
+    if (!msgs.size)
+	app_msgarg(&msgs, "cur");
     if (!folder)
 	folder = getfolder (1);
     strncpy (maildir, m_maildir (folder), sizeof(maildir));
@@ -237,8 +212,8 @@ main (int argc, char **argv)
 	adios (NULL, "no messages in %s", folder);
 
     /* parse the message range/sequence/name and set SELECTED */
-    for (msgnum = 0; msgnum < nummsgs; msgnum++)
-	if (!m_convert (mp, msgs[msgnum]))
+    for (msgnum = 0; msgnum < msgs.size; msgnum++)
+	if (!m_convert (mp, msgs.msgs[msgnum]))
 	    done (1);
     seq_setprev (mp);	/* set the previous-sequence */
 
@@ -291,7 +266,8 @@ main (int argc, char **argv)
     context_replace (pfolder, folder);	/* update current folder   */
     context_save ();			/* save the context file   */
     folder_free (mp);			/* free folder structure   */
-    return done (0);
+    done (0);
+    return 1;
 }
 
 
@@ -303,26 +279,15 @@ main (int argc, char **argv)
 static void
 opnfolds (struct st_fold *folders, int nfolders)
 {
-    register char *cp;
     char nmaildir[BUFSIZ];
     register struct st_fold *fp, *ep;
     register struct msgs *mp;
-    struct stat st;
 
     for (fp = folders, ep = folders + nfolders; fp < ep; fp++) {
 	chdir (m_maildir (""));
 	strncpy (nmaildir, m_maildir (fp->f_name), sizeof(nmaildir));
 
-	if (stat (nmaildir, &st) == NOTOK) {
-	    if (errno != ENOENT)
-		adios (nmaildir, "error on folder");
-	    cp = concat ("Create folder \"", nmaildir, "\"? ", NULL);
-	    if (!getanswer (cp))
-		done (1);
-	    free (cp);
-	    if (!makedir (nmaildir))
-		adios (NULL, "unable to create folder %s", nmaildir);
-	}
+    create_folder (nmaildir, 0, done);
 
 	if (chdir (nmaildir) == NOTOK)
 	    adios (nmaildir, "unable to change directory to");
