@@ -2,10 +2,15 @@
 /*
  * repl.c -- reply to a message
  *
- * $Id: repl.c,v 1.5 2000/02/04 20:28:24 danh Exp $
+ * $Id: repl.c,v 1.9 2007/11/04 11:54:36 jjr Exp $
+ *
+ * This code is Copyright (c) 2002, by the authors of nmh.  See the
+ * COPYRIGHT file in the root directory of the nmh distribution for
+ * complete copyright information.
  */
 
 #include <h/mh.h>
+#include <h/utils.h>
 
 
 static struct swit switches[] = {
@@ -314,7 +319,7 @@ main (int argc, char **argv)
 	    if (folder)
 		adios (NULL, "only one folder at a time!");
 	    else
-		folder = path (cp + 1, *cp == '+' ? TFOLDER : TSUBCWF);
+		folder = pluspath (cp);
 	} else {
 	    if (msg)
 		adios (NULL, "only one message at a time!");
@@ -437,7 +442,8 @@ try_it_again:
 	done (0);
     what_now (ed, nedit, NOUSE, drft, msg, 0, mp,
 	    anot ? "Replied" : NULL, inplace, cwd);
-    return done (1);
+    done (1);
+    return 1;
 }
 
 void
