@@ -2,7 +2,7 @@
 /*
  * rmm.c -- remove a message(s)
  *
- * $Id: rmm.c,v 1.5 2002/08/23 20:37:01 jon Exp $
+ * $Id: rmm.c,v 1.10 2007/11/04 11:54:36 jjr Exp $
  *
  * This code is Copyright (c) 2002, by the authors of nmh.  See the
  * COPYRIGHT file in the root directory of the nmh distribution for
@@ -10,12 +10,7 @@
  */
 
 #include <h/mh.h>
-
-/*
- * We allocate space for message names and ranges
- * (msgs array) this number of elements at a time.
- */
-#define MAXMSGS  256
+#include <h/utils.h>
 
 static struct swit switches[] = {
 #define UNLINKSW      0
@@ -33,10 +28,11 @@ static struct swit switches[] = {
 int
 main (int argc, char **argv)
 {
-    int nummsgs, maxmsgs, msgnum, unlink_msgs = 0;
+    int msgnum, unlink_msgs = 0;
     char *cp, *maildir, *folder = NULL;
     char buf[BUFSIZ], **argp;
-    char **arguments, **msgs;
+    char **arguments;
+    struct msgs_array msgs = { 0, 0, NULL };
     struct msgs *mp;
 
 #ifdef LOCALE
@@ -50,15 +46,6 @@ main (int argc, char **argv)
     arguments = getarguments (invo_name, argc, argv, 1);
     argp = arguments;
 
-    /*
-     * Allocate the initial space to record message
-     * names and ranges.
-     */
-    nummsgs = 0;
-    maxmsgs = MAXMSGS;
-    if (!(msgs = (char **) malloc ((size_t) (maxmsgs * sizeof(*msgs)))))
-	adios (NULL, "unable to allocate storage");
-
     /* parse arguments */
     while ((cp = *argp++)) {
 	if (*cp == '-') {
@@ -90,26 +77,15 @@ main (int argc, char **argv)
 	    if (folder)
 		adios (NULL, "only one folder at a time!");
 	    else
-		folder = path (cp + 1, *cp == '+' ? TFOLDER : TSUBCWF);
-	} else {
-	    /*
-	     * Check if we need to allocate more space
-	     * for message names/ranges.
-	     */
-	    if (nummsgs >= maxmsgs){
-		maxmsgs += MAXMSGS;
-		if (!(msgs = (char **) realloc (msgs,
-			     (size_t) (maxmsgs * sizeof(*msgs)))))
-		    adios (NULL, "unable to reallocate msgs storage");
-	    }
-	    msgs[nummsgs++] = cp;
-	}
+		folder = pluspath (cp);
+	} else
+		app_msgarg(&msgs, cp);
     }
 
     if (!context_find ("path"))
 	free (path ("./", TFOLDER));
-    if (!nummsgs)
-	msgs[nummsgs++] = "cur";
+    if (!msgs.size)
+	app_msgarg(&msgs, "cur");
     if (!folder)
 	folder = getfolder (1);
     maildir = m_maildir (folder);
@@ -126,8 +102,8 @@ main (int argc, char **argv)
 	adios (NULL, "no messages in %s", folder);
 
     /* parse all the message ranges/sequences and set SELECTED */
-    for (msgnum = 0; msgnum < nummsgs; msgnum++)
-	if (!m_convert (mp, msgs[msgnum]))
+    for (msgnum = 0; msgnum < msgs.size; msgnum++)
+	if (!m_convert (mp, msgs.msgs[msgnum]))
 	    done (1);
     seq_setprev (mp);		/* set the previous-sequence      */
 
@@ -151,5 +127,6 @@ main (int argc, char **argv)
     context_replace (pfolder, folder);	/* update current folder   */
     context_save ();			/* save the context file   */
     folder_free (mp);			/* free folder structure   */
-    return done (0);
+    done (0);
+    return 1;
 }
