@@ -2,7 +2,7 @@
 /*
  * scansbr.c -- routines to help scan along...
  *
- * $Id: scansbr.c,v 1.6 2003/08/11 01:20:52 jchonig Exp $
+ * $Id: scansbr.c,v 1.11.2.1 2008/05/22 10:42:09 pm215 Exp $
  *
  * This code is Copyright (c) 2002, by the authors of nmh.  See the
  * COPYRIGHT file in the root directory of the nmh distribution for
@@ -14,6 +14,7 @@
 #include <h/fmt_scan.h>
 #include <h/scansbr.h>
 #include <h/tws.h>
+#include <h/utils.h>
 
 #ifdef _FSTDIO
 # define _ptr _p                /* Gag    */
@@ -67,13 +68,19 @@ char *scanl = 0;			/* text of most recent scanline    */
 int sc_width (void);			/* from termsbr.c */
 static int mh_fputs(char *, FILE *);
 
+#ifdef MULTIBYTE_SUPPORT
+#define SCAN_CHARWIDTH MB_CUR_MAX
+#else
+#define SCAN_CHARWIDTH 1
+#endif
 
 int
 scan (FILE *inb, int innum, int outnum, char *nfs, int width, int curflg,
       int unseen, char *folder, long size, int noisy)
 {
     int i, compnum, encrypted, state;
-    char *cp, *tmpbuf, **nxtbuf;
+    unsigned char *cp, *tmpbuf;
+    char **nxtbuf;
     char *saved_c_text;
     struct comp *cptr;
     struct comp **savecomp;
@@ -96,8 +103,7 @@ scan (FILE *inb, int innum, int outnum, char *nfs, int width, int curflg,
 		width = MAXSCANL;
 	}
 	dat[3] = slwidth = width;
-	if ((scanl = (char *) malloc((size_t) (slwidth + 2) )) == NULL)
-	    adios (NULL, "unable to malloc scan line (%d bytes)", slwidth+2);
+	scanl = (char *) mh_xmalloc((size_t) SCAN_CHARWIDTH * (slwidth + 2) );
 	if (outnum)
 	    umask(~m_gmprot());
 
@@ -133,8 +139,7 @@ scan (FILE *inb, int innum, int outnum, char *nfs, int width, int curflg,
 	used_buf += ncomps+1; *--used_buf = 0;
 	rlwidth = bodycomp && (width > SBUFSIZ) ? width : SBUFSIZ;
 	for (i = ncomps; i--; )
-	    if ((*nxtbuf++ = malloc(rlwidth)) == NULL)
-		adios (NULL, "unable to allocate component buffer");
+	    *nxtbuf++ = mh_xmalloc(rlwidth);
     }
 
     /*
@@ -204,7 +209,7 @@ scan (FILE *inb, int innum, int outnum, char *nfs, int width, int curflg,
 		 */
 		if ((cptr = wantcomp[CHASH(name)])) {
 		    do {
-			if (!strcasecmp(name, cptr->c_name)) {
+			if (!mh_strcasecmp(name, cptr->c_name)) {
 			    if (! cptr->c_text) {
 				cptr->c_text = tmpbuf;
 				for (cp = tmpbuf + strlen (tmpbuf) - 1; 
