@@ -2,7 +2,7 @@
 /*
  * send.c -- send a composed message
  *
- * $Id: send.c,v 1.7 2003/09/30 16:58:43 gbburkhardt Exp $
+ * $Id: send.c,v 1.9 2007/11/04 11:54:36 jjr Exp $
  *
  * This code is Copyright (c) 2002, by the authors of nmh.  See the
  * COPYRIGHT file in the root directory of the nmh distribution for
@@ -104,6 +104,8 @@ static struct swit switches[] = {
     { "user", SASLminc(-4) },
 #define ATTACHSW              40
     { "attach", 6 },
+#define ATTACHFORMATSW        41
+    { "attachformat", 7 },
     { NULL, 0 }
 };
 
@@ -142,6 +144,7 @@ main (int argc, char **argv)
     struct msgs *mp;
     struct stat st;
     char	*attach = (char *)0;	/* header field name for attachments */
+    int attachformat = 0; /* mhbuild format specifier for attachments */
 #ifdef UCI
     FILE *fp;
 #endif /* UCI */
@@ -280,6 +283,21 @@ main (int argc, char **argv)
 		    if (!(attach = *argp++) || *attach == '-')
 			adios (NULL, "missing argument to %s", argp[-2]);
 		    continue;
+
+		case ATTACHFORMATSW:
+		    if (! *argp || **argp == '-')
+			adios (NULL, "missing argument to %s", argp[-1]);
+		    else {
+			attachformat = atoi (*argp);
+			if (attachformat < 0 ||
+			    attachformat > ATTACHFORMATS - 1) {
+			    advise (NULL, "unsupported attachformat %d",
+				    attachformat);
+			    continue;
+			}
+		    }
+		    ++argp;
+		    continue;
 	    }
 	} else {
 	    msgs[msgp++] = cp;
@@ -443,7 +461,8 @@ go_to_it:
     closefds (3);
 
     for (msgnum = 0; msgnum < msgp; msgnum++) {
-	switch (sendsbr (vec, vecp, msgs[msgnum], &st, 1, attach)) {
+	switch (sendsbr (vec, vecp, msgs[msgnum], &st, 1, attach,
+			 attachformat)) {
 	    case DONE: 
 		done (++status);
 	    case NOTOK: 
@@ -454,5 +473,6 @@ go_to_it:
     }
 
     context_save ();	/* save the context file */
-    return done (status);
+    done (status);
+    return 1;
 }
