@@ -2,7 +2,7 @@
 /*
  * sendsbr.c -- routines to help WhatNow/Send along
  *
- * $Id: sendsbr.c,v 1.7 2005/12/12 20:26:53 bress Exp $
+ * $Id: sendsbr.c,v 1.17 2007/11/04 11:54:36 jjr Exp $
  *
  * This code is Copyright (c) 2002, by the authors of nmh.  See the
  * COPYRIGHT file in the root directory of the nmh distribution for
@@ -15,6 +15,8 @@
 #include <signal.h>
 #include <fcntl.h>
 #include <h/mime.h>
+#include <h/tws.h>
+#include <h/utils.h>
 
 #ifdef TIME_WITH_SYS_TIME
 # include <sys/time.h>
@@ -39,7 +41,6 @@ char *altmsg   = NULL;		/*  .. */
 char *annotext = NULL;
 char *distfile = NULL;
 
-static int armed = 0;
 static jmp_buf env;
 
 static	char	body_file_name[MAXPATHLEN + 1];		/* name of temporary file for body content */
@@ -53,13 +54,13 @@ static	FILE	*composition_file;			/* composition file pointer */
 /*
  * external prototypes
  */
-int sendsbr (char **, int, char *, struct stat *, int, char *);
-int done (int);
+int sendsbr (char **, int, char *, struct stat *, int, char *, int);
 char *getusername (void);
 
 /*
  * static prototypes
  */
+static void armed_done (int);
 static void alert (char *, int);
 static int tmp_fd (void);
 static void anno (int, struct stat *);
@@ -67,10 +68,10 @@ static void annoaux (int);
 static int splitmsg (char **, int, char *, struct stat *, int);
 static int sendaux (char **, int, char *, struct stat *);
 
-static	int	attach(char *, char *);
+static	int	attach(char *, char *, int);
 static	void	clean_up_temporary_files(void);
 static	int	get_line(void);
-static	void	make_mime_composition_file_entry(char *);
+static	void	make_mime_composition_file_entry(char *, int);
 
 
 /*
@@ -78,7 +79,7 @@ static	void	make_mime_composition_file_entry(char *);
  */
 
 int
-sendsbr (char **vec, int vecp, char *drft, struct stat *st, int rename_drft, char *attachment_header_field_name)
+sendsbr (char **vec, int vecp, char *drft, struct stat *st, int rename_drft, char *attachment_header_field_name, int attachformat)
 {
     int status;
     char buffer[BUFSIZ], file[BUFSIZ];
@@ -103,7 +104,7 @@ sendsbr (char **vec, int vecp, char *drft, struct stat *st, int rename_drft, cha
      */
 
     if (attachment_header_field_name != (char *)0) {
-	switch (attach(attachment_header_field_name, drft)) {
+	switch (attach(attachment_header_field_name, drft, attachformat)) {
 	case OK:
 	    drft = composition_file_name;
 	    break;
@@ -116,7 +117,7 @@ sendsbr (char **vec, int vecp, char *drft, struct stat *st, int rename_drft, cha
 	}
     }
 
-    armed++;
+    done=armed_done;
     switch (setjmp (env)) {
     case OK: 
 	/*
@@ -152,7 +153,7 @@ sendsbr (char **vec, int vecp, char *drft, struct stat *st, int rename_drft, cha
 	break;
     }
 
-    armed = 0;
+    done=exit;
     if (distfile)
 	unlink (distfile);
 
@@ -187,7 +188,8 @@ sendsbr (char **vec, int vecp, char *drft, struct stat *st, int rename_drft, cha
 }
 
 static	int
-attach(char *attachment_header_field_name, char *draft_file_name)
+attach(char *attachment_header_field_name, char *draft_file_name,
+       int attachformat)
 {
     char		buf[MAXPATHLEN + 6];	/* miscellaneous buffer */
     int			c;			/* current character for body copy */
@@ -208,8 +210,7 @@ attach(char *attachment_header_field_name, char *draft_file_name)
      *  This buffer might need to be quite large, so we grow it as needed.
      */
 
-    if ((field = (char *)malloc(field_size = 256)) == (char *)0)
-	adios(NULL, "can't allocate field buffer.");
+    field = (char *)mh_xmalloc(field_size = 256);
 
     /*
      *	Scan the draft file for a header field name that matches the -attach
@@ -294,7 +295,7 @@ attach(char *attachment_header_field_name, char *draft_file_name)
      */
 
     if (has_body)
-	make_mime_composition_file_entry(body_file_name);
+	make_mime_composition_file_entry(body_file_name, attachformat);
 
     /*
      *	Now, go back to the beginning of the draft file and look for header fields
@@ -308,7 +309,7 @@ attach(char *attachment_header_field_name, char *draft_file_name)
 	    for (p = field + length + 1; *p == ' ' || *p == '\t'; p++)
 		;
 
-	    make_mime_composition_file_entry(p);
+	    make_mime_composition_file_entry(p, attachformat);
 	}
     }
 
@@ -360,8 +361,7 @@ get_line(void)
 	}
 
 	if (++n >= field_size - 1) {
-	    if ((field = (char *)realloc((void *)field, field_size += 256)) == (char *)0)
-		adios(NULL, "can't grow field buffer.");
+	    field = (char *)mh_xrealloc((void *)field, field_size += 256);
 
 	    p = field + n - 1;
 	}
@@ -377,7 +377,7 @@ get_line(void)
 }
 
 static	void
-make_mime_composition_file_entry(char *file_name)
+make_mime_composition_file_entry(char *file_name, int attachformat)
 {
     int			binary;			/* binary character found flag */
     int			c;			/* current character */
@@ -400,7 +400,7 @@ make_mime_composition_file_entry(char *file_name)
 
     if ((p = strrchr(file_name, '.')) != (char *)0) {
 	for (np = m_defs; np; np = np->n_next) {
-	    if (strncasecmp(np->n_name, "mhshow-suffix-", 14) == 0 && strcasecmp(p, np->n_field) == 0) {
+	    if (strncasecmp(np->n_name, "mhshow-suffix-", 14) == 0 && mh_strcasecmp(p, np->n_field) == 0) {
 		content_type = np->n_name + 14;
 		break;
 	    }
@@ -445,41 +445,84 @@ make_mime_composition_file_entry(char *file_name)
 	adios((char *)0, "unable to access file \"%s\"", file_name);
     }
 
-    (void)fprintf(composition_file, "#%s; name=\"%s\"; x-unix-mode=0%.3ho",
-     content_type, ((p = strrchr(file_name, '/')) == (char *)0) ? file_name : p + 1, (unsigned short)(st.st_mode & 0777));
+    switch (attachformat) {
+    case 0:
+        /* Insert name, file mode, and Content-Id. */
+        (void)fprintf(composition_file, "#%s; name=\"%s\"; x-unix-mode=0%.3ho",
+            content_type, ((p = strrchr(file_name, '/')) == (char *)0) ? file_name : p + 1, (unsigned short)(st.st_mode & 0777));
 
-    if (strlen(file_name) > MAXPATHLEN) {
-	clean_up_temporary_files();
-	adios((char *)0, "attachment file name `%s' too long.", file_name);
-    }
+        if (strlen(file_name) > MAXPATHLEN) {
+            clean_up_temporary_files();
+            adios((char *)0, "attachment file name `%s' too long.", file_name);
+        }
 
-    (void)sprintf(cmd, "file '%s'", file_name);
+        (void)sprintf(cmd, "file '%s'", file_name);
 
-    if ((fp = popen(cmd, "r")) != (FILE *)0 && fgets(cmd, sizeof (cmd), fp) != (char *)0) {
-	*strchr(cmd, '\n') = '\0';
+        if ((fp = popen(cmd, "r")) != (FILE *)0 && fgets(cmd, sizeof (cmd), fp) != (char *)0) {
+            *strchr(cmd, '\n') = '\0';
 
-	/*
-	 *  The output of the "file" command is of the form
-	 *
-	 *  	file:	description
-	 *
-	 *  Strip off the "file:" and subsequent white space.
-	 */
+            /*
+             *  The output of the "file" command is of the form
+             *
+             *  	file:	description
+             *
+             *  Strip off the "file:" and subsequent white space.
+             */
 
-	for (p = cmd; *p != '\0'; p++) {
-	    if (*p == ':') {
-		for (p++; *p != '\0'; p++) {
-		    if (*p != '\t')
-			break;
-		}
-		break;
-	    }
-	}
+            for (p = cmd; *p != '\0'; p++) {
+                if (*p == ':') {
+                    for (p++; *p != '\0'; p++) {
+                        if (*p != '\t')
+                            break;
+                    }
+                    break;
+                }
+            }
 
-	if (*p != '\0')
-	    (void)fprintf(composition_file, " [ %s ]", p);
+            if (*p != '\0')
+                /* Insert Content-Description. */
+                (void)fprintf(composition_file, " [ %s ]", p);
 
-	(void)pclose(fp);
+            (void)pclose(fp);
+        }
+
+        break;
+    case 1:
+        if (stringdex (m_maildir(invo_name), file_name) == 0) {
+            /* Content had been placed by send into a temp file.
+               Don't generate Content-Disposition header, because
+               it confuses Microsoft Outlook, Build 10.0.6626, at
+               least. */
+            (void) fprintf (composition_file, "#%s <>", content_type);
+        } else {
+            /* Suppress Content-Id, insert simple Content-Disposition. */
+            (void) fprintf (composition_file,
+                            "#%s; name=\"%s\" <>{attachment}",
+                            content_type,
+                            ((p = strrchr(file_name, '/')) == (char *)0) ? file_name : p + 1);
+        }
+
+        break;
+    case 2:
+        if (stringdex (m_maildir(invo_name), file_name) == 0) {
+            /* Content had been placed by send into a temp file.
+               Don't generate Content-Disposition header, because
+               it confuses Microsoft Outlook, Build 10.0.6626, at
+               least. */
+            (void) fprintf (composition_file, "#%s <>", content_type);
+        } else {
+            /* Suppress Content-Id, insert Content-Disposition with
+               modification date. */
+            (void) fprintf (composition_file,
+                            "#%s; name=\"%s\" <>{attachment; modification-date=\"%s\"}",
+                            content_type,
+                            ((p = strrchr(file_name, '/')) == (char *)0) ? file_name : p + 1,
+                            dtime (&st.st_mtime, 0));
+        }
+
+        break;
+    default:
+        adios ((char *)0, "unsupported attachformat %d", attachformat);
     }
 
     /*
@@ -527,13 +570,13 @@ splitmsg (char **vec, int vecp, char *drft, struct stat *st, int delay)
 		/*
 		 * This header field is discarded.
 		 */
-		if (!strcasecmp (name, "Message-ID")) {
+		if (!mh_strcasecmp (name, "Message-ID")) {
 		    while (state == FLDPLUS)
 			state = m_getfld (state, name, buffer, sizeof(buffer), in);
 		} else if (uprf (name, XXX_FIELD_PRF)
-			|| !strcasecmp (name, VRSN_FIELD)
-			|| !strcasecmp (name, "Subject")
-		        || !strcasecmp (name, "Encrypted")) {
+			|| !mh_strcasecmp (name, VRSN_FIELD)
+			|| !mh_strcasecmp (name, "Subject")
+		        || !mh_strcasecmp (name, "Encrypted")) {
 		    /*
 		     * These header fields are copied to the enclosed
 		     * header of the first message in the collection
@@ -542,7 +585,7 @@ splitmsg (char **vec, int vecp, char *drft, struct stat *st, int delay)
 		     * version of it, can be copied to the header
 		     * of each messsage/partial in the collection.
 		     */
-		    if (!strcasecmp (name, "Subject")) {
+		    if (!mh_strcasecmp (name, "Subject")) {
 			size_t sublen;
 
 			strncpy (subject, buffer, BUFSIZ);
@@ -966,7 +1009,7 @@ annoaux (int fd)
     }
     if (!(mp = folder_read (folder))) {
 	if (debugsw)
-	    admonish (NULL, "unable to read folder %s");
+	    admonish (NULL, "unable to read folder %s", folder);
 	return;
     }
 
@@ -1031,12 +1074,10 @@ oops:
 }
 
 
-int
-done (int status)
+static void
+armed_done (int status)
 {
-    if (armed)
-	longjmp (env, status ? status : NOTOK);
+    longjmp (env, status ? status : NOTOK);
 
     exit (status);
-    return 1;  /* dead code to satisfy the compiler */
 }
