@@ -2,7 +2,7 @@
 /*
  * show.c -- show/list messages
  *
- * $Id: show.c,v 1.6 2003/01/02 04:07:49 kimmo Exp $
+ * $Id: show.c,v 1.10 2007/04/13 11:53:08 jjr Exp $
  *
  * This code is Copyright (c) 2002, by the authors of nmh.  See the
  * COPYRIGHT file in the root directory of the nmh distribution for
@@ -11,6 +11,7 @@
 
 #include <h/mh.h>
 #include <h/mime.h>
+#include <h/utils.h>
 
 static struct swit switches[] = {
 #define CHECKMIMESW          0
@@ -80,9 +81,9 @@ main (int argc, char **argv)
     /* read user profile/context */
     context_read();
 
-    if (!strcasecmp (invo_name, "next")) {
+    if (!mh_strcasecmp (invo_name, "next")) {
 	mode = NEXT;
-    } else if (!strcasecmp (invo_name, "prev")) {
+    } else if (!mh_strcasecmp (invo_name, "prev")) {
 	mode = PREV;
     }
     arguments = getarguments (invo_name, argc, argv, 1);
@@ -178,7 +179,7 @@ usage:
 	    if (folder)
 		adios (NULL, "only one folder at a time!");
 	    else
-		folder = path (cp + 1, *cp == '+' ? TFOLDER : TSUBCWF);
+		folder = pluspath (cp);
 	} else {
 	    if (mode != SHOW)
 		goto usage;
@@ -384,7 +385,8 @@ static int
 is_nontext (char *msgnam)
 {
     int	result, state;
-    char *bp, *cp, *dp;
+    unsigned char *bp, *dp;
+    char *cp;
     char buf[BUFSIZ], name[NAMESZ];
     FILE *fp;
 
@@ -399,7 +401,7 @@ is_nontext (char *msgnam)
 	    /*
 	     * Check Content-Type field
 	     */
-	    if (!strcasecmp (name, TYPE_FIELD)) {
+	    if (!mh_strcasecmp (name, TYPE_FIELD)) {
 		int passno;
 		char c;
 
@@ -454,7 +456,7 @@ invalid:
 		if (!*bp)
 		    goto invalid;
 		if (passno > 1) {
-		    if ((result = (strcasecmp (bp, "plain") != 0)))
+		    if ((result = (mh_strcasecmp (bp, "plain") != 0)))
 			goto out;
 		    *dp = c;
 		    for (dp++; isspace (*dp); dp++)
@@ -486,7 +488,7 @@ invalid:
 		    /* Check the character set */
 		    result = !check_charset (dp, strlen (dp));
 		} else {
-		    if (!(result = (strcasecmp (bp, "text") != 0))) {
+		    if (!(result = (mh_strcasecmp (bp, "text") != 0))) {
 			*dp = c;
 			bp = dp;
 			passno = 2;
@@ -505,7 +507,7 @@ out:
 	    /*
 	     * Check Content-Transfer-Encoding field
 	     */
-	    if (!strcasecmp (name, ENCODING_FIELD)) {
+	    if (!mh_strcasecmp (name, ENCODING_FIELD)) {
 		cp = add (buf, NULL);
 		while (state == FLDPLUS) {
 		    state = m_getfld (state, name, buf, sizeof(buf), fp);
@@ -516,9 +518,9 @@ out:
 		for (dp = bp; istoken (*dp); dp++)
 		    continue;
 		*dp = '\0';
-		result = (strcasecmp (bp, "7bit")
-		       && strcasecmp (bp, "8bit")
-		       && strcasecmp (bp, "binary"));
+		result = (mh_strcasecmp (bp, "7bit")
+		       && mh_strcasecmp (bp, "8bit")
+		       && mh_strcasecmp (bp, "binary"));
 
 		free (cp);
 		if (result) {
