@@ -2,7 +2,7 @@
 /*
  * sortm.c -- sort messages in a folder by date/time
  *
- * $Id: sortm.c,v 1.8 2004/10/15 17:10:58 jon Exp $
+ * $Id: sortm.c,v 1.15 2007/11/04 11:54:36 jjr Exp $
  *
  * This code is Copyright (c) 2002, by the authors of nmh.  See the
  * COPYRIGHT file in the root directory of the nmh distribution for
@@ -11,13 +11,7 @@
 
 #include <h/mh.h>
 #include <h/tws.h>
-
-/*
- * We allocate space for messages (msgs array)
- * this number of elements at a time.
- */
-#define MAXMSGS  256
-
+#include <h/utils.h>
 
 static struct swit switches[] = {
 #define DATESW                 0
@@ -75,10 +69,12 @@ static void rename_msgs (struct msgs *, struct smsg **);
 int
 main (int argc, char **argv)
 {
-    int	nummsgs, maxmsgs, i, msgnum;
-    char *cp, *maildir, *datesw = NULL;
+    int	i, msgnum;
+    unsigned char *cp;
+    char *maildir, *datesw = NULL;
     char *folder = NULL, buf[BUFSIZ], **argp;
-    char **arguments, **msgs;
+    char **arguments;
+    struct msgs_array msgs = { 0, 0, NULL };
     struct msgs *mp;
     struct smsg **dlist;
 
@@ -93,15 +89,6 @@ main (int argc, char **argv)
     arguments = getarguments (invo_name, argc, argv, 1);
     argp = arguments;
 
-    /*
-     * Allocate the initial space to record message
-     * names and ranges.
-     */
-    nummsgs = 0;
-    maxmsgs = MAXMSGS;
-    if (!(msgs = (char **) malloc ((size_t) (maxmsgs * sizeof(*msgs)))))
-	adios (NULL, "unable to allocate storage");
-
     /*
      * Parse arguments
      */
@@ -174,26 +161,15 @@ main (int argc, char **argv)
 	    if (folder)
 		adios (NULL, "only one folder at a time!");
 	    else
-		folder = path (cp + 1, *cp == '+' ? TFOLDER : TSUBCWF);
-	} else {
-	    /*
-	     * Check if we need to allocate more space
-	     * for message names/ranges.
-	     */
-	    if (nummsgs >= maxmsgs) {
-		maxmsgs += MAXMSGS;
-		if (!(msgs = (char **) realloc (msgs,
-			(size_t) (maxmsgs * sizeof(*msgs)))))
-		    adios (NULL, "unable to reallocate msgs storage");
-	    }
-	    msgs[nummsgs++] = cp;
-	}
+		folder = pluspath (cp);
+	} else
+		app_msgarg(&msgs, cp);
     }
 
     if (!context_find ("path"))
 	free (path ("./", TFOLDER));
-    if (!nummsgs)
-	msgs[nummsgs++] = "all";
+    if (!msgs.size)
+	app_msgarg(&msgs, "all");
     if (!datesw)
 	datesw = "date";
     if (!folder)
@@ -212,8 +188,8 @@ main (int argc, char **argv)
 	adios (NULL, "no messages in %s", folder);
 
     /* parse all the message ranges/sequences and set SELECTED */
-    for (msgnum = 0; msgnum < nummsgs; msgnum++)
-	if (!m_convert (mp, msgs[msgnum]))
+    for (msgnum = 0; msgnum < msgs.size; msgnum++)
+	if (!m_convert (mp, msgs.msgs[msgnum]))
 	    done (1);
     seq_setprev (mp);	/* set the previous sequence */
 
@@ -223,9 +199,7 @@ main (int argc, char **argv)
     /*
      * sort a list of pointers to our "messages to be sorted".
      */
-    dlist = (struct smsg **) malloc ((nmsgs+1) * sizeof(*dlist));
-    if (! dlist)
-	adios (NULL, "couldn't allocate sort memory");
+    dlist = (struct smsg **) mh_xmalloc ((nmsgs+1) * sizeof(*dlist));
     for (i = 0; i < nmsgs; i++)
 	dlist[i] = &smsgs[i];
     dlist[nmsgs] = 0;
@@ -252,9 +226,7 @@ main (int argc, char **argv)
 	struct smsg **slist, **flist;
 	register struct smsg ***il, **fp, **dp;
 
-	slist = (struct smsg **) malloc ((nmsgs+1) * sizeof(*slist));
-	if (! slist)
-	    adios (NULL, "couldn't allocate sort memory");
+	slist = (struct smsg **) mh_xmalloc ((nmsgs+1) * sizeof(*slist));
 	memcpy((char *)slist, (char *)dlist, (nmsgs+1)*sizeof(*slist));
 	qsort((char *)slist, nmsgs, sizeof(*slist), (qsort_comp) subsort);
 
@@ -272,9 +244,7 @@ main (int argc, char **argv)
 	 * make up the final list, chronological but with
 	 * all the same subjects grouped together.
 	 */
-	flist = (struct smsg **) malloc ((nmsgs+1) * sizeof(*flist));
-	if (! flist)
-	    adios (NULL, "couldn't allocate msg list");
+	flist = (struct smsg **) mh_xmalloc ((nmsgs+1) * sizeof(*flist));
 	fp = flist;
 	for (dp = dlist; *dp;) {
 	    register struct smsg **s = il[(*dp++)->s_msg];
@@ -315,7 +285,8 @@ main (int argc, char **argv)
     seq_save (mp);			/* synchronize message sequences */
     context_save ();			/* save the context file         */
     folder_free (mp);			/* free folder/message structure */
-    return done (0);
+    done (0);
+    return 1;
 }
 
 static int
@@ -372,7 +343,7 @@ get_fields (char *datesw, int msg, struct smsg *smsg)
 	case FLDEOF:
 	case FLDPLUS:
 	    compnum++;
-	    if (!strcasecmp (nam, datesw)) {
+	    if (!mh_strcasecmp (nam, datesw)) {
 		datecomp = add (buf, datecomp);
 		while (state == FLDPLUS) {
 		    state = m_getfld (state, nam, buf, sizeof(buf), in);
@@ -380,7 +351,7 @@ get_fields (char *datesw, int msg, struct smsg *smsg)
 		}
 		if (!subjsort || subjcomp)
 		    break;
-	    } else if (subjsort && !strcasecmp (nam, subjsort)) {
+	    } else if (subjsort && !mh_strcasecmp (nam, subjsort)) {
 		subjcomp = add (buf, subjcomp);
 		while (state == FLDPLUS) {
 		    state = m_getfld (state, nam, buf, sizeof(buf), in);
@@ -439,7 +410,8 @@ get_fields (char *datesw, int msg, struct smsg *smsg)
 	     * leading "re:", everything but letters & smash
 	     * letters to lower case.
 	     */
-	    register char  *cp, *cp2, c;
+	    register char  *cp, *cp2;
+	    register unsigned char c;
 
 	    cp = subjcomp;
 	    cp2 = subjcomp;
