@@ -5,7 +5,7 @@
  * This is a simpler, faster, replacement for "post" for use
  * when "sendmail" is the transport system.
  *
- * $Id: spost.c,v 1.14 2003/09/22 01:04:04 gbburkhardt Exp $
+ * $Id: spost.c,v 1.19 2007/04/13 11:53:08 jjr Exp $
  *
  * This code is Copyright (c) 2002, by the authors of nmh.  See the
  * COPYRIGHT file in the root directory of the nmh distribution for
@@ -19,8 +19,7 @@
 #include <h/dropsbr.h>
 #include <h/tws.h>
 #include <h/mts.h>
-
-#define	uptolow(c)	((isalpha(c) && isupper (c)) ? tolower (c) : c)
+#include <h/utils.h>
 
 #define MAX_SM_FIELD	1476	/* < largest hdr field sendmail will accept */
 #define FCCS		10	/* max number of fccs allowed */
@@ -192,7 +191,7 @@ static void finish_headers (FILE *);
 static int get_header (char *, struct headers *);
 static void putadr (char *, struct mailname *);
 static int putone (char *, int, int);
-static void insert_fcc (struct headers *, char *);
+static void insert_fcc (struct headers *, unsigned char *);
 static void file (char *);
 static void fcc (char *, char *);
 
@@ -632,7 +631,7 @@ get_header (char *header, struct headers *table)
     struct headers *h;
 
     for (h = table; h->value; h++)
-	if (!strcasecmp (header, h->value))
+	if (!mh_strcasecmp (header, h->value))
 	    return (h - table);
 
     return NOTOK;
@@ -721,9 +720,9 @@ putone (char *adr, int pos, int indent)
 
 
 static void
-insert_fcc (struct headers *hdr, char *pp)
+insert_fcc (struct headers *hdr, unsigned char *pp)
 {
-    char   *cp;
+    unsigned char   *cp;
 
     for (cp = pp; isspace (*cp); cp++)
 	continue;
@@ -762,7 +761,18 @@ make_bcc_file (void)
     chmod (bccfil, 0600);
 
     fprintf (out, "Date: %s\n", dtimenow (0));
-    fprintf (out, "From: %s\n", signature);
+    if (msgflags & MFRM) {
+      /* There was already a From: in the draft.  Don't add one. */
+      if (!draft_from_masquerading)
+        /* mts.conf didn't contain "masquerade:[...]draft_from[...]"
+           so we'll reveal the user's actual account@thismachine
+           address in a Sender: header (and use it as the envelope
+           From: later). */
+        fprintf (out, "Sender: %s\n", from);
+    }
+    else
+      /* Construct a From: header. */
+      fprintf (out, "From: %s\n", signature);
     if (subject)
 	fprintf (out, "Subject: %s", subject);
     fprintf (out, "BCC:\n\n------- Blind-Carbon-Copy\n\n");
