@@ -2,7 +2,7 @@
 /*
  * termsbr.c -- termcap support
  *
- * $Id: termsbr.c,v 1.4 2002/07/02 22:09:15 kenh Exp $
+ * $Id: termsbr.c,v 1.5 2008/04/11 14:12:55 opk Exp $
  *
  * This code is Copyright (c) 2002, by the authors of nmh.  See the
  * COPYRIGHT file in the root directory of the nmh distribution for
@@ -105,10 +105,10 @@ read_termcap(void)
  * If possible, we let tgetent allocate its own termcap buffer
  */
 #ifdef TGETENT_ACCEPTS_NULL
-    if (tgetent (NULL, term) <= 0)
-	return
+    if (tgetent (NULL, term) != TGETENT_SUCCESS)
+	return;
 #else
-    if (tgetent (termbuf, term) <= 0)
+    if (tgetent (termbuf, term) != TGETENT_SUCCESS)
 	return;
 #endif
 
