@@ -2,7 +2,7 @@
 /*
  * viamail.c -- send multiple files in a MIME message
  *
- * $Id: viamail.c,v 1.9 2003/09/30 16:58:43 gbburkhardt Exp $
+ * $Id: viamail.c,v 1.11 2007/11/04 11:54:36 jjr Exp $
  *
  * This code is Copyright (c) 2002, by the authors of nmh.  See the
  * COPYRIGHT file in the root directory of the nmh distribution for
@@ -236,7 +236,7 @@ via_mail (char *mailsw, char *subjsw, char *parmsw, char *descsw,
     if (verbsw)
 	vec[vecp++] = "-verbose";
 
-    switch (sendsbr (vec, vecp, tmpfil, &st, 0, (char *)0)) {
+    switch (sendsbr (vec, vecp, tmpfil, &st, 0, (char *)0, 0)) {
 	case DONE:
 	case NOTOK:
 	    status++;
@@ -248,5 +248,6 @@ via_mail (char *mailsw, char *subjsw, char *parmsw, char *descsw,
     fclose (fp);
     if (unlink (tmpfil) == -1)
 	advise (NULL, "unable to remove temp file %s", tmpfil);
-    return done (status);
+    done (status);
+    return 1;
 }
