@@ -2,7 +2,11 @@
 /*
  * vmhsbr.c -- routines to help vmh along
  *
- * $Id: vmhsbr.c,v 1.3 1999/07/16 01:01:24 danh Exp $
+ * $Id: vmhsbr.c,v 1.7 2006/01/02 03:17:42 bress Exp $
+ *
+ * This code is Copyright (c) 2002, by the authors of nmh.  See the
+ * COPYRIGHT file in the root directory of the nmh distribution for
+ * complete copyright information.
  */
 
 /*
@@ -12,6 +16,7 @@
 
 #include <h/mh.h>
 #include <h/vmhsbr.h>
+#include <h/utils.h>
 #include <errno.h>
 
 static char *types[] = {
@@ -94,8 +99,7 @@ peer2rc (struct record *rc)
     if (read (PEERrfd, (char *) rc_head (rc), RHSIZE (rc)) != RHSIZE (rc))
 	return rclose (rc, "read from peer lost(1)");
     if (rc->rc_len) {
-	if ((rc->rc_data = malloc ((unsigned) rc->rc_len + 1)) == NULL)
-	    return rclose (rc, "malloc of %d lost", rc->rc_len + 1);
+	rc->rc_data = mh_xmalloc ((unsigned) rc->rc_len + 1);
 	if (read (PEERrfd, rc->rc_data, rc->rc_len) != rc->rc_len)
 	    return rclose (rc, "read from peer lost(2)");
 	rc->rc_data[rc->rc_len] = 0;
@@ -106,7 +110,7 @@ peer2rc (struct record *rc)
     if (fp) {
 	fseek (fp, 0L, SEEK_END);
 	fprintf (fp, "%d: <--- %s %d: \"%*.*s\"\n", (int) getpid(),
-		types[rc->rc_type], rc->rc_len,
+		types[(unsigned char)rc->rc_type], rc->rc_len,
 		rc->rc_len, rc->rc_len, rc->rc_data);
 	fflush (fp);
     }
@@ -127,7 +131,7 @@ rc2peer (char code, int len, char *data)
     if (fp) {
 	fseek (fp, 0L, SEEK_END);
 	fprintf (fp, "%d: ---> %s %d: \"%*.*s\"\n", (int) getpid(),
-		types[rc->rc_type], rc->rc_len,
+		types[(unsigned char)rc->rc_type], rc->rc_len,
 		rc->rc_len, rc->rc_len, data);
 	fflush (fp);
     }
